<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') or die;

use FOF40\Container\Container;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Object\CMSObject;
use Joomla\CMS\Plugin\CMSPlugin;

class plgButtonAtscannedreplies extends CMSPlugin
{
	/**
	 * Have I loaded my CSS and JS files?
	 *
	 * @var   bool
	 * @since 3.4.0
	 */
	protected static $loadStaticMedia = false;

	/**
	 * Load the language file on instantiation.
	 *
	 * @var    boolean
	 * @since  3.4.0
	 */
	protected $autoloadLanguage = true;

	/** @inheritDoc */
	public function __construct(&$subject, $config = [])
	{
		parent::__construct($subject, $config);
	}

	/**
	 * Display the button
	 *
	 * @param   string  $name  The name of the button to add
	 *
	 * @return  CMSObject|null  The button options as JObject
	 *
	 * @since   3.4.0
	 */
	public function onDisplay($name): ?CMSObject
	{
		if (!class_exists('\\FOF40\\Container\\Container'))
		{
			return null;
		}

		try
		{
			$container = Container::getInstance('com_ats', ['tempInstance' => true]);
		}
		catch (Throwable $e)
		{
			return null;
		}

		$hasAccess = (bool) $container->platform->getSessionVar('canned_replies.enabled', false, 'com_ats');

		if (!$hasAccess)
		{
			return null;
		}

		// Load static media
		$this->loadStaticMedia();

		// Pass script options
		$document = Factory::getApplication()->getDocument();
		$document->addScriptOptions('plg_editors-xtd_atscannedreplies_editor', $name);

		// Modal options
		$options = '{handler: \'iframe\', size: {x: 800, y: 500}}';

		if (version_compare(JVERSION, '3.999.999', 'gt'))
		{
			$options = [
				'height'     => '300px',
				'width'      => '800px',
				'bodyHeight' => '70',
				'modalWidth' => '80',
			];
		}

		// Modal window link
		$app        = Factory::getApplication();
		$isSite     = $app->isClient('site');
		$layout     = $isSite ? 'default' : 'choose';
		$categoryId = (int) $container->platform->getSessionVar('canned_replies.category', 0, 'com_ats');
		$link       = sprintf('index.php?option=com_ats&view=CannedReplies&layout=%s&tmpl=component&category=%u', $layout, $categoryId);

		$svgIconText = file_get_contents(JPATH_SITE . '/media/com_ats/images/ats_color.svg');

		return new CMSObject([
			'modal'    => true,
			'class'    => 'btn',
			'link'     => $link,
			'text'     => Text::_('PLG_EDITORS_XTD_ATSCANNEDREPLIES_BTN_TITLE'),
			'name'     => 'atscannedreplies',
			'options'  => $options,
			'iconSVG'  => $svgIconText,
			'realName' => __CLASS__,
		]);
	}

	/**
	 * Loads the CSS and JS files required for this feature
	 *
	 * @throws Exception
	 * @since  3.4.0
	 */
	protected function loadStaticMedia(): void
	{
		if (self::$loadStaticMedia)
		{
			return;
		}

		self::$loadStaticMedia = true;

		if (!class_exists('\FOF40\Container\Container'))
		{
			return;
		}

		$document = Factory::getApplication()->getDocument();
		$container = Container::getInstance('com_ats');
		$document->addStyleSheet('media/plg_editors-xtd_atscannedreplies/css/cannedreplies.min.css', [
			'version' => $container->mediaVersion
		]);
		$document->addScript('media/plg_editors-xtd_atscannedreplies/js/CannedReplies.min.js', [
			'version' => $container->mediaVersion
		], [
			'defer' => true
		]);
	}
}