<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Credits;
use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\CMSPlugin;

// Make sure F0F is loaded, otherwise do not run
if (!defined('FOF40_INCLUDED') && !@include_once(JPATH_LIBRARIES . '/fof40/include.php'))
{
	return;
}

class plgContentAtscredits extends CMSPlugin
{
	/** @var \FOF40\Container\Container The container of the component */
	protected $container;

	public function __construct(&$subject, $config)
	{
		parent::__construct($subject, $config);

		$this->loadLanguage();
		$this->container = \FOF40\Container\Container::getInstance('com_ats');
	}

	public function onContentPrepare($context, &$article, &$params, $limitstart = 0)
	{
		// Check whether the plugin should process or not
		if (\Joomla\String\StringHelper::strpos($article->text, 'atscredits') === false)
		{
			return true;
		}

		// Search for this tag in the content
		$regex = "#{atscredits(.*?)}#s";

		$article->text = preg_replace_callback($regex, ['self', 'process'], $article->text);
	}

	private function process($match)
	{
		if (Permissions::getUser()->guest)
		{
			$ret = '';
		}
		else
		{
			$credits = Credits::creditsLeft(Permissions::getUser()->id, true);
			$ret     = Text::sprintf('PLG_ATSCREDITS_CREDITS', $credits);
		}

		return $ret;
	}
}

