<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\Controller;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Model\Buckets;
use FOF40\Container\Container;
use FOF40\Controller\DataController;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;

class Bucket extends DataController
{
	public function __construct(Container $container, array $config = [])
	{
		parent::__construct($container, $config);

		$this->registerTask('choosebucket', 'browse');
		$this->registerTask('blank', 'browse');
	}

	public function newreply()
	{
		// CSRF prevention
		$this->csrfProtection();

		/** @var \Akeeba\TicketSystem\Admin\Model\Buckets $model */
		$model  = $this->getModel();
		$data   = $this->input->getData();
		$result = $model->reply($data);

		if ($result)
		{
			$msg  = Text::_('COM_ATS_BUCKET_POST_ADDED');
			$type = 'message';
		}
		else
		{
			$msg  = Text::_('COM_ATS_BUCKET_POST_ADD_ERROR');
			$type = 'error';
		}

		$url = 'index.php?option=com_ats&view=Buckets&task=edit&id=' . $data['ats_bucket_id'];

		if ($customURL = $this->input->getString('returnurl', ''))
		{
			$url = base64_decode($customURL);
		}

		$this->setRedirect($url, $msg, $type);
	}

	public function close()
	{
		$this->csrfProtection();

		/** @var Buckets $bucket */
		$bucket = $this->getModel();

		if (!$bucket->getId())
		{
			$this->getIDsFromRequest($bucket);
		}

		$data           = $bucket->getData();
		$data['status'] = 'C';

		$url = 'index.php?option=com_ats&view=Bucket&id=' . $bucket->ats_bucket_id . $this->getItemidURLSuffix();

		if ($customURL = $this->input->getBase64('returnurl', ''))
		{
			$url = base64_decode($customURL);
		}

		try
		{
			$bucket->save($data);

			$this->setRedirect($url);
		}
		catch (\Exception $e)
		{
			$this->setRedirect($url, $e->getMessage(), 'error');
		}

		return true;
	}

	public function reopen()
	{
		$this->csrfProtection();

		/** @var Buckets $bucket */
		$bucket = $this->getModel();

		if (!$bucket->getId())
		{
			$this->getIDsFromRequest($bucket);
		}

		$data           = $bucket->getData();
		$data['status'] = 'O';

		$url = 'index.php?option=com_ats&view=Bucket&id=' . $bucket->ats_bucket_id . $this->getItemidURLSuffix();

		if ($customURL = $this->input->getBase64('returnurl', ''))
		{
			$url = base64_decode($customURL);
		}

		try
		{
			$bucket->save($data);

			$this->setRedirect($url);
		}
		catch (\Exception $e)
		{
			$this->setRedirect($url, $e->getMessage(), 'error');
		}

		return true;
	}

	/**
	 * Adds tickets to a bucket.
	 *
	 * This is meant to be called through AJAX.
	 *
	 * @since  3.4.0
	 */
	public function addtickets()
	{
		$tickets  = $this->input->get('ats_ticket_id', [], 'array');
		$bucket   = $this->input->get('cid', [], 'array');
		$response = (object) [
			'success' => true,
			'message' => null,
		];

		if ($bucket)
		{
			$bucket = array_shift($bucket);
		}

		if (!$bucket)
		{
			$response->success = false;
			$response->message = Text::_('COM_ATS_BUCKETS_CHOOSE_ONE');

			echo '###' . json_encode($response) . '###';

			$this->container->platform->closeApplication();
		}

		if (!$tickets)
		{
			$response->success = false;
			$response->message = Text::_('COM_ATS_BUCKETS_NO_TICKET_SELECTED');

			echo '###' . json_encode($response) . '###';

			$this->container->platform->closeApplication();

		}

		/** @var \Akeeba\TicketSystem\Admin\Model\Tickets $ticketModel */
		$ticketModel = $this->container->factory->model('Tickets')->tmpInstance();
		$result      = $ticketModel->addTicketsToBucket($tickets, $bucket);

		$response->success = false;
		$response->message = Text::_('COM_ATS_BUCKETS_TICKETS_NOT_ADDED');

		if ($result)
		{
			$response->success = true;
			$response->message = Text::_('COM_ATS_BUCKETS_TICKETS_ADDED');
		}

		echo '###' . json_encode($response) . '###';

		$this->container->platform->closeApplication();
	}

	public function onBeforeRead()
	{
		HTMLHelper::_('behavior.keepalive');
	}

	public function onBeforeEdit()
	{
		HTMLHelper::_('behavior.keepalive');
	}
}
