<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\Controller;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Model\Categories;
use Akeeba\TicketSystem\Admin\Model\CustomFields;
use FOF40\Controller\DataController;
use FOF40\Model\DataModel\Collection;

class CustomField extends DataController
{
	protected function onAfterApplySave()
	{
		/** @var CustomFields $model */
		$model = $this->getModel();

		$rawCategoryIDs = array_map(function ($x) {
			return max((int) $x, 0);
		}, $this->input->get('cats', [], 'array'));

		$rawCategoryIDs = array_filter($rawCategoryIDs, function ($x) {
			return $x > 0;
		});

		$model->cats->reset();

		array_map(function ($catId) use (&$model) {
			/** @var Categories $item */
			$item = $this->container->factory->model('Categories')->tmpInstance();

			if ($item->load($catId))
			{
				$model->cats->add($item);
			}

			return $catId;
		}, $rawCategoryIDs);

		$model->push();
	}
	
    /**
     * We are telling the model to not perform additional checks on the linked category, since we are working in the
     * browser view and we're not passing all the required info (for example we are reordering or unpublishing a record)
     */
    protected function onBeforeSaveorder()
    {
        /** @var \Akeeba\TicketSystem\Admin\Model\CustomFields $model */
        $model = $this->getModel();
        $model->preventCatCheck = true;
    }

    protected function onAfterSaveorder()
    {
        /** @var \Akeeba\TicketSystem\Admin\Model\CustomFields $model */
        $model = $this->getModel();
        $model->preventCatCheck = false;
    }

    protected function onBeforePublish()
    {
        /** @var \Akeeba\TicketSystem\Admin\Model\CustomFields $model */
        $model = $this->getModel();
        $model->preventCatCheck = true;
    }

    protected function onAfterPublish()
    {
        /** @var \Akeeba\TicketSystem\Admin\Model\CustomFields $model */
        $model = $this->getModel();
        $model->preventCatCheck = false;
    }

    protected function onBeforeUnpublish()
    {
        /** @var \Akeeba\TicketSystem\Admin\Model\CustomFields $model */
        $model = $this->getModel();
        $model->preventCatCheck = true;
    }

    protected function onAfterUnpublish()
    {
        /** @var \Akeeba\TicketSystem\Admin\Model\CustomFields $model */
        $model = $this->getModel();
        $model->preventCatCheck = false;
    }
}
