<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\Controller;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Email;
use Akeeba\TicketSystem\Admin\Helper\Permissions;
use FOF40\Controller\DataController;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;

class EmailTemplate extends DataController
{
	public function testtemplate()
	{
		$id = $this->input->getInt('id', 0);

		$conf = $this->container->platform->getConfig();

		try
		{
			$mailer = Email::getMailer();
		}
		catch (\Exception $e)
		{
			$this->setRedirect('index.php?option=com_ats&view=EmailTemplate&id=' . $id,
				Text::sprintf('COM_ATS_EMAILTEMPLATES_TEST_NOTSENT', $e->getMessage()),
				'error'
			);

			return;
		}

		/** @var \Akeeba\TicketSystem\Admin\Model\EmailTemplates $model */
		$model = $this->getModel();
		$key   = $model->getKey($id);

		[$subject, $body, $loadedLanguage] = Email::loadEmailTemplateFromDB($key);

		$mailInfo = [
			'id'              => '12345',
			'title'           => 'Template Test',
			'url'             => Uri::root(),
			'attachment'      => '',
			'poster_username' => 'Poster Username',
			'poster_name'     => 'Poster Name',
			'user_username'   => 'Notified user Username',
			'user_name'       => 'Notified user Name',
			'text'            => 'This is the text contained inside the post',
			'catname'         => 'Category title',
			'sitename'        => $conf->get('sitename'),
			'origin'          => 'ORIGIN',
			'avatar'          => '',
			'assigned_to'     => 'Assigned user',
		];

		try
		{
			Email::parseTemplate($body, $subject, $mailInfo, $mailer);

			$user = Permissions::getUser();
			$mailer->addRecipient($user->email, $user->name);
			$mailer->Send();

			$this->setRedirect('index.php?option=com_ats&view=EmailTemplate&id=' . $id, Text::_('COM_ATS_EMAILTEMPLATES_TEST_SENT'));
		}
		catch (\Exception $e)
		{
			// JMail died on us
			$this->setRedirect('index.php?option=com_ats&view=EmailTemplate&id=' . $id,
				Text::sprintf('COM_ATS_EMAILTEMPLATES_TEST_NOTSENT', $e->getMessage()),
				'error'
			);

			return;
		}
	}
}
