<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\Controller;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Model\Log as LogModel;
use FOF40\Container\Container;
use FOF40\Controller\Controller;
use FOF40\Controller\Mixin\PredefinedTaskList;

/**
 * ATS Log Viewer Controller
 *
 * @since       3.2.0
 */
class Log extends Controller
{
	use PredefinedTaskList;

	/** @inheritDoc */
	public function __construct(Container $container, array $config = [])
	{
		parent::__construct($container, $config);

		$this->predefinedTaskList = ['default', 'iframe', 'download', 'inlineRaw'];
	}

	/**
	 * Display the log page
	 *
	 * @return  void
	 *
	 * @since   3.2.0
	 */
	public function onBeforeDefault()
	{
		$filename = $this->input->get('filename', null, 'cmd');

		if (empty($filename))
		{
			$filename = null;
		}

		/** @var LogModel $model */
		$model = $this->getModel();
		$model->setState('filename', $filename);
	}

	/**
	 * Renders the contents of the log, used inside the IFRAME of the log page
	 *
	 * @return  void
	 *
	 * @since   3.2.0
	 */
	public function iframe()
	{
		$filename = $this->input->get('filename', null, 'cmd');

		if (empty($filename))
		{
			$filename = null;
		}

		/** @var LogModel $model */
		$model = $this->getModel();
		$model->setState('filename', $filename);

		$this->display();
	}

	/**
	 * Download the log file as a text file
	 *
	 * @return  void
	 *
	 * @since   3.2.0
	 */
	public function download()
	{
		$filename = $this->input->get('filename', null, 'cmd');

		if (empty($filename))
		{
			$filename = null;
		}

		/** @var LogModel $model */
		$model = $this->getModel();
		$model->setState('filename', $filename);

		$asAttachment = $this->input->getBool('attachment', true);

		@ob_end_clean(); // In case some braindead plugin spits its own HTML
		header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
		header("Expires: Sat, 26 Jul 1997 05:00:00 GMT"); // Date in the past
		header("Content-Description: File Transfer");
		header('Content-Type: text/plain');

		if ($asAttachment)
		{
			header('Content-Disposition: attachment; filename="Akeeba Ticket System Debug Log.txt"');
		}

		$model->echoRawLog();

		flush();
		$this->container->platform->closeApplication();
	}

	/**
	 * Display the log file as preformatted HTML text
	 *
	 * @return  void
	 *
	 * @since   3.2.0
	 */
	public function inlineRaw()
	{
		$filename = $this->input->get('filename', null, 'cmd');

		if (empty($filename))
		{
			$filename = null;
		}

		/** @var LogModel $model */
		$model = $this->getModel();
		$model->setState('filename', $filename);

		echo "<pre>";
		$model->echoRawLog();
		echo "</pre>";
	}
}