<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\CustomField;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Model\CustomFields;
use \Joomla\CMS\Language\Text as JText;

/**
 * A single checkbox field
 *
 * @author Nicholas K. Dionysopoulos
 */
class Checkbox extends Base
{
	public function getField($item, $cache)
	{
		// Get the current value
		$current = $this->getCurrentValue($item, $cache, true);

		// Is this a required field?
		$required = $item->allow_empty ? '' : '* ';

		// Parse value
		if ($current)
		{
			$checked = 'checked="checked"';
		}
		else
		{
			$checked = '';
		}

		// Set up field's HTML content
		$html = '<input type="checkbox" name="params[' . $item->slug . ']" id="' . $item->slug . '" ' . $checked . ' />';

		// Setup the field
		$field = [
			'id'          => $item->slug,
			'label'       => $required . JText::_($item->title),
			'elementHTML' => $html,
			'isValid'     => $required ? !empty($current) : true,
		];

		if ($item->invalid_label)
		{
			$field['invalidLabel'] = JText::_($item->invalid_label);
		}

		if ($item->valid_label)
		{
			$field['validLabel'] = JText::_($item->valid_label);
		}

		return $field;
	}

	public function validate($item, &$custom)
	{
		if (!is_array($custom) || !array_key_exists($item->slug, $custom))
		{
			$custom[$item->slug] = 0;
		}

		$valid = true;

		if (!$item->allow_empty)
		{
			$valid = $custom[$item->slug];
		}

		return $valid ? 1 : 0;
	}

	public function getDisplay(CustomFields $item, $value)
	{
		return strtolower($value) == 'on' ? JText::_('JYES') : JText::_('JNO');
	}
}
