<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\CustomField;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Model\CustomFields;
use Joomla\CMS\Language\Text;

/**
 * A multiple selection list field
 *
 * @author Nicholas K. Dionysopoulos
 */
class Multiselect extends Dropdown
{
	public function __construct(array $config = [])
	{
		parent::__construct($config);

		$this->input_type = 'multiselect';
	}

	public function getDisplay(CustomFields $item, $value)
	{
		$values = [];

		foreach ($value as $selected)
		{
			// Let's quote the expression and escape the / char, since it could be used as value
			$regex_selected = str_replace('/', '\/', preg_quote($selected));

			preg_match('/' . $regex_selected . '=(.*?)(?:$|\n)/i', $item->options, $matches);

			if (isset($matches[1]))
			{
				$values[] = Text::_(trim($matches[1]));
			}
		}

		return implode(', ', $values);
	}


}
