<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\CustomField;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Model\CustomFields;
use Joomla\CMS\Language\Text as JText;

/**
 * A textarea field
 *
 * @author Nicholas K. Dionysopoulos
 * @since  2.6.0
 */
class Textarea extends Base
{
	/**
	 * Creates a custom field of the "textarea" type
	 *
	 * @param   CustomFields  $item   A custom field definition
	 * @param   array         $cache  The values cache
	 *
	 * @return  array
	 */
	public function getField($item, $cache)
	{
		// Get the current value
		$current = $this->getCurrentValue($item, $cache);

		// Is this a required field?
		$required = $item->allow_empty ? '' : '* ';

		// Parse options
		if ($item->options)
		{
			$placeholder = htmlentities(str_replace("\n", '', $item->options), ENT_COMPAT, 'UTF-8');
		}
		else
		{
			$placeholder = '';
		}

		// Set up field's HTML content
		$html = '<textarea name="params[' . $item->slug . ']" id="' . $item->slug . '" placeholder="' . $placeholder . '">';
		$html .= $current;
		$html .= '</textarea>';

		// Setup the field
		$field = [
			'id'          => $item->slug,
			'label'       => $required . JText::_($item->title),
			'elementHTML' => $html,
			'isValid'     => $required ? !empty($current) : true,
		];

		if ($item->invalid_label)
		{
			$field['invalidLabel'] = JText::_($item->invalid_label);
		}
		if ($item->valid_label)
		{
			$field['validLabel'] = JText::_($item->valid_label);
		}

		return $field;
	}

	/**
	 * Validate a text field
	 *
	 * @param   CustomFields  $item    The custom field to validate
	 * @param   array         $custom  The custom fields' values array
	 *
	 * @return int 1 if the field is valid, 0 otherwise
	 */
	public function validate($item, &$custom)
	{
		if (!isset($custom[$item->slug]) || !is_array($custom))
		{
			$custom[$item->slug] = '';
		}
		elseif (!array_key_exists($item->slug, $custom))
		{
			$custom[$item->slug] = '';
		}

		$valid = true;

		if (!$item->allow_empty)
		{
			$valid = !empty($custom[$item->slug]);
		}

		return $valid ? 1 : 0;
	}
}
