<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\Model;

defined('_JEXEC') or die;

use FOF40\Container\Container;
use FOF40\Database\Installer;
use FOF40\Model\Model;

class ControlPanel extends Model
{
	/**
	 * Checks if there is at least one menu entry that shows all the categories.
	 * This is needed because otherwise JRoute won't find any suitable menu
	 *
	 * @return bool
	 */
	public static function needsCategoriesMenu()
	{
		$container = Container::getInstance('com_ats');
		$db        = $container->db;

		$query = $db->getQuery(true)
			->select('COUNT(id)')
			->from('#__menu')
			->where($db->qn('link') . ' = ' . $db->q('index.php?option=com_ats&view=Categories'))
			->where($db->qn('published') . ' = ' . $db->q(1));

		return !(bool) $db->setQuery($query)->loadResult();
	}

	/**
	 * Checks the database for missing / outdated tables using the $dbChecks
	 * data and runs the appropriate SQL scripts if necessary.
	 *
	 * @return  $this
	 * @throws  \RuntimeException    If the previous database update is stuck
	 *
	 */
	public function checkAndFixDatabase()
	{
		$params = $this->container->params;

		// First of all let's check if we are already updating
		$stuck = $params->get('updatedb', 0);

		if ($stuck)
		{
			throw new \RuntimeException('Previous database update is flagged as stuck');
		}

		// Then set the flag
		$params->set('updatedb', 1);
		$params->save();

		$db = $this->container->platform->getDbo();

		$dbInstaller = new Installer($db, JPATH_ADMINISTRATOR . '/components/com_ats/sql/xml');
		$dbInstaller->updateSchema();

		// And finally remove the flag if everything went fine
		$params->set('updatedb', null);
		$params->save();

		return $this;
	}

	/**
	 * Does the user needs to enter a Download ID?
	 *
	 * @return boolean
	 */
	public function needsDownloadID()
	{
		/** @var Updates $updateModel */
		$updateModel = $this->container->factory->model('Updates')->tmpInstance();

		// Migrate J3 to J4 settings
		$updateModel->upgradeLicenseKey();

		// Save the J4 license key in the component options, if necessary
		$updateModel->backportLicenseKey();

		// Do I need a Download ID?
		$isPro = defined('ATS_PRO') ? ATS_PRO : 0;

		if (!$isPro)
		{
			return false;
		}

		$dlid = $updateModel->sanitizeLicenseKey($updateModel->getLicenseKey());

		return !$updateModel->isValidLicenseKey($dlid);
	}
}
