<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\Toolbar;

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper as JHtml;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Toolbar\Toolbar as JToolbar;
use Joomla\CMS\Toolbar\ToolbarHelper as JToolBarHelper;

class Toolbar extends \FOF40\Toolbar\Toolbar
{
	/**
	 * Renders the submenu (toolbar links) for all defined views of this component
	 */
	public function renderSubmenu(): void
	{
		$views = [
			'ControlPanel',
			'COM_ATS_MAINMENU_SETUP' => [
				'CustomFields',
				'EmailTemplates',
				'UserTags',
				'OfflineSchedules',
				'SchedulingInfo',
			],
			'COM_ATS_FAST_REPLIES'   => [
				'AutoReplies',
				'Buckets',
				'CannedReplies',
			],
			'COM_ATS_REPORTS'        => [
				'TimeCards',
				'Log',
			],
			'CreditTransactions',
			'Tickets',
		];

		$proOnlyFeatures = [
			'Buckets',
			'EmailTemplates',
			'CannedReplies',
			'CreditTransactions',
			'OfflineSchedules',
			'SchedulingInfo',
			'TimeCards',
			'Log',
			'COM_ATS_REPORTS',
		];

		$isCore = !defined('ATS_PRO') || (!ATS_PRO);

		foreach ($views as $label => $view)
		{
			if (!is_array($view))
			{
				if (in_array($view, $proOnlyFeatures) && $isCore)
				{
					continue;
				}

				$this->addSubmenuLink($view);
				continue;
			}
			elseif (in_array($label, $proOnlyFeatures) && $isCore)
			{
				continue;
			}

			$label = Text::_($label);
			$this->appendLink($label, '', false);

			foreach ($view as $v)
			{
				if (in_array($v, $proOnlyFeatures) && $isCore)
				{
					continue;
				}

				$this->addSubmenuLink($v, $label);
			}
		}

		$this->appendLink(
			Text::_('COM_ATS_SUBMENU_CATEGORIES'),
			'index.php?option=com_categories&extension=com_ats'
		);
	}

	public function onControlPanels()
	{
		$this->renderSubmenu();

		$option = $this->container->componentName;

		JToolBarHelper::title(Text::_(strtoupper($option)), str_replace('com_', '', $option));

		JToolBarHelper::preferences($option);
	}

	public function onEmailtemplatesAdd()
	{
		// Quick hack to mark this record as new
		$this->_isNew = true;

		parent::onAdd();
	}

	public function onEmailtemplatesEdit()
	{
		if (!isset($this->_isNew))
		{
			JToolBarHelper::custom('testtemplate', 'print', '', 'COM_ATS_EMAILTEMPLATES_TESTTEMPLATE', false);
		}

		parent::onEdit();
	}

	public function onTicketsBrowse()
	{
		parent::onBrowse();

		$bar = JToolbar::getInstance();

		// Add to bucket button
		$html = '<a id="bucketadd" class="btn btn-small" href="index.php?option=com_ats&view=Buckets&tmpl=component&task=choosebucket&layout=choose">';
		$html .= '<span class="icon-cogs"></span>' . Text::_('COM_ATS_ADD_TO_BUCKET');
		$html .= '</a>';

		$bar->appendButton('Custom', $html, 'bucketadd');

		// Export as CSV button
		$csvLink = 'index.php?option=com_ats&view=Tickets&task=browse&format=csv';

		$bar->appendButton('Link', 'download', Text::_('COM_ATS_COMMON_EXPORTCSV'), $csvLink);
	}

	public function onTimecards()
	{
		JToolBarHelper::title(Text::_('COM_ATS') . ': ' . Text::_('COM_ATS_TITLE_TIMECARDS'), 'ats');

		$this->renderSubmenu();
	}

	public function onLogs()
	{
		JToolBarHelper::title(Text::_('COM_ATS') . ': ' . Text::_('COM_ATS_TITLE_LOG'), 'ats');

		$this->renderSubmenu();
	}

	public function onSchedulingInfos()
	{
		JToolBarHelper::title(Text::_('COM_ATS') . ': ' . Text::_('COM_ATS_TITLE_SCHEDULINGINFO'), 'ats');
		$this->renderSubmenu();
	}

	/**
	 * Adds a link to the submenu (toolbar links)
	 *
	 * @param   string  $view    The view we're linking to
	 * @param   array   $parent  The parent view
	 */
	private function addSubmenuLink($view, $parent = null)
	{
		static $activeView = null;

		if (empty($activeView))
		{
			$activeView = $this->container->input->getCmd('view', 'cpanel');
		}

		if ($activeView == 'cpanels')
		{
			$activeView = 'cpanel';
		}

		$key = $this->container->componentName . '_TITLE_' . $view;

		// Exceptions to avoid introduction of a new language string
		if ($view == 'ControlPanel')
		{
			$key = $this->container->componentName . '_TITLE_CPANEL';
		}

		if (strtoupper(Text::_($key)) == strtoupper($key))
		{
			$altView = $this->container->inflector->isPlural($view) ? $this->container->inflector->singularize($view) : $this->container->inflector->pluralize($view);
			$key2    = strtoupper($this->container->componentName) . '_TITLE_' . strtoupper($altView);

			if (strtoupper(Text::_($key2)) == $key2)
			{
				$name = ucfirst($view);
			}
			else
			{
				$name = Text::_($key2);
			}
		}
		else
		{
			$name = Text::_($key);
		}

		$link = 'index.php?option=' . $this->container->componentName . '&view=' . $view;

		$active = $view == $activeView;

		$this->appendLink($name, $link, $active, null, $parent);
	}
}
