<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\View\ControlPanel;

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;

class Html extends \FOF40\View\DataView\Html
{
	/** @var bool Is the Download ID missing? */
	public $needsdlid;

	/** @var bool Is a menu item for ATS missing? */
	public $needsMenuItem;

	/** @var string The formatted date when we stop supporting older PHP versions */
	public $akeebaCommonDateObsolescence;

	/** @var string The formatted date when the PHP version went EOL */
	public $akeebaCommonDatePHP;

	/** @var string IFRAME definition for stats collection */
	public $statsIframe;

	/**
	 * Do I have stuck updates pending?
	 *
	 * @var  bool
	 */
	public $stuckUpdates = false;

	protected function onBeforeMain($tpl = null)
	{
		$container = $this->container;
		$container->template->addJS('media://com_ats/js/ControlPanel.min.js', true, false, $container->mediaVersion);
		$container->template->addJS('https://cdn.jsdelivr.net/npm/chart.js@3.2.1/dist/chart.min.js', true);
		$container->template->addJS('https://cdn.jsdelivr.net/npm/moment@2.27.0', true);
		$container->template->addJS('https://cdn.jsdelivr.net/npm/chartjs-adapter-moment@0.1.1', true);

		if ($container->params->get('userfeedback', 0) && ATS_PRO)
		{
			HTMLHelper::_('jquery.framework');

			$container->template->addJS('media://com_ats//datatables/js/datatables.min.js', true, false, $container->mediaVersion);
			$container->template->addJS('media://com_ats//datatables/js/paging.js', true, false, $container->mediaVersion);
			$container->template->addCSS('media://com_ats/datatables/css/datatables.css', $container->mediaVersion);
		}

		Text::script('COM_ATS_CPANEL_OPENED');
		Text::script('COM_ATS_CPANEL_SAVED');

		$platform = $container->platform;

		/** @var \Akeeba\TicketSystem\Admin\Model\ControlPanel $model */
		$model = $this->getModel();
		/** @var \Akeeba\TicketSystem\Admin\Model\Stats $stats */
		$stats = $container->factory->model('Stats')->tmpInstance();

		$this->akeebaCommonDatePHP          = $platform->getDate('2015-09-03 00:00:00', 'GMT')->format(Text::_('DATE_FORMAT_LC1'));
		$this->akeebaCommonDateObsolescence = $platform->getDate('2016-06-03 00:00:00', 'GMT')->format(Text::_('DATE_FORMAT_LC1'));
		$this->needsdlid                    = $model->needsDownloadID();
		$this->needsMenuItem                = $model->needsCategoriesMenu();
		$this->statsIframe                  = $stats->collectStatistics(true);
		$this->stuckUpdates                 = ($container->params->get('updatedb', 0) == 1);
	}
}
