<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\View\Log;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Model\Log;
use Exception;
use FOF40\View\DataView\Html as BaseView;

class Html extends BaseView
{
	/**
	 * Big log file threshold: 2Mb
	 */
	const bigLogSize = 2097152;
	/**
	 * JHtml list of available log files
	 *
	 * @var  array
	 */
	public $logs = [];
	/**
	 * Currently selected log file name
	 *
	 * @var  string
	 */
	public $filename;
	/**
	 * Is the selected log file too big for being displayed by default?
	 *
	 * @var bool
	 */
	public $logTooBig = false;
	/**
	 * Size of the log file
	 *
	 * @var int
	 */
	public $logSize = 0;

	/**
	 * The main page of the log viewer. It allows you to select a profile to display. When you do it displays the IFRAME
	 * with the actual log content and the button to download the raw log file.
	 *
	 * @return  void
	 */
	public function onBeforeMain()
	{
		// Get a list of log names
		/** @var Log $model */
		$model      = $this->getModel();
		$this->logs = $model->getLogOptions();

		$filename = $model->getState('filename', '', 'cmd');

		if (empty($filename))
		{
			$filename = null;
		}

		$this->filename = $filename;

		// Let's check if the file is too big to display
		if ($this->filename)
		{

			try
			{
				$file = $model->getLogPath();
				if (@file_exists($file))
				{
					$this->logSize   = filesize($file);
					$this->logTooBig = ($this->logSize >= self::bigLogSize);
				}
			}
			catch (Exception $e)
			{
				$this->logSize   = 0;
				$this->logTooBig = false;
			}
		}

		if ($this->logTooBig)
		{
			$src = 'index.php?option=com_ats&view=Log&task=inlineRaw&filename=' . urlencode($this->filename) . '&tmpl=component';
			$js  = <<<JS

;// Prevent broken 3PD Javascript from causing errors

akeeba.Loader.add('akeeba.System', function() {
   akeeba.System.addEventListener('showlog', function () {
       var iFrameHolder = document.getElementById('iframe-holder');
		iFrameHolder.style.display = 'block';
		iFrameHolder.insertAdjacentHTML('beforeend', '<iframe width="99%" src="$src" height="400px"/>');
		this.parentNode.style.display = 'none';
   });
});
JS;
			$this->addJavascriptInline($js);
		}
	}

}