<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\View\SchedulingInfo;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Model\SchedulingInfo;
use FOF40\View\DataView\Html as BaseView;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;

class Html extends BaseView
{
	/**
	 * Task scheduling information
	 *
	 * @var   object|null
	 * @since 3.2.0
	 */
	public $cronInfo = null;

	/**
	 * ATS CRON plugin information
	 *
	 * @var   array|null
	 * @since 3.2.0
	 */
	public $plugins = null;

	/**
	 * Do I have a configured Secret Word for front-end CRON URLs?
	 *
	 * @var   bool
	 * @since 3.2.0
	 */
	public $hasSecretWord = false;

	/**
	 * The proposed Secret Word for front-end CRON URLs
	 *
	 * @var   string
	 * @since 3.2.0
	 */
	public $newSecretWord = '';

	/**
	 * Currently selected command
	 *
	 * @var   string
	 * @since 3.2.0
	 */
	public $selectedCRONCommand;

	/**
	 * Help text for the currently selected command
	 *
	 * @var   string
	 * @since 3.2.0
	 */
	public $commandHelpText = '';

	/**
	 * Short description of the currently selected command
	 *
	 * @var   string
	 * @since 3.2.0
	 */
	public $commandDescription = '';

	/**
	 * Display the Scheduling Information page
	 *
	 * @return  void
	 *
	 * @since   3.2.0
	 */
	protected function onBeforeMain()
	{
		/** @var SchedulingInfo $model */
		$model               = $this->getModel();
		$this->cronInfo      = $model->getCRONInfo();
		$this->plugins       = $model->getAtsCronPlugins();
		$this->hasSecretWord = $model->hasSecretWord();

		if (!$this->hasSecretWord)
		{
			$this->newSecretWord = $this->container->platform->getSessionVar('newSecretWord', '', 'ats.cron');
		}

		$this->selectedCRONCommand = $model->getSelectedCRONCommand();
		$allCommands               = $model->getActiveCRONCommands();

		if ($this->selectedCRONCommand == 'commandName')
		{
			$this->commandHelpText    = Text::_('COM_ATS_SCHEDULINGINFO_LBL_COMMANDNAMEGENERIC_DESC');
			$this->commandDescription = Text::_('COM_ATS_SCHEDULINGINFO_LBL_COMMANDNAMEGENERIC_DESC_SHORT');
		}
		else
		{
			$this->commandHelpText    = Text::_($allCommands[$this->selectedCRONCommand]['description']);
			$this->commandDescription = Text::_($allCommands[$this->selectedCRONCommand]['label']);
		}
	}

	/**
	 * Return the JHtml options for the CRON command drop-down list
	 *
	 * @return  array
	 *
	 * @since   3.2.0
	 */
	public function getCRONCommandOptions()
	{
		/** @var SchedulingInfo $model */
		$model = $this->getModel();

		$options = [
			HTMLHelper::_('select.option', 'commandName', 'COM_ATS_SCHEDULINGINFO_LBL_COMMANDNAMEGENERIC_TITLE', [
				'option.label' => 'COM_ATS_SCHEDULINGINFO_LBL_COMMANDNAMEGENERIC_DESC',
			]),
		];

		foreach ($model->getActiveCRONCommands() as $info)
		{
			$options[] = HTMLHelper::_('select.option', $info['command'],
				$info['label'],
				['option.label' => $info['description']]);
		}

		return $options;
	}
}