<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\View\Tickets;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Akeeba\TicketSystem\Admin\Helper\Subscriptions;
use Joomla\CMS\Language\Text;

/**
 * Class Html
 *
 * @property    \Akeeba\TicketSystem\Admin\Model\Tickets    $item
 *
 * @package Akeeba\TicketSystem\Admin\View\Tickets
 */
class Html extends \FOF40\View\DataView\Html
{
    public $cache            = [];
    
    public $hasSubscriptions = false;

    public $showuserinfo     = false;

    public $activesubs       = [];

    public $inactivesubs     = [];

    public $isManager        = false;

	/** @var array	Do we have any custom fields to show? */
    public $customFields	 = [];

    /** @var array User Tags */
    public $userTags			 = [];

    protected function onBeforeBrowse()
    {
	    $container = $this->container;
    	$container->template->addJS('media://com_ats/js/Tickets.min.js', true, false, $container->mediaVersion);
    	$container->template->addJS('media://com_ats/js/Buckets.min.js', true, false, $container->mediaVersion);

    	Text::script('JLIB_HTML_PLEASE_MAKE_A_SELECTION_FROM_THE_LIST');

        // Let's force eager loading on joomla_categories and Joomla Users relationship
        /** @var \Akeeba\TicketSystem\Admin\Model\Tickets $model */
        $model = $this->getModel();
        $model->with(['joomla_category', 'assigned']);

        parent::onBeforeBrowse();
    }

    protected function onBeforeEdit()
    {
        parent::onBeforeEdit();

	    $container = $this->container;
	    $container->template->addJS('media://com_ats/js/Tickets.min.js', true, false, $container->mediaVersion);

        $this->showuserinfo = true;

        // Am I a full manager or I can simply view/edit the ticket?
        $this->isManager = Permissions::isManager($this->item->catid);

        // Do we have a subscriptions component?
        $this->hasSubscriptions = Subscriptions::hasSubscriptionsComponent();

        if($this->hasSubscriptions)
        {
            $user = Permissions::getUser($this->item->created_by);
            $subs = Subscriptions::getSubscriptionsList($user);

            $this->activesubs   = $subs->active;
            $this->inactivesubs = $subs->inactive;
        }

	    // Push the Joomla user model into the view. In this way we can always reference the same
	    // object (and cache its data) instead of keep creating it and running extra queries
	    $juserModel = $this->container->factory->model('JoomlaUsers');
	    $this->setModel('JoomlaUsers', $juserModel);

	    $this->customFields = $this->getCustomFields();
		$this->userTags		= $this->getUserTags();
    }

    protected function getCustomFields()
	{
		if(!$this->item->ats_ticket_id)
		{
			return [];
		}

		// I use the array + array syntax so empty values won't replace valid ones
		$args = $this->item->getData() + $this->cache;

		$this->container->platform->importPlugin('ats');
		$jResponse = $this->container->platform->runPlugins('onTicketFormRenderPerCatFields', array($args));

		if (!is_array($jResponse) || empty($jResponse))
		{
			return [];
		}

		// Custom field data is always in the first element (ie Geolocation plugin will trigger but will return empty data)
		$customFields = $jResponse[0];

		if(!is_array($customFields) || empty($customFields))
		{
			return [];
		}

		return $customFields;
	}

	protected function getUserTags()
	{
		static $tags = null;

		if (!is_null($tags))
		{
			return $tags;
		}

		$container = $this->getContainer();
		$tags      = [];

		if(!$this->item->created_by)
		{
			return $tags;
		}

		// First fetch the tags from the legacy storage
		// TODO This will be removed in future versions when we completed the migration of the tags
		/** @var \Akeeba\TicketSystem\Admin\Model\UserTags $usertags */
		$usertags = $container->factory->model('UserTags')->tmpInstance();
		$tags     = $usertags->loadTagsByUser($this->item->created_by);

		// Then merge them with the new way
		/** @var \Akeeba\TicketSystem\Admin\Model\JoomlaUsers $joomlaModel */
		$joomlaModel = $this->getModel('JoomlaUsers');
		$joomlaModel->find($this->item->created_by);

		/** @var \FOF40\Model\DataModel\Collection $collection */
		$collection = $joomlaModel->atstags;
		$tags = array_merge($tags, $collection->modelKeys());
		$tags = array_unique($tags);

		return $tags;
	}
}
