<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Akeeba\TicketSystem\Admin\Helper\Select;
use FOF40\Html\FEFHelper\BrowseView;
use Joomla\CMS\Language\Text;

?>
@extends('any:lib_fof40/Common/browse')

@section('browse-filters')
    <div class="akeeba-filter-element akeeba-form-group">
        @searchfilter('title', 'title', 'COM_ATS_COMMON_TITLE')
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        {{ Select::runManagerActions('run_after_manager', $this->getModel()->getState('run_after_manager'), ['class' => 'atsCommonEventsOnChangeSubmit']) }}
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        {{ BrowseView::publishedFilter('enabled', 'JENABLED') }}
    </div>
@stop

@section('browse-table-header')
    <tr>
        <td width="8%">
            @sortgrid('ordering', '<i class="icon-menu-2"></i>')
        </td>
        <th width="20px">
            @jhtml('FEFHelp.browse.checkall')
        </th>
        <th>
            @sortgrid('title', 'COM_ATS_COMMON_TITLE')
        </th>
        <th>
            @lang('COM_ATS_SUBMENU_CATEGORIES')
        </th>
        <th width="10%">
            @sortgrid('run_after_manager', 'COM_ATS_AUTOREPLIES_RUN_AFTER_MANAGER')
        </th>
        <th width="8%">
            @sortgrid('num_posts', 'COM_ATS_AUTOREPLIES_NUM_POSTS')
        </th>
        <th width="8%">
            @sortgrid('min_after', 'COM_ATS_AUTOREPLIES_MIN_AFTER')
        </th>
        <th width="8%">
            @sortgrid('keywords', 'COM_ATS_AUTOREPLIES_KEYWORDS')
        </th>
        <th width="8%">
            @sortgrid('attachment', 'COM_ATS_TICKETS_HEADING_ATTACHMENT')
        </th>
        <th width="8%">
            @sortgrid('enabled', 'JENABLED')
        </th>
    </tr>
@stop

@section('browse-table-body-withrecords')
<?php
	/** @var \Akeeba\TicketSystem\Admin\Model\AutoReplies $row */
	$i = 0;
	$enabled = Permissions::getUser()->authorise('core.edit.state', 'com_ats');
	$categories = Select::getCategoriesOptions();

	foreach($this->items as $row):
        $reply_cats = array();
        $keywords   = array();

        if($row->keywords_title)
        {
	        $keywords[] = '<em>' . Text::_('COM_ATS_AUTOREPLIES_KEYWORDS_TITLE') . '</em>';
        }

        if($row->keywords_text)
        {
	        $keywords[] = '<em>' . Text::_('COM_ATS_AUTOREPLIES_KEYWORDS_TEXT') . '</em>';
        }

        $keywords = implode('<br/>', $keywords);

        if (isset($row->params['categories']))
        {
			foreach ($row->params['categories'] as $cat)
			{
                $reply_cats[] = BrowseView::getOptionName($cat, $categories);
			}
        }

        $reply_cats = implode('<br/>', $reply_cats);
    ?>
        <tr>
            <td>
                @jhtml('FEFHelp.browse.order', 'ordering', $row->ordering)
            </td>
            <td>
                @jhtml('FEFHelp.browse.id', ++$i, $row->getId())
            </td>
            <td>
                <a href="@route(\FOF40\Html\FEFHelper\BrowseView::parseFieldTags('index.php?option=com_ats&view=AutoReply&task=edit&id=[ITEM:ID]', $row))">
                    {{{ $row->title }}}
                </a>
            </td>
            <td>
                {{ $reply_cats }}
            </td>
            <td>{{ BrowseView::getOptionName($row->run_after_manager, Select::runManagerActions('', '', [], true)) }}</td>
            <td>{{{ $row->num_posts  }}}</td>
            <td>{{{ $row->min_after  }}}</td>
            <td>{{ $keywords }}</td>
            <td>{{ BrowseView::getOptionName($row->attachment, Select::autoRepliesAttachment('', '', [], true)) }}</td>
            <td>
                @jhtml('FEFHelp.browse.published', $row->enabled, $i, '', $enabled)
            </td>
        </tr>
    <?php endforeach; ?>
@stop