<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;

/** @var FOF40\View\DataView\Html $this */

$tickets = $this->input->get('ats_ticket_id', [], 'array');
$tickets = array_unique($tickets);

// Add script options to the document. THis is used by Buckets.js.
$platform = $this->container->platform;
$platform->addScriptOptions('com_ats.Bucket.ticketIDs', $tickets);
$platform->addScriptOptions('com_ats.Bucket.ajaxURL', 'index.php?option=com_ats&view=Buckets&task=addtickets&format=json');

// Server-side check to ensure that I have some tickets to add to a bucket
if(!$tickets)
{
	Factory::getApplication()->enqueueMessage(Text::_('COM_ATS_BUCKETS_NO_TICKET_SELECTED'), 'notice');

	return;
}
?>

@extends('admin:com_ats/Buckets/default')

@section('browse-hidden-fields')
    <input type="hidden" name="layout" value="choose" />
    <input type="hidden" name="tmpl" value="component" />

    @foreach ($tickets as $ticket)
        <input type="hidden" name="ats_ticket_id[]" value="{{{  $ticket }}}" />
    @endforeach
@stop

@section('browse-table-body-withrecords')
	<?php
	$i = 0;
	/** @var \Akeeba\TicketSystem\Admin\Model\Buckets $row */
	?>
    @foreach($this->items as $row)
    <tr>
        <td>
            @jhtml('FEFHelp.browse.id', ++$i, $row->getId())
        </td>
        <td>
            <a href="#" class="atsBucketSelectLink" data-bucketid="{{ $row->getId() }}">
                {{{ $row->title }}}
            </a>
        </td>
        <td>
            {{ \FOF40\Html\FEFHelper\BrowseView::getOptionName($row->status, \Akeeba\TicketSystem\Admin\Helper\Select::getTicketStatus()) }}
        </td>
        <td>
            @jhtml('FEFHelp.browse.published', $row->enabled, $i, '', false)
        </td>
    </tr>
	@endforeach
@stop