<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

/**
 * Assign To Manager drop-down list
 * Use it $this->loadAnyTemplate('admin:com_ats/Common/ManagerAssignDropdown', $params)
 *
 * $params is an array defining the following keys (they are expanded into local scope vars automatically):
 *
 * @var Tickets                  $item     The current row
 * @var string|null              $selected The **full name** of the assigned manager
 *
 * Variables made automatically available to us by FOF:
 *
 * @var \FOF40\View\DataView\Raw $this
 */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Akeeba\TicketSystem\Admin\Model\Tickets;
use Joomla\CMS\Language\Text;

$container  = $item->getContainer();
$category   = $item->catid;
$myId       = Permissions::getUser()->id;
$managers   = Permissions::getManagers($category);
$color      = 'dark';
$me         = isset($managers[$myId]) ? $managers[$myId]->name : '';
$unassigned = Text::_('COM_ATS_TICKETS_UNASSIGNED');

switch ($selected)
{
	case $unassigned:
		$color = 'grey';
		break;

	case $me:
		$color = 'teal';
		break;
}

?>
<nav class="akeeba-dropdown">
    <button class="akeeba-btn--small--{{ $color }}">{{ $selected }}</button>
    <section>
        <a href="#" data-userid="{{ $myId }}" data-ticketid="{{ $item->getId() }}">
            <span class="akeeba-label--teal"><span class="akion-flag"></span></span>
            @lang('COM_ATS_TICKET_ASSIGN_TOME')
        </a>
        <a href="#" data-userid="0" data-ticketid="{{ $item->getId() }}">
            <span class="akeeba-label--red"><span class="akion-fireball"></span></span>
            @lang('COM_ATS_TICKET_UNASSIGN')
        </a>
        @foreach ($managers as $manager)
        <a href="#" data-userid="{{ $manager->id }}" data-ticketid="{{ $item->getId() }}">
            {{{ $manager->name }}}
        </a>
        @endforeach
    </section>
</nav>