<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Format;
use Akeeba\TicketSystem\Admin\Helper\Html;
use FOF40\Date\Date;
use Joomla\CMS\Language\Text;
use Joomla\CMS\User\User;

$createdOn = Format::date2($ticket->created_on, '', true);
$createdBy = User::getInstance($ticket->created_by)->username;

$modifiedOn = new Date($ticket->modified_on);

if($modifiedOn->toUnix() > 90000)
{
    $lastOn = Format::date2($ticket->modified_on, '', true);
    $lastBy = User::getInstance($ticket->modified_by)->username;
}
else
{
    $lastOn = $createdOn;
    $lastBy = $createdBy;
}

$icon 		 = $ticket->public ? 'icon-eye-open' : 'icon-eye-close';
$assigned_to = $ticket->assigned_to ? $ticket->getUser($ticket->assigned_to)->name : Text::_('COM_ATS_TICKETS_UNASSIGNED');
?>
<tr id="ats-ticket-<?php echo $ticket->ats_ticket_id ?>">
    <td>
        @include('admin:com_ats/Common/TicketPriority', ['item' => $ticket])
    </td>
    <td class="badges">
        <span class="<?php echo $icon?> icon-white ats-visibility hasTooltip ak-badge"></span>
    </td>
    <td>
        <h4>
			<?php if(ATS_PRO):?>
            <span class="pull-right badge assigned_to <?php echo $ticket->assigned_to ? 'badge-info': ''?>" style="margin-right:5px">
                                            <?php echo $assigned_to?>
                                        </span>
			<?php endif;?>
            <a href="index.php?option=com_ats&view=Ticket&id=<?php echo $ticket->ats_ticket_id ?>">
                #<?php echo $ticket->ats_ticket_id ?>:
				<?php echo $this->escape($ticket->title) ?>
            </a>
            <div class="clearfix"></div>
        </h4>

        <div>
            <span class="small pull-right">
                @sprintf('COM_ATS_TICKETS_MSG_LASTPOST', $lastBy, $lastOn)
            </span>
            <span class="small pull-left">
                @sprintf('COM_ATS_TICKETS_MSG_CREATED', $createdOn, $createdBy)
            </span>
        </div>
    </td>
    <td>
        @include('admin:com_ats/Common/TicketStatus', ['item' => $ticket, 'create_span' => true])
    </td>
</tr>