<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

/**
 * Ticket Status display field
 * Use it $this->loadAnyTemplate('admin:com_ats/Common/TicketStatus', $params)
 *
 * $params is an array defining the following keys (they are expanded into local scope vars automatically):
 *
 * @var Tickets $item        The current row
 * @var bool    $create_span Should I wrap the output in a span?
 * @var string  $add_class   Additional HTML classes to add to the span (when $create_span = true)
 *
 * Variables made automatically available to us by FOF:
 *
 * @var \FOF40\View\DataView\Raw                 $this
 */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Select;
use Akeeba\TicketSystem\Admin\Model\Tickets;
use Joomla\CMS\Language\Text;

$standard = ['O', 'P', 'C'];
$custom   = Select::getCustomTicketStatuses();

// Sanity check
if (!in_array($item->status, $standard) && !isset($custom[$item->status]))
{
	return;
}

if (in_array($item->status, $standard))
{
	$text = Text::_('COM_ATS_TICKETS_STATUS_' . $item->status);
}
elseif (isset($custom[$item->status]))
{
	$text = $custom[$item->status];
}

switch ($item->status)
{
	case 'O':
		$class = 'akeeba-label--red ats-status-open';

		break;
	case 'C':
		$class = 'akeeba-label--green ats-status-close';

		break;
	case 'P':
		$class = 'akeeba-label--orange ats-status-pending';

		break;
	default:
		$class = 'akeeba-label--orange ats-status-' . $item->status;

		break;
}
?>
@if ($create_span ?? false)
    <span class="ats-status {{ $class }} {{ $add_class ?? '' }}">{{ $text }}</span>
@else
    {{ $text }}
@endif