<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

/**
 * Ticket Status Change drop-down list
 * Use it $this->loadAnyTemplate('admin:com_ats/Common/TicketStatusDropdown', $params)
 *
 * $params is an array defining the following keys (they are expanded into local scope vars automatically):
 *
 * @var Tickets                  $item The current row
 *
 * Variables made automatically available to us by FOF:
 *
 * @var \FOF40\View\DataView\Raw $this
 */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Select;
use Akeeba\TicketSystem\Admin\Model\Tickets;
use Joomla\CMS\Language\Text;

$selected = $item->status;

/**
 * The statuses are arranged as Open, Pending, custom statuses, Closed. The reason is that internally the custom
 * statuses are treated as Pending.
 */
$statuses = [
	'O' => Text::_('COM_ATS_TICKETS_STATUS_O'),
	'P' => Text::_('COM_ATS_TICKETS_STATUS_P'),
];

// Can't use array_merge since if custom status IDs are not sequential, they will end up messed up (ie 1,3,4 will become 1,2,3)
foreach (Select::getCustomTicketStatuses() as $custom_id => $custom_status)
{
	$statuses[$custom_id] = $custom_status;
}

$statuses['C'] = Text::_('COM_ATS_TICKETS_STATUS_C');

$text = $statuses[$selected];

switch ($selected)
{
	case 'O':
		$status_class = 'red';
		break;
	case 'P':
		$status_class = 'orange';
		break;
	case 'C':
		$status_class = 'green';
		break;
	default:
		$status_class = 'grey';
		break;
}

?>
<nav class="akeeba-dropdown">
    <button class="akeeba-btn--small--{{ $status_class }}">{{ $text }}</button>
    <section>
    @foreach ($statuses as $value => $text)
        <a href="#" data-status="{{ $value }}" data-ticketid="{{ $item->getId() }}">
            @if ($value === 'O')
                <span class="akeeba-label--red">{{ $text }}</span>
            @elseif ($value === 'P')
                <span class="akeeba-label--orange">{{ $text }}</span>
            @elseif ($value === 'C')
                <span class="akeeba-label--green">{{ $text }}</span>
            @else
                <span class="akeeba-label--grey">{{ $text }}</span>
            @endif
        </a>
    @endforeach
    </section>
</nav>