<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') or die;

use FOF40\Date\Date;

/** @var  \Akeeba\Backup\Admin\View\Log\Html $this */
/** @var \Akeeba\TicketSystem\Admin\Model\Log $model */

$model = $this->getModel();

?>
<pre>
<?php
	try
	{
		$filePath = $model->getLogPath();
		$filename = basename($filePath);
	}
	catch (RuntimeException $e)
	{
		echo $e->getMessage();

		return;
	}

	if (!file_exists($filePath))
	{
		echo "Log file $filename is empty or does not exist.";

		return;
	}

	// Try to open our file for reading
	$fp = @fopen($filePath, 'r');

	if ($fp === false)
	{
		echo "ERROR: Cannot open $filename for reading.\r\n";

		return;
	}

	// All right. Let's start the output!
	echo "WARNING: Do not copy and paste lines from this file!\r\n";
	echo "You are supposed to ZIP and attach it in your support forum post.\r\n";
	echo "\r\n";
	echo "Log filename: $filename\r\n";
	echo "\r\n";
	echo "--- START OF LOG --\r\n";

	// Process each and every log line.
	while (!feof($fp))
	{
		$line = @fgets($fp);

		if ($line === false)
		{
			break;
		}

		$line = trim($line);

		// Ignore comments
		if (substr($line, 0, 1) == '#')
		{
			continue;
		}

		// Ignore PHP lines
		if (substr($line, 0, 5) == '<?php')
		{
			continue;
		}

		// Empty lines are also output as a blank line
		if (empty($line))
		{
			echo "\r\n";

			continue;
		}

		/**
		 * A log line looks like this
		 *
		 * 2020-02-10T11:19:39+00:00    DEBUG -    ats.cron    Starting the CRON job from CLI
		 *
		 * Split it by tabs into three parts: date, level/context and message
		 */
		$parts = explode("\t", $line, 4);

		// If there are fewer parts I have no idea what this line is, skip it over
		if (count($parts) != 4)
		{
			continue;
		}

		// Get the formatted date
		try
		{
			$date          = new Date($parts[0]);
			$formattedDate = $date->format('Y-m-d H:i:s e', true, false);
		}
		catch (\Exception $e)
		{
			continue;
		}

		// Get the log level
		$contextParts = explode(' ', $parts[1], 2);
		$logLevel     = $contextParts[0];

		/**
		 * Echo the formatted line.
		 *
		 * Example:
		 * 2020-02-10 13:19:39 +02:00 | DEBUG     |  Starting the CRON job from CLI
		 */
		switch (strtoupper($logLevel))
		{
			case "ERROR":
			case "CRITICAL":
			case "ALERT":
				$fmtString = "style=\"color: #E2363C; font-weight: bold;\"";
				break;
			case "NOTICE":
			case "WARNING":
				$fmtString = "style=\"color: #F0AD4E; font-weight: bold;\"";
				break;
			case "INFO":
				$fmtString = "style=\"color: #40B5B8;\"";
				break;
			case "DEBUG":
				$fmtString = "style=\"color: #514F50;\"";
				break;
			default:
				$fmtString = '';
				break;
		}

		echo sprintf("<span %s>%-26s | %-9s | %s</span>\r\n", $fmtString, $formattedDate, $logLevel, $parts[3]);
	}

	// Finally, close the log file.
	@fclose($fp);

	// That's the end of our log. Thank you for flying with us and see you soon!
	echo "--- END OF LOG ---\r\n";
	?>
</pre>
