<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var \Akeeba\TicketSystem\Admin\Model\ManagerNotes $item */
/** @var FOF40\View\DataView\Html $this */

use Akeeba\TicketSystem\Admin\Helper\Bbcode;
use Akeeba\TicketSystem\Admin\Helper\Format;
use Akeeba\TicketSystem\Admin\Helper\Html;
use Akeeba\TicketSystem\Admin\Helper\Permissions;

$platform  = $this->container->platform;
$postUser  = Html::getPostUser($item->created_by);
$user      = Permissions::getUser();

// Get the return URL to point back to ourselves
$permalink = JUri::getInstance();
$permalink->setFragment('mn'.$item->ats_managernote_id);

\Joomla\CMS\Language\Text::script('COM_ATS_POSTS_MSG_DELETEPROMPT');
?>
<div class="ats-post akeeba-panel--default ats-post-status-<?php echo $item->enabled ? 'published' : 'unpublished' ?>" id="mn{{{ $item->ats_managernote_id }}}">
	<header class="ats-post-header akeeba-block-header">
		<span class="ats-post-header-date">
			<a href="{{{ $permalink }}}">
				{{{ $postUser->name }}} ({{{ $postUser->username }}}) &bull; {{{ Format::date($item->created_on) }}}
			</a>
		</span>
	</header>
	<div class="ats-post-body">
		<div class="ats-post-content">
			<div class="ats-post-content-html">
				<?php
                    if(!$item->note_html)
                    {
                        echo Bbcode::parseBBCode($item->note);
                    }
				    else
                    {
                        echo $item->note_html;
                    }
                ?>
			</div>
			<div class="ats-post-content-signature">
				<?php echo nl2br(Html::getSignature($postUser)) ?>
			</div>
		</div>
	</div>
	<div class="ats-post-footer">
		@if(!empty($item->modified_on) && ($item->modified_on != '0000-00-00 00:00:00') && ($item->modified_on != $this->getContainer()->db->getNullDate()))
		<div class="ats-post-edits">
			@sprintf('COM_ATS_TICKETS_MSG_EDITEDBYON', Permissions::getUser($item->modified_by)->username, Format::date($item->modified_on) ) ?>
		</div>
		@endif
		<div class="ats-post-buttons">
            @if($item->enabled)
			<a class="akeeba-btn--red-small" href="index.php?option=com_ats&view=ManagerNotes&task=unpublish&id=<?php echo $item->ats_managernote_id ?>&returnurl=<?php echo $returnURL ?>&@token=1">
				<span class="akion-locked"></span>
				@lang('COM_ATS_COMMON_UNPUBLISH')
			</a>
            @else
			<a class="akeeba-btn--green-small" href="index.php?option=com_ats&view=ManagerNotes&task=publish&id=<?php echo $item->ats_managernote_id ?>&returnurl=<?php echo $returnURL ?>&@token=1">
				<span class="akion-unlocked"></span>
				@lang('COM_ATS_COMMON_PUBLISH')
			</a>
            @endif

			@if($user->authorise('core.manage','com_ats') || $user->authorise('core.edit','com_ats') || ($user->authorise('core.edit.own','com_ats') && ($user->id == $item->id)) )
			<a class="akeeba-btn--small" href="index.php?option=com_ats&view=ManagerNotes&task=edit&id=<?php echo $item->ats_managernote_id ?>&returnurl=<?php echo $returnURL ?>&@token=1">
				<span class="akion-edit"></span>
				@lang('COM_ATS_COMMON_EDIT')
			</a>
			@endif

			@if($user->authorise('core.delete','com_ats'))
			<a class="akeeba-btn--small-red atsCommonEventsOnClickConfirm"
			   href="index.php?option=com_ats&view=ManagerNotes&task=remove&id=<?php echo $item->ats_managernote_id ?>&returnurl=<?php echo $returnURL ?>&@token=1"
			   data-atsconfirmmessage="COM_ATS_POSTS_MSG_DELETEPROMPT">
				<span class="akion-trash-b"></span>
				@lang('COM_ATS_COMMON_DELETE')
			</a>
			@endif
		</div>
	</div>
</div>
