<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Credits;
use Akeeba\TicketSystem\Admin\Helper\Filter;
use Akeeba\TicketSystem\Admin\Helper\Format;
use Akeeba\TicketSystem\Admin\Helper\Html;
use Akeeba\TicketSystem\Admin\Helper\Permissions;

/** @var \FOF40\View\DataView\Html $this */
/** @var \Akeeba\TicketSystem\Admin\Model\Posts $item */

if (!isset($showCustomFields)) $showCustomFields = 0;
if (isset($firstPostId)) $showCustomFields = $item->getId() == $firstPostId;
if (!isset($attachmentErrors)) $attachmentErrors = array();

$postUser = Html::getPostUser($item->created_by);
$user = Permissions::getUser();
$isPostUserManager = Permissions::isManager($item->ticket->catid, $postUser->id);
$permalink = JRoute::_('index.php?option=com_ats&view=Ticket&id=' . $item->ats_ticket_id) . '#p' . $item->ats_post_id;
$withinEditingTime = Permissions::editGraceTime($item);

$isPrintView = $this->input->getCmd('layout') == 'print';

$customClasses = array_map(function ($groupName) {
	return 'ats-post-group-' . Filter::toSlug($groupName);
}, array_keys($postUser->groups));

$visibleAttachments = [];

// Attachments are Collections, not simply arrays
if (count($item->attachments))
{
	$visibleAttachments = $item->attachments->filter(function ($attachment) use ($item) {
		return !Permissions::attachmentPrivate($attachment, $this->isManager, $item->ticket->created_by)
				&& Permissions::attachmentVisible($attachment, $this->isManager, $item);
	});
}

\Joomla\CMS\Language\Text::script('COM_ATS_ATTACHMENTS_MSG_DELETEPROMPT');
\Joomla\CMS\Language\Text::script('COM_ATS_POSTS_MSG_DELETEPROMPT');
?>
@section('post-header-date')
	<span class="ats-post-header-date">
        @include('admin:com_ats/Common/TicketOrigin', ['item' => $item])
        @if($isPrintView)
			@atsFormatDateTZ($item->created_on, '', true)
		@else
			<a href="{{ $permalink }}">
            @atsFormatDateTZ($item->created_on, '', true)
        </a>
		@endif
    </span>
@overwrite

@section('post-header-timespent')
	@if ($item->timespent && $this->isManager)
		<span class="akeeba-label--grey">
            @sprintf('COM_ATS_POSTS_TIMESPENT_MSG', $item->timespent)
        </span>
	@endif
@overwrite

@section('post-header-fullname')
	@if ($this->isManager && $isPrintView)
		<span class="ats-post-header-fullname akeeba-pull-right">
            &bull;
            {{{ $postUser->name }}}
            ({{{ $postUser->username }}})
		</span>
	@endif
@overwrite

@section('post-attachment-errors')
	@if (!empty($attachmentErrors))
		<div class="ats-post-content-attachment-errors">
			<div class="akeeba-block--failure">
				<h4>
					@lang('COM_ATS_POSTS_ERR_ATTACHMENTERRORS')
				</h4>
				<ul>
					@foreach($attachmentErrors as $errorMessage)
						<li>
							{{{ $errorMessage }}}
						</li>
					@endforeach
				</ul>
			</div>
		</div>
	@endif
@overwrite

@section('post-content')
	<div class="ats-post-content-html">
		{{ $item->content_html }}
	</div>
@overwrite

@section('post-custom-fields')
	@if($showCustomFields && ATS_PRO)
		<?php $customFields = $item->ticket->loadCustomFields(); ?>
		@if ($customFields)
			<div class="ats-post-customfields">
				<p>
					<strong>@lang('COM_ATS_TITLE_CUSTOMFIELDS')</strong>
				</p>
				<table class="akeeba-table" width="100%">
					@foreach ($customFields as $field)
						<tr>
							<td><strong>{{ $field['label'] }}</strong></td>
							<td>{{ $field['value'] ? $field['value'] : '&nbsp;' }}</td>
						</tr>
					@endforeach
				</table>
			</div>
		@endif
	@endif
@overwrite

@section('post-attachments')
	@if(count($visibleAttachments))
		<div class="ats-post-attachments">
            <span class="ats-post-attachments-head">
                @lang('COM_ATS_TICKETS_HEADING_ATTACHMENT')
            </span>

			@foreach($item->attachments as $attachment)
			<div class="ats-post-attachment">
                <span class="ats-post-attachments-filename">
                    <a href="index.php?option=com_ats&view=Attachment&task=read&id={{ $attachment->ats_attachment_id }}&format=raw&@token(true)=1">
                        {{{ $attachment->original_filename }}}
                    </a>
                </span>

				@unless($isPrintView)
					@if($user->authorise('core.edit.state', 'com_ats') || $this->isManager || ($user->authorise('core.edit.own', 'com_ats') && ($user->id == $item->created_by)))
						&nbsp;
						@if($attachment->enabled)
							<a class="akeeba-btn--small atsTooltip" data-toggle="tooltip"
							   title="@lang('COM_ATS_COMMON_UNPUBLISH')"
							   href="index.php?option=com_ats&view=Attachment&task=unpublish&id={{ $attachment->ats_attachment_id }}&returnurl={{ $returnURL }}&@token(true)=1">
								<span class="akion-locked"></span>
							</a>
						@else
							<a class="akeeba-btn--small atsTooltip" data-toggle="tooltip"
							   title="@lang('COM_ATS_COMMON_PUBLISH')"
							   href="index.php?option=com_ats&view=Attachment&task=publish&id={{ $attachment->ats_attachment_id }}&returnurl={{ $returnURL }}&@token(true)=1">
								<span class="akion-unlocked"></span>
							</a>
						@endif
					@endif

					@if(Permissions::getUser()->authorise('core.delete', 'com_ats') || $this->isManager)
						&nbsp;
						<a class="akeeba-btn--red-small atsCommonEventsOnClickConfirm"
						   href="index.php?option=com_ats&view=Attachment&task=remove&id={{ $attachment->ats_attachment_id }}&returnurl={{ $returnURL }}&@token(true)=1"
						   data-atsconfirmmessage="COM_ATS_ATTACHMENTS_MSG_DELETEPROMPT">
							<span class="akion-trash-b"></span>
							@lang('COM_ATS_COMMON_DELETE')
						</a>
					@endif
				@endunless
			</div>
			@endforeach
		</div>
	@endif
@overwrite

@section('post-signature')
	<div class="ats-post-content-signature">
		{{ \Akeeba\TicketSystem\Admin\Helper\Html::getSignature($postUser) }}
	</div>
@overwrite

@section('post-footer-edited-notice')
	@if(!empty($item->modified_on) && ($item->modified_on != '0000-00-00 00:00:00') && ($item->modified_on != $this->getContainer()->db->getNullDate()))
		<div class="ats-post-edits">
			@sprintf('COM_ATS_TICKETS_MSG_EDITEDBYON', Permissions::getUser($item->modified_by)->username, \Akeeba\TicketSystem\Admin\Helper\Format::date($item->modified_on) )
		</div>
	@endif
@overwrite

@section('post-footer-unpublished-notice')
	@unless($item->enabled)
		<span class="ats-post-header-unpublished akeeba-label--red">
            @lang('COM_ATS_TICKETS_MSG_UNPUBLISHEDPOSTNOTICE')
        </span>
	@endunless
@overwrite

@section('post-footer-button-publish')
	@if($user->authorise('core.edit.state', 'com_ats') || $this->isManager )
		@if($item->enabled)
			<a class="akeeba-btn--orange-small atsTooltip" data-toggle="tooltip"
			   title="@lang('COM_ATS_COMMON_UNPUBLISH')"
			   href="index.php?option=com_ats&view=Post&task=unpublish&id={{ $item->ats_post_id }}&returnurl={{ $returnURL }}&@token(true)=1">
				<span class="akion-locked"></span>
			</a>
		@else
			<a class="akeeba-btn--small atsTooltip" data-toggle="tooltip"
			   title="@lang('COM_ATS_COMMON_PUBLISH')"
			   href="index.php?option=com_ats&view=Post&task=publish&id={{ $item->ats_post_id }}&returnurl={{ $returnURL }}&@token(true)=1">
				<span class="akion-unlocked"></span>
			</a>
		@endif
	@endif
@overwrite

@section('post-footer-button-edit')
	{{-- If I am a manager OR I can globally edit OR I am within the grace time OR I can edit my own and it's a post of mine, then show buttons --}}
	@if(
    $this->isManager ||
    $user->authorise('core.edit', 'com_ats') ||
    ($withinEditingTime) ||
    ($user->authorise('core.edit.own', 'com_ats') && ($user->id == $item->created_by))
    )
		<a class="akeeba-btn--small-ghost atsTooltip" data-toggle="tooltip"
		   title="@lang('COM_ATS_COMMON_EDIT')"
		   href="index.php?option=com_ats&view=Post&task=edit&id={{ $item->ats_post_id }}&returnurl={{ $returnURL }}&@token(true)=1">
			<span class="akion-edit"></span>
		</a>
	@endif
@overwrite

@section('post-footer-button-delete')
	@if(Permissions::getUser()->authorise('core.delete', 'com_ats') || $this->isManager)
		<a class="akeeba-btn--small-red atsTooltip atsCommonEventsOnClickConfirm"
		   data-toggle="tooltip"
		   title="@lang('COM_ATS_COMMON_DELETE')"
		   href="index.php?option=com_ats&view=Post&task=remove&id={{ $item->ats_post_id }}&returnurl={{ $returnURL }}&@token(true)=1"
		   data-atsconfirmmessage="COM_ATS_POSTS_MSG_DELETEPROMPT">
			<span class="akion-trash-b"></span>
		</a>
	@endif
@overwrite

@section('post-footer-button-credits')
	@if( ($this->isManager || $user->authorise('core.edit.state', 'com_ats')) && ATS_PRO )
		&nbsp;
		{{--
        Please note that if the category doesn't charge the user to post, the following statements always fails, so the
        "Charge credits" button is displayed, even if we won't charge anything ever! Should we change this behaviour?
        Should we display them only when the credit feature is on?
        --}}
		@if($creditsCharged = Credits::creditsCharged('post', $item->ats_ticket_id, $item->ats_post_id))
			<a href="index.php?option=com_ats&view=Post&task=creditsrefund&id={{ $item->ats_post_id }}&@token(true)=1&returnurl={{ $returnURL }}"
			   class="akeeba-btn--red-small atsTooltip" data-toggle="tooltip"
			   title="@sprintf('COM_ATS_POSTS_CREDITS_REFUND', $creditsCharged)">
				<span class="akion-minus-round"></span>
				{{ $creditsCharged }}
			</a>
		@else
			<a href="index.php?option=com_ats&view=Post&task=creditscharge&id={{ $item->ats_post_id }}&@token(true)=1&returnurl={{ $returnURL }}"
			   class="akeeba-btn--green-small atsTooltip" data-toggle="tooltip"
			   title="@lang('COM_ATS_POSTS_CREDITS_CHARGE')">
				<span class="akion-plus-round"></span>
			</a>
		@endif
	@endif
@overwrite

@include('admin:com_ats/Posts/threaded_user',[
    'user'        => $postUser,
    'isPrintView' => $isPrintView
])

{{-- Done defining post blocks, now let's assemble everything with what we have --}}

@section('post-body')
	<div class="ats-post-body">
		<div class="ats-post-content">
			@unless($isPrintView)
				@yield('post-attachment-errors')
			@endunless
			@yield('post-content')
			@yield('post-custom-fields')
			@yield('post-attachments')
			@yield('post-signature')
		</div>
	</div>
@overwrite

@section('post-footer')
	<div class="ats-post-footer">
		@yield('post-footer-edited-notice')
		@yield('post-footer-unpublished-notice')

		@unless($isPrintView)
			<div class="ats-post-buttons">
				@yield('post-footer-button-publish')
				@yield('post-footer-button-edit')
				@yield('post-footer-button-delete')
				@yield('post-footer-button-credits')
			</div>
		@endunless
	</div>
@overwrite

@section('post-userinfo')
	<div class="ats-post-userinfo">
		@yield('post-user-avatar')
		@if($this->isManager)
			<div class="ats-post-userinfo-name">
				{{{ $postUser->name }}}
			</div>
		@endif
		<div class="ats-post-userinfo-username">
			@yield('post-user-username')
			@yield('post-user-timespent')
		</div>
		@yield('post-user-badges')
		@yield('post-user-subscriptions')
		@yield('post-user-groups')
		@yield('post-user-tags')
	</div>
@overwrite

<div class="ats-post akeeba-panel--{{ $item->enabled ? ($isPostUserManager ? 'green' : 'default') : 'red' }} {{ implode(' ',$customClasses) }} ats-post-status-{{ $item->enabled ? 'published' : 'unpublished' }}"
	 id="p{{ $item->ats_post_id }}">
	<header class="ats-post-header akeeba-block-header">
		@yield('post-header-date')
		@yield('post-header-timespent')
		@yield('post-header-fullname')
	</header>

	@unless($isPrintView)
		<div class="ats-post-columns-container">
			@yield('post-userinfo')
			<div class="ats-post-body-container">
				@yield('post-body')
				@yield('post-footer')
			</div>
		</div>
	@else
		<div class="ats-post-body-container">
			@yield('post-body')
			@yield('post-footer')
		</div>
	@endunless
</div>
