<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

/** @var $this FOF40\View\DataView\Html */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Html;
use Akeeba\TicketSystem\Admin\Helper\Permissions;
use FOF40\Html\FEFHelper\BrowseView;
use Akeeba\TicketSystem\Admin\Helper\Select;
use Joomla\CMS\Language\Text;

?>
@extends('any:lib_fof40/Common/browse')

@section('browse-filters')
    <div class="akeeba-filter-element akeeba-form-group">
        @searchfilter('ats_ticket_id', 'ats_ticket_id', 'JGRID_HEADING_ID')
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        @searchfilter('username', 'username', 'COM_ATS_TICKETS_HEADING_USER')
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        @searchfilter('ass_username', 'ass_username', 'COM_ATS_TICKETS_ASSIGNED_TO')
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        @searchfilter('title', 'title', 'COM_ATS_TICKETS_HEADING_TITLE')
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        {{ Select::ticketstatuses($this->getModel()->getState('status'), 'status', ['class' => 'atsCommonEventsOnChangeSubmit'], 'filter_status') }}
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        {{ Select::publicstate($this->getModel()->getState('public'), 'public', ['class' => 'atsCommonEventsOnChangeSubmit']) }}
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        <select name="catid" class="input-medium atsCommonEventsOnChangeSubmit">
            <option value="">@lang('JOPTION_SELECT_CATEGORY')</option>
            @jhtml('select.options', JHtml::_('category.options', 'com_ats'), 'value', 'text', $this->getModel()->getState('catid',''))
        </select>
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        {{ BrowseView::publishedFilter('enabled', 'JENABLED') }}
    </div>
@stop

@section('browse-table-header')
    <tr>
        <th width="20px">
            @jhtml('FEFHelp.browse.checkall')
        </th>
        <th>
            @sortgrid('ats_ticket_id', 'JGRID_HEADING_ID')
        </th>
        <th>
            @sortgrid('created_by', 'COM_ATS_TICKETS_HEADING_USER')
        </th>
        <th>
            @sortgrid('created_on', 'COM_ATS_TICKETS_HEADING_CREATED')
            &bull;
            @sortgrid('modified_on', 'COM_ATS_TICKETS_HEADING_MODIFIED')
        </th>
        <th>
            @sortgrid('title', 'COM_ATS_COMMON_TITLE')
            &bull;
            @sortgrid('status', 'COM_ATS_TICKETS_HEADING_STATUS')
            &bull;
            @sortgrid('catid', 'JCATEGORY')
            @if(ATS_PRO)
                &bull;
                @sortgrid('timespent', 'COM_ATS_TICKETS_HEADING_TIMESPENT')
            @endif
        </th>
        <th>
            @sortgrid('enabled', 'JSTATUS')
        </th>
        <th>
            @sortgrid('public', 'COM_ATS_TICKETS_HEADING_PUBLIC')
        </th>

    </tr>
@stop

@section('browse-table-body-withrecords')
	<?php
	$i = 0;
	$user = Permissions::getUser();
	$enabled = $user->authorise('core.edit.state', 'com_ats');
	/** @var \Akeeba\TicketSystem\Admin\Model\Tickets $item */
	?>
    @foreach($this->items as $item)
	<?php
	$item->cat_link = JRoute::_('index.php?option=com_categories&extension=com_ats&task=edit&type=other&cid[]=' . $item->catid);
	$canEdit = $user->authorise('core.edit', 'com_ats.category.' . $item->catid);
	$canChange = $user->authorise('core.edit.state', 'com_ats.category.' . $item->catid);
	$assigned_class = $item->assigned_to ? 'akeeba-label--teal' : 'akeeba-label--grey';
	$assigned_to = $item->assigned_to ? $item->assigned->name : Text::_('COM_ATS_TICKETS_UNASSIGNED');
	?>
    <tr valign="top">
        <td>
            @jhtml('FEFHelp.browse.id', ++$i, $item->getId())
        </td>
        <td>
            @include('admin:com_ats/Common/TicketPriority', ['item' => $item])

            {{ $item->ats_ticket_id }}
        </td>
        <td>
            @include('any:lib_fof40/Common/user_show', ['item' => $item, 'field' => 'created_by', 'showLink' => false])
        </td>
        <td class="ats-nowrap">
            <strong>
                @jhtml('date',$item->created_on, Text::_('DATE_FORMAT_LC5'))
            </strong>

            @if((empty($item->modified_on)) || ($item->modified_on == '0000-00-00 00:00:00') || ($item->modified_on == $this->getContainer()->db->getNullDate()))
            @else
                <br/>
                @jhtml('date',$item->modified_on, Text::_('DATE_FORMAT_LC5'))
            @endif
        </td>
        <td>
			<?php
			$title = $this->escape($item->title);

			if ($canEdit)
			{
				$title = '<a href="' . JRoute::_('index.php?option=com_ats&view=Ticket&task=edit&id=' . (int) $item->ats_ticket_id) . '">' . $this->escape($item->title) . '</a>';
			}
			?>
            <div class="AKEEBA_MASTER_FORM_STYLING akeeba-form--inline ats-ticket-assign-status-controls">
                @if(ATS_PRO)
                    <div class="assignto">
                        @include('admin:com_ats/Common/ManagerAssignDropdown', ['item' => $item, 'selected' => $assigned_to])
                        <input type="hidden" class="ticket_id" value="{{ $item->ats_ticket_id }}" />
                    </div>
                @endif
                <div class="ticketstatus">
                    @include('admin:com_ats/Common/TicketStatusDropdown', ['item' => $item])
                </div>
            </div>
            <div class="ats-ticket-title-backend">
                {{ $title }}
            </div>

            @if(is_object($item->joomla_category))
                <div class="ats-ticket-category-container">
                    <span class="ats-ticket-category-label">
                    @lang('JCATEGORY'):
                    </span>
                    <span class="ats-ticket-category-name">
                        {{ $item->joomla_category->title }}
                    </span>
                </div>
            @endif

            @if(ATS_PRO && ($item->timespent > 0))
                <div class="ats-ticket-time-container">
                    <span class="ats-ticket-time-label">
                        @lang('COM_ATS_TICKETS_HEADING_TIMESPENT'):
                    </span>
                    <span class="ats-ticket-time-spent">
                        {{ sprintf('%.1f', $item->timespent) }}
                    </span>
                </div>
            @endif
        </td>
        <td>
            @jhtml('FEFHelp.browse.published', $item->enabled, $i, '', $enabled)
        </td>
        <td class="center public">
            @jhtml('jgrid.published', $item->public, $i, 'public_', $canChange)
        </td>

    </tr>
    @endforeach
@stop

@section('browse-hidden-fields')
    <input type="hidden" id="user" value="{{{ Permissions::getUser()->id }}}" />
@stop