<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var \Akeeba\TicketSystem\Admin\View\Tickets\Html $this */

$js = <<<JS

akeeba.Loader.add('akeeba.fef.tabs', function () {
    akeeba.fef.tabs();
});
JS;

$this->container->template->addJSInline($js);

/** @var \Akeeba\TicketSystem\Admin\Model\Tickets $item */
$item = $this->getItem();
?>

@extends('any:lib_fof40/Common/edit')

@section('edit-hidden-fields')
    <input type="hidden" name="ats_ticket_id" value="{{{ $item->ats_ticket_id }}}" />
@stop

@section('edit-form-body')
    <div class="akeeba-container--50-50">
        <div>
            @include('admin:com_ats/Tickets/form_general')
        </div>

        <div>
            @include('admin:com_ats/Tickets/form_userinfo')
            <h3>@lang('COM_ATS_TITLE_CUSTOMFIELDS')</h3>

            @include('site:com_ats/NewTickets/customfields', ['customFields' => $this->customFields])
        </div>
    </div>
@stop

@section('edit-page-bottom')
{{--// Load the post form only if we have a ticket (let's keep it simple)--}}
    @if($this->item->ats_ticket_id)
        <div class="akeeba-tabs">
            <label for="ats_ticket_backend_conversation" class="active">@lang('COM_ATS_TICKETS_LEGEND_CONVO')</label>
            <section id="ats_ticket_backend_conversation">
                <?php
                $posts = $this->item->posts;

                $this->items = $posts;
                echo $this->loadAnyTemplate('admin:com_ats/Posts/threaded');
                $this->items = null;
                ?>

                <div class="ats-clear"></div>

                @if($this->item->status != 'C')
                    <h3 class="ats-ticket-reply-header">@lang('COM_ATS_POSTS_HEADING_REPLYAREA')</h3>

                    {{-- // If the ticket is already assigned to another manager, warn the user --}}
                    @if($this->item->assigned_to && $this->item->assigned_to != \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser()->id)
                        <div class="akeeba-block--failure small">
                            @sprintf('COM_ATS_TICKET_ALREADY_ASSIGNED_WARN', \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser($this->item->assigned_to)->name)
                        </div>
                    @endif

                    @include('admin:com_ats/Posts/form')
                @endif
            </section>

        @if($this->isManager)
            <label for="ats_ticket_backend_notes">@lang('COM_ATS_TICKETS_LEGEND_MANAGERNOTES')</label>
            <section id="ats_ticket_backend_notes">
                <?php
                $notes = $this->item->manager_notes;

                $this->items = $notes;
                echo $this->loadAnyTemplate('admin:com_ats/ManagerNotes/threaded');
                $this->items = null;
                ?>

                <h3 class="ats-ticket-reply-header">@lang('COM_ATS_POSTS_HEADING_MANAGERNOTEAREA')</h3>

                @include('admin:com_ats/ManagerNotes/form')
            </section>
        @endif
        </div>
    @endif
@stop