<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Site\View\Buckets;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Akeeba\TicketSystem\Site\Model\Buckets;
use Akeeba\TicketSystem\Site\View\PageMetaAware;
use Joomla\CMS\Factory;
use Joomla\CMS\Pagination\Pagination;
use Joomla\CMS\Uri\Uri;

class Html extends \FOF40\View\DataView\Html
{
	use PageMetaAware;

	/**
	 * Partial URL for manager actions. It's missing the `&task=<something>` bit.
	 *
	 * @var   string
	 * @since 3.0.0
	 */
	public $adminActionURL;

	public $editorID;

	public $editorName;

	/**
	 * State of the "status" filter
	 *
	 * @var   string
	 * @since 3.0.0
	 */
	public $filterStatus;

	/**
	 * Is the current user a manager?
	 *
	 * @var bool
	 */
	public $isManager = false;

	/**
	 * The bucket we're displaying in the read task
	 *
	 * @var   Buckets
	 */
	public $item;

	/**
	 * Joomla! menu item ID
	 *
	 * @var   int
	 * @since 3.0.0
	 */
	public $itemID = 0;

	/**
	 * The list of buckets we're displaying in the browse task
	 *
	 * @var   Buckets[]
	 */
	public $items;

	/**
	 * Return URL, base64-encoded
	 *
	 * @var   string
	 * @since 3.0.0
	 */
	public $returnURLEncoded;

	/**
	 * Should I show a page heading inside the component's content?
	 *
	 * @var   bool
	 * @since 3.0.0
	 */
	public $showPageHeading;

	/**
	 * Should I show the replye area?
	 *
	 * @var   bool
	 * @since 3.0.0
	 */
	public $showReplyArea;

	/**
	 * Should I display separate tabs for the ticket list and reply area?
	 *
	 * @var   bool
	 * @since 3.0.0
	 */
	public $showTabs;

	/**
	 * Should I show the ticket list?
	 *
	 * @var   bool
	 * @since 3.0.0
	 */
	public $showTicketList;

	protected function onBeforeBrowse()
	{
		if ($this->task == 'choosebucket')
		{
			$this->setLayout('choose');

			// This is a choose view and I need to narrow down the list
			// I have to use a Tmp Instance of the model, so I won't mess up data of "standard view"
			// The only downside is that I have to manually pass every filter value :(
			/** @var Buckets $model */
			$model = $this->container->factory->model('Buckets')->tmpInstance();
			$model->status('O')
				->enabled(1)
				->limit($this->input->getInt('limit'))
				->limitstart($this->input->getInt('limitstart', 0))
				->filter_order($this->input->getCmd('filter_order', 'id'))
				->filter_order_Dir($this->input->getCmd('filter_order_Dir', 'DESC'));

			$this->lists = new \stdClass();

			// Display limits
			$defaultLimit = 20;

			$app = Factory::getApplication();

			if (method_exists($app, 'get'))
			{
				$defaultLimit = $app->get('list_limit');
			}

			$this->lists->order      = $model->getState('filter_order', 'id', 'cmd');
			$this->lists->order_Dir  = $model->getState('filter_order_Dir', 'DESC', 'cmd');
			$this->lists->limitStart = $model->getState('limitstart', 0, 'int');
			$this->lists->limit      = $model->getState('limit', $defaultLimit, 'int');

			// Assign data to the view
			$this->items     = $model->get();
			$this->itemCount = $model->count();

			// Pagination
			$this->pagination = new Pagination($this->itemCount, $this->lists->limitStart, $this->lists->limit);

			/** @var \JApplicationSite $app */
			$app              = Factory::getApplication();
			$params           = $app->getParams();
			$this->pageParams = $params;
		}
		else
		{
			parent::onBeforeBrowse();
		}

		$this->itemID          = $this->input->getInt('Itemid', 0);
		$this->filterStatus    = $this->getModel()->getState('status', '');
		$this->showPageHeading = $this->getPageParams()->get('show_page_heading', 1);
	}

	protected function onBeforeRead()
	{
		$container = $this->container;
		$container->template->addJS('media://com_ats/js/Tickets.min.js', true, false, $container->mediaVersion);

		parent::onBeforeRead();

		/** @var \JApplicationSite $app */
		$app              = Factory::getApplication();
		$params           = $app->getParams();
		$this->pageParams = $params;

		$this->returnURLEncoded = base64_encode(Uri::getInstance()->toString());
		$this->isManager        = Permissions::isManager();
		$this->itemID           = $this->input->getInt('Itemid', 0);
		$this->adminActionURL   = 'index.php?option=com_ats&view=Bucket&id=' . $this->item->ats_bucket_id . '&returnurl=' . $this->returnURLEncoded . '&Itemid=' . $this->itemID . '&' . $container->platform->getToken(true) . '=1';
		$this->showTicketList   = count($this->item->tickets) > 0;
		$this->showReplyArea    = $this->item->status != 'C' && count($this->item->tickets) > 0;
		$this->showTabs         = $this->isManager && $this->showReplyArea && $this->showTicketList;
		$this->editorName       = 'content_html';
		$this->editorID         = 'ats-content';

		// JavaScript required for the bucket view
		$this->addJavascriptFile('media://com_ats/js/Buckets.min.js', $container->mediaVersion, 'text/javascript', true);

		$this->setPageMeta();
	}

}
