<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Site\View\Latests;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Akeeba\TicketSystem\Site\Model\Tickets;
use Akeeba\TicketSystem\Site\View\PageMetaAware;
use Joomla\CMS\Language\Text;

class Html extends \FOF40\View\DataView\Html
{
	use PageMetaAware;

	public $filterCategory;

	public $filterStatus;

	/**
	 * Joomla! menu item ID
	 *
	 * @var   int
	 * @since 3.0.0
	 */
	public $itemID;

	/** @var Tickets[] */
	public $items;

	/** @var bool Is the current user a manager? */
	protected $isManager = false;

	protected function onBeforeBrowse()
	{
		$container = $this->container;
		$container->template->addJS('media://com_ats/js/Tickets.min.js', true, false, $container->mediaVersion);
		$container->template->addJS('media://com_ats/js/LatestOpen.min.js', true, false, $container->mediaVersion);

		/** @var Tickets $model */
		$model                = $this->getModel();
		$this->filterStatus   = $model->getState('status', 'O');
		$this->filterCategory = $model->getState('category', null);
		$allowedCategories    = Permissions::getManagerCategories();

		if (!empty($this->filterCategory) && !in_array($this->filterCategory, $allowedCategories))
		{
			$container->platform->raiseError(403, Text::_('JLIB_APPLICATION_ERROR_ACCESS_FORBIDDEN'));
		}

		// Apply custom filters for frontend
		$model->categories($allowedCategories)
			->enabled(1)
			->status($this->filterStatus)
			->filterNewest(1)
			->filter_order_Dir('ASC');

		parent::onBeforeBrowse();

		$this->itemID = $this->input->getInt('Itemid', 0);

		// Add filters to pagination output
		$this->pagination->setAdditionalUrlParam('status', $this->getModel()->getState('status', 'O'));

		if (!empty($this->filterCategory))
		{
			$this->pagination->setAdditionalUrlParam('category', $this->filterCategory);
		}

		$this->setPageMeta();
	}
}
