<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Site\View\Mies;

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Akeeba\TicketSystem\Site\Model\Tickets;
use Akeeba\TicketSystem\Site\View\PageMetaAware;

class Html extends \FOF40\View\DataView\Html
{
	use PageMetaAware;

	/**
	 * The username I am displaying tickets for. Only populated when I'm a manager and I display tickets for a different
	 * user than my own.
	 *
	 * @var   string
	 * @since 3.0.0
	 */
	public $displayedUsername;

	/**
	 * State of the "Category" filter
	 *
	 * @var   int
	 * @since 3.0.0
	 */
	public $filterCategory;

	/** @var bool Is the current user a manager? */
	public $isManager = false;

	/**
	 * Joomla! menu item ID
	 *
	 * @var   int
	 * @since 3.0.0
	 */
	public $itemID;

	/**
	 * Should I display a page heading in the component output?
	 *
	 * @var   bool
	 * @since 3.0.0
	 */
	public $showPageHeading;

	/**
	 * Time spent for supporting this user. Only populated when I'm a manager and I display tickets for a different user
	 * than my own.
	 *
	 * @var   int
	 * @since 3.0.0
	 */
	public $timeSpentPerUser;

	/**
	 * The user ID for which to display tickets
	 *
	 * @var   int
	 * @since 3.0.0
	 */
	public $userID;

	protected function onBeforeBrowse()
	{
		$container = $this->container;
		$container->template->addJS('media://com_ats/js/Tickets.min.js', true, false, $container->mediaVersion);

		/** @var Tickets $model */
		$model = $this->getModel();

		// Apply custom filters for frontend
		$currentUserID = Permissions::getUser()->id;
		$model->status_array('O,C,P,1,2,3,4,5,6,7,8,9')
			->enabled(1)
			->filterNewest(1)
			->filter_order_Dir('DESC')
			->created_by($currentUserID);

		// If I'm a manager I can display tickets of other users as well
		$this->isManager = Permissions::isManager();
		$this->userID    = $this->input->getInt('userid', 0);

		if ($this->userID == $currentUserID)
		{
			$this->userID = 0;
		}

		if ($this->isManager && $this->userID)
		{
			$model->created_by($this->userID);

			$this->timeSpentPerUser  = \Akeeba\TicketSystem\Admin\Helper\Html::getTimeSpentPerUser($this->userID);
			$this->displayedUsername = Permissions::getUser($this->userID)->username;
		}

		parent::onBeforeBrowse();

		$this->itemID          = $this->input->getInt('Itemid', 0);
		$this->filterCategory  = $this->getModel()->getState('category', 0);
		$this->showPageHeading = $this->getPageParams()->get('show_page_heading', 1);

		$this->setPageMeta();
	}
}
