<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var Akeeba\TicketSystem\Site\View\Buckets\Html $this */

/**
 * This view template lists all ticket buckets
 *
 * Variables coming from loadAnytemplate method
 *
 * $assignTickets	Should I display the "Add to bucket" button?
 * $hideLinks		Should I hide bucket link?
 */

// Prevent warnings with param variables
if (!isset($assignTickets)) $assignTickets = 0;
if (!isset($hideLinks)) $hideLinks = 0;
?>
@section('header-modules')
    @modules('ats-top')
    @modules('ats-buckets-top')
@show

@if($this->showPageHeading)
    <h1>@lang('COM_ATS_TITLE_BUCKETS')</h1>
@endif

<div class="ats-buttonbar">
    @if($assignTickets)
        <div style="float:left">
            <button id="addTickets"
                    class="akeeba-btn--primary akeeba-pull-left">@lang('COM_ATS_BUCKETS_ADD_TICKETS')</button>
            <div class="akeeba-pull-left" style="margin:5px">
                <img id="loading" style="display:none"
                     src="<?php echo $this->getContainer()->template->parsePath('media://com_ats/images/throbber.gif')?>"
                     alt="@lang('COM_ATS_NEWTICKET_INSTANTREPLY_LOADING')"
                />
                <div id="saveok" class="akeeba-pull-left" style="display:none;">
                    <i>@lang('COM_ATS_BUCKETS_TICKET_SAVE_OK')</i>
                </div>
                <div id="saveko" class="akeeba-pull-left" style="display:none">
                    <i>@lang('COM_ATS_BUCKETS_TICKET_SAVE_ERR')</i>
                </div>
            </div>
        </div>
    @else
        <div class="akeeba-pull-right">
            @atsTicketStatusSelect($this->filterStatus, 'filter-status', array('class' => 'form-control atsFilterStatusSelect'), 'filter-status')
        </div>
    @endif
</div>

<div class="ats-clear"></div>

@if(!count($this->items))
    @modules('ats-buckets-none-top')

    <p>@lang('COM_ATS_BUCKETS_MSG_NOBUCKETS')</p>

    @modules('ats-buckets-none-bottom')
@else
    <table class="akeeba-table--striped">
        <tbody>
        <?php $this->i = 0; ?>
        @foreach($this->items as $bucket)
            @include('site:com_ats/Buckets/default_bucket', array(
				'displayCbx' => $assignTickets,
				'hideLinks'  => $hideLinks,
				'bucket'     => $bucket
			))
        @endforeach
        </tbody>
    </table>

@endif

<form id="ats-pagination" name="atspagination"
      action="@route('index.php?option=com_ats&view=Buckets' . ($this->itemID != 0) ? '&Itemid=' . $this->itemID : '')"
      method="post">
    <input type="hidden" name="option" value="com_ats" />
    <input type="hidden" name="view" value="Buckets" />
    <input type="hidden" name="status" value="{{ $this->filterStatus }}" id="ats_filter_status" />
    @if($this->input->getCmd('tmpl'))
        <input type="hidden" name="tmpl" value="{{{ $this->input->getCmd('tmpl') }}}" />
    @endif
    <input type="hidden" name="task" value="{{{ $this->input->getCmd('task') }}}" />

    <div class="pagination">
        <p class="counter">
            {{ $this->pagination->getPagesCounter() }}
        </p>

        {{ $this->pagination->getPagesLinks() }}
    </div>

    @if($assignTickets)
        <input type="hidden" name="boxchecked" value="0" />
    @endif
</form>

@section('footer-modules')
    @modules('ats-buckets-bottom')
    @modules('ats-bottom')
@show
