<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

use FOF40\Date\Date;

/**
 * Displays a single bucket in a list of buckets.
 *
 * Variables coming from loadAnytemplate method
 *
 * $displayCbx	Should I display bucket checkbox?
 * $hideLinks	Should I hide bucket links?
 * $bucket      The bucket to display
 */

/** @var \Akeeba\TicketSystem\Site\Model\Buckets $bucket */
/** @var bool $displayCbx */
/** @var bool $hideLinks */

$displayModify = $bucket->modified_on && \FOF40\Date\Date::getInstance($bucket->modified_on)->toUnix() > 90000

?>
<tr>
    @if($displayCbx)
        <td style="vertical-align:middle;text-align:center">
            {{-- I have to remove any onclick event since there is no adminForm form... --}}
            {{ preg_replace('#onclick=".*?"#', '', \Joomla\CMS\HTML\HTMLHelper::_('grid.id', $this->i++, $bucket->ats_bucket_id)) }}
        </td>
    @endif

    <td class="badges" style="width: 30px; vertical-align: top;">
        @if(\Akeeba\TicketSystem\Admin\Helper\Permissions::getUser()->id == $bucket->created_by)
            <span class="ats-my-ticket akeeba-label--grey hasTooltip"
                  title="@lang('COM_ATS_CREATED_BY_ME')">
                <span class="akion-person" aria-hidden="true"></span>
            </span>
        @endif
    </td>

    <td>
        <h3 class="ats-bucket-title akeeba-pull-left">
            @if($hideLinks)
                #{{ $bucket->ats_bucket_id }} : {{{$bucket->title}}}
            @else
                <a href="@route('index.php?option=com_ats&view=Bucket&id='.$bucket->ats_bucket_id)">
                    #{{ $bucket->ats_bucket_id }} : {{{$bucket->title}}}
                </a>
            @endif
        </h3>
        <span class="akeeba-label--{{ ($bucket->status == 'C') ? 'green' : ($bucket->status == 'P' ? 'orange' : 'red') }} akeeba-pull-right">
			@lang('COM_ATS_BUCKETS_STATUS_'.strtoupper($bucket->status))
		</span>

        <div class="ats-clear"></div>

        <span class="small akeeba-pull-right">
            @if($displayModify)
                @sprintf('COM_ATS_BUCKETS_MSG_LASTPOST',
                \Akeeba\TicketSystem\Admin\Helper\Format::date($bucket->modified_on),
                 \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser($bucket->modified_by)->username)
            @else
                @sprintf('COM_ATS_BUCKETS_MSG_LASTPOST',
                    \Akeeba\TicketSystem\Admin\Helper\Format::date($bucket->created_on),
                    \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser($bucket->created_by)->username)
            @endif
		</span>
        <span class="small akeeba-pull-left">
			@sprintf('COM_ATS_BUCKETS_MSG_CREATED',
			    \Akeeba\TicketSystem\Admin\Helper\Format::date($bucket->created_on),
			    \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser($bucket->created_by)->username)
		</span>
    </td>
</tr>
