<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var Akeeba\TicketSystem\Site\View\Buckets\Html $this */

/**
 * This view template displays a single ticket bucket and all the tickets it contains.
 */
?>
@if (version_compare(JVERSION, '3.999.999', 'le'))
    @jhtml('behavior.tooltip')
@endif

@jhtml('behavior.multiselect')

@section('reply-area')
    @if($this->showReplyArea)
        <h3 class="ats-bucket-reply-header">@lang('COM_ATS_POSTS_HEADING_REPLYAREA')</h3>
        @if( $this->item->status == 'C' )
            <div class="akeeba-block-failure--small">
                @lang('COM_ATS_BUCKET_MSG_CLOSEDNOTICE_CLOSED_ADMIN')
            </div>
        @endif
        <div class="ats-ticket-replyarea">
            <form action="@route('index.php?option=com_ats&view=Buckets')" method="post" id="adminForm"
                  enctype="multipart/form-data">
                <input type="hidden" name="option" value="com_ats" />
                <input type="hidden" name="view" value="Buckets" />
                <input type="hidden" name="task" value="newreply" />
                <input type="hidden" name="ats_bucket_id" value="{{ $this->item->ats_bucket_id }}" />
                <input type="hidden" name="@token(true)" value="1" />
                <input type="hidden" name="returnurl" value="{{ $this->returnURLEncoded }}" />

                <div class="ats-ticket-replyarea-content bbcode">
                    @editor($this->editorName, '', '95%', 350, 80, 20, false, $this->editorID)
                </div>

                <div class="ats-ticket-replyarea-attachment">
                    <p>@lang('COM_ATS_POSTS_MSG_ADDATTACHMENT')</p>
                    <input type="file" name="attachedfile" size="10" />
                </div>
                <br />
                <div class="ats-ticket-replyarea-postbutton">
                    <input class="akeeba-btn--primary" type="submit"
                           value="@lang('COM_ATS_POSTS_MSG_POST')" />
                </div>
            </form>
        </div>
    @endif
@stop

@section('ticket-list')
    @if($this->showTicketList)
        <h3>@lang('COM_ATS_BUCKETS_HEADING_TICKETLIST')</h3>
        <table class="akeeba-table--striped ats-tickets-table">
            <tbody>
            @each('site:com_ats/Tickets/default_ticket', $this->item->tickets, 'ticket')
            </tbody>
        </table>
    @elseif($this->item->status == 'C')
        <div class="ats-bucket-closednotice">
            @lang('COM_ATS_BUCKET_MSG_CLOSEDNOTICE_CLOSED')
        </div>
    @else
        <div class="akeeba-block--info">
            @lang('COM_ATS_BUCKETS_NO_TICKETS_INFO')
        </div>
    @endif
@stop

@section('header-modules')
    @modules('ats-top')
    @modules('ats-posts-top')
@show

@if ($this->getPageParams()->get('show_page_heading', 1))
    <h1 class="ats-bucket-view-title">
        # {{{ $this->item->ats_bucket_id }}} &ndash; {{{ $this->item->title }}}
    </h1>
@endif

<div>
    @if(!$this->item->enabled)
        <a class="akeeba-btn--green akeeba-pull-left" href="@route($this->adminActionURL.'&task=publish')">
            <span class="akion-unlocked"></span>
            @lang('COM_ATS_BUCKET_LBL_PUBLISH')
        </a>
    @else
        <a class="akeeba-btn--orange akeeba-pull-left" href="@route($this->adminActionURL.'&task=unpublish')">
            <span class="akion-locked"></span>
            @lang('COM_ATS_BUCKET_LBL_UNPUBLISH')
        </a>
    @endif

    @if($this->item->status != 'C')
        <a class="akeeba-btn--dark akeeba-pull-left" href="@route($this->adminActionURL.'&task=close')">
            <span class="akion-power"></span>
            @lang('COM_ATS_BUCKET_LBL_CLOSE')
        </a>
    @else
        <a class="akeeba-btn--primary akeeba-pull-left" href="@route($this->adminActionURL.'&task=reopen')">
            <span class="akion-android-sync"></span>
            @lang('COM_ATS_BUCKET_LBL_REOPEN')
        </a>
    @endif
</div>

<div style="clear: both;margin-bottom:10px"></div>

@unless($this->showTabs)
    @yield('reply-area')
    @yield('ticket-list')
@else
    <div id="atsTabContent" class="akeeba-tabs">
        <label for="ats_bucket_reply" class="active">@lang('COM_ATS_BUCKETS_LEGEND_REPLY')</label>
        <section id="ats_bucket_reply">
            @yield('reply-area')
        </section>
        <label for="ats_bucket_tickets">@lang('COM_ATS_BUCKETS_LEGEND_TICKETLIST')</label>
        <section id="ats_bucket_tickets">
            @yield('ticket-list')
        </section>
    </div>
@endif

@section('footer-modules')
    @modules('ats-posts-bottom')
    @modules('ats-bottom')
@show
