<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var Akeeba\TicketSystem\Site\View\Categories\Html $this */

/**
 * Displays a list of all ticket categories.
 *
 * If you're looking for the list of tickets in a category look under the Tickets folder, the default.blade.php file.
 */
use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Joomla\CMS\Language\Text;

?>
<div>
    @section('header-modules')
        @modules('ats-top')
        @modules('ats-categories-top')
    @show

    @if ($this->getPageParams()->get('show_page_heading', 1))
        <h1>
            {{{ $this->getPageParams()->get('page_heading', Text::_('COM_ATS_CATEGORIES_TITLE')) }}}
        </h1>
    @endif

    @if(!count($this->items))
        @section('no-categories-modules')
            @modules('ats-categories-none-top')
            <p>
                @lang('COM_ATS_CATEGORIES_MSG_NOCATEGORIES')
            </p>
            @modules('ats-categories-none-bottom')
        @show
    @else
        @foreach($this->items as $cat)
			<?php
			/** @var \Akeeba\TicketSystem\Site\Model\Categories $cat */
			$actions = Permissions::getAclPrivileges($cat->id);
			?>
            <div class="akeeba-panel--info">
                <header class="akeeba-block-header">
                    <h3>
                        @if($cat->level > 1)
                            @for($i = 1; $i < $cat->level; $i++)
                                <div class="ats-category-levelpad">&#x2520;</div>
                            @endfor
                        @endif
                        {{{ $cat->title }}}
                    </h3>
                </header>

                <div class=" akeeba-container--75-25">
                    <div class="ats-category-desc">
                        @if($cat->params->get('image', ''))
                            <img src="{{{ $cat->params->get('image', '') }}}" alt="{{{ $cat->params->get('image_alt', '') }}}" class="ats-category-image" />
                        @endif

                        {{ $cat->description }}
                    </div>

                    <div class="ats-category-quickbuttons">
                        <a class="akeeba-btn--primary-small"
                           href="@route('index.php?option=com_ats&view=Tickets&category=' . $cat->id)">
                            <span class="akion-folder"></span>
                            @lang('COM_ATS_CATEGORIES_VIEWTICKETS')
                        </a>
                        @if($actions['core.create'])
                            <a class="akeeba-btn--green-small"
                               href="@route('index.php?option=com_ats&view=NewTicket&category=' . $cat->id)">
                                <span class="akion-document"></span>
                                @lang('COM_ATS_TICKETS_BUTTON_NEWTICKET')
                            </a>
                        @endif
                    </div>
                </div>

                <div class="ats-clear"></div>
            </div>
        @endforeach
    @endif

    @section('footer-modules')
        @modules('ats-categories-bottom')
        @modules('ats-bottom')
    @show

</div>
