<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/**
 * Displays the Latest Open Tickets page
 */

/** @var Akeeba\TicketSystem\Site\View\Latests\Html $this */
use Akeeba\TicketSystem\Admin\Helper\Permissions;

?>
@section('header-modules')
    @modules('ats-top')
    @modules('ats-latest-top')
@show

@if ($this->getPageParams()->get('show_page_heading', 1))
    <h1>
        @lang('COM_ATS_LATEST_TITLE')
    </h1>
@endif

<form id="ats-pagination" name="latestTicketsForm"
      action="@route('index.php?option=com_ats&view=Latests' . ($this->itemID != 0) ? '&Itemid='.$this->itemID : '')" method="post">
    <input type="hidden" name="option" value="com_ats" />
    <input type="hidden" name="view" value="Latests" />
    <input type="hidden" name="@token(true)" value="1" id="token" />
    <input type="hidden" id="user" value="{{ \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser()->id }}" />

    <div class="ats-latests-filters">
        <div class="akeeba-pull-right">
            <span>
                @atsTicketStatusSelect($this->filterStatus, 'status', ['data-atsSubmitTarget' => "ats-pagination",'class' => 'atscategory atsCommonEventsOnChangeSubmit','unselect_option' => false], 'filter-status')
            </span>
            <span>
                @atsCategorySelect($this->filterCategory, 'category', ['class' => 'atscategory'], null, true)
			</span>
        </div>

        <div class="ats-clear"></div>
    </div>


    @if(!count($this->items))
        @section('no-tickets-modules')
            @modules('ats-latest-none-top')
            <p>
                @lang('COM_ATS_LATEST_MSG_NOTICKETS')
            </p>
            @modules('ats-latest-none-bottom')
        @show
    @else
        <table class="akeeba-table--striped ats-latestopen-table ats-tickets-table">
            <tbody>
			<?php $counter = 0; ?>
			@foreach ($this->items as $ticket)
				<?php $this->isManager = Permissions::isManager($ticket->catid) ?>

				@include('site:com_ats/Tickets/default_ticket', array(
					'ticket'        => $ticket,
					'showAgo'       => 1,
					'showCategory'  => 1,
					'showStatusDD'  => 0,
					'showStatus'    => 0,
					'extraRowAttr'  => 'data-latestopentid="' . $ticket->ats_ticket_id . '" data-latestopensequence="' . $counter . '"',
					'extraLinkAttr' => 'id="ats-latestopenlink-' . ++$counter . '"'
				))
			@endforeach
            </tbody>
        </table>

        <div class="pagination">
            <p class="counter">
                {{ $this->pagination->getPagesCounter() }}
            </p>
            {{ $this->pagination->getPagesLinks() }}
        </div>
    @endif
</form>

@section('footer-modules')
    @modules('ats-latest-bottom')
    @modules('ats-bottom')
@show