<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var \Akeeba\TicketSystem\Site\Model\ManagerNotes $item */
/** @var FOF40\View\DataView\Html $this */

use Akeeba\TicketSystem\Admin\Helper\Html;

if (!$item->enabled)
{
	return;
}

$postUser = Html::getPostUser($item->created_by);
$user     = \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser();

// Get the return URL to point back to ourselves
$permalink = JUri::getInstance();
$permalink->setFragment('mn' . $item->ats_managernote_id);

\Joomla\CMS\Language\Text::script('COM_ATS_POSTS_MSG_DELETEPROMPT');
?>
<div class="ats-post akeeba-panel--default ats-post-status-{{ $item->enabled ? 'published' : 'unpublished' }}"
     id="mn{{ $item->ats_managernote_id }}">
    <header class="ats-post-header akeeba-block-header">
		<span class="ats-post-header-date">
			<a href="{{ $permalink }}">
				{{ $postUser->name }} ({{ $postUser->username }})
				&bull;
                @atsFormatDate($item->created_on)
			</a>
		</span>
    </header>
    <div class="ats-post-body">
        <div class="ats-post-content">
            <div class="ats-post-content-html">
                @unless($item->note_html)
                    @parseBBCode($item->note)
                @else
                    {{ $item->note_html }}
                @endif
            </div>
            <div class="ats-post-content-signature">
                {{ \Akeeba\TicketSystem\Admin\Helper\Html::getSignature($postUser) }}
            </div>
        </div>
    </div>
    <div class="ats-post-footer">
        @if(!empty($item->modified_on) && ($item->modified_on != $this->getContainer()->db->getNullDate()) && ($item->modified_on != '0000-00-00 00:00:00'))
            <div class="ats-post-edits">
                @sprintf('COM_ATS_TICKETS_MSG_EDITEDBYON',
                \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser($item->modified_by)->username,
                \Akeeba\TicketSystem\Admin\Helper\Format::date($item->modified_on) )
            </div>
        @endif

        <div class="ats-post-buttons">
            @if($item->enabled)
                <a class="akeeba-btn--small-grey"
                   href="index.php?option=com_ats&view=ManagerNotes&task=unpublish&id={{ $item->ats_managernote_id }}&returnurl={{ $returnURL }}&@token(true)=1">
                    <span class="akion-locked"></span>
                    @lang('COM_ATS_COMMON_UNPUBLISH')
                </a>
            @else
                <a class="akeeba-btn--small-grey"
                   href="index.php?option=com_ats&view=ManagerNotes&task=publish&id={{ $item->ats_managernote_id }}&returnurl={{ $returnURL }}&@token(true)=1">
                    <span class="akion-unlocked"></span>
                    @lang('COM_ATS_COMMON_PUBLISH')
                </a>
            @endif

            <a class="akeeba-btn--primary-small"
               href="index.php?option=com_ats&view=ManagerNotes&task=edit&id={{ $item->ats_managernote_id }}&returnurl={{ $returnURL }}&@token(true)=1">
                <span class="akion-edit"></span>
                @lang('COM_ATS_COMMON_EDIT')
            </a>

            <a class="akeeba-btn--red-small atsCommonEventsOnClickConfirm"
               href="index.php?option=com_ats&view=ManagerNotes&task=remove&id={{ $item->ats_managernote_id }}&returnurl={{ $returnURL }}&@token(true)=1"
               data-atsconfirmmessage="COM_ATS_POSTS_MSG_DELETEPROMPT">
                <span class="akion-trash-b"></span>
                @lang('COM_ATS_COMMON_DELETE')
            </a>
        </div>
    </div>
</div>
