<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var Akeeba\TicketSystem\Site\View\Mies\Html $this */

use Akeeba\TicketSystem\Admin\Helper\Html;
use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Akeeba\TicketSystem\Admin\Helper\Select;

?>
@section('head-modules')
    @modules('ats-top')
    @modules('ats-mytickets-top')
@show

@if ($this->showPageHeading || !empty($this->userID))
    <h1>
        @unless($this->isManager && !empty($this->userID))
            @lang('COM_ATS_MY_TITLE')
        @else
            @sprintf('COM_ATS_TICKETS_BY', $this->displayedUsername)

            <span class="akeeba-label--teal--small akeeba-pull-right"
                  title="@sprintf('COM_ATS_TICKET_LBL_HAVESPENTXMINUTES', $this->timeSpentPerUser)">
                {{{ (int) $this->timeSpentPerUser }}}'
            </span>
        @endif
    </h1>
@endif

<form id="adminForm" name="adminForm" class="akeeba-form--inline"
      action="@route('index.php?option=com_ats&view=Mies' . ($this->itemID != 0) ? '&Itemid=' . $this->itemID : '')" method="post">
    <input type="hidden" name="option" value="com_ats" />
    <input type="hidden" name="view" value="Mies" />
    <input type="hidden" name="userid"
           value="{{ $this->userID }}" />

    <div class="ats-mytickets-filters" style="margin-bottom: 10px">
        <div class="akeeba-pull-left">
            <span>
                <span>
                    <input type="text" name="title" id="title" value="{{ $this->getModel()->getState('title') }}"
                           placeholder="@lang('COM_ATS_TICKETS_HEADING_TITLE')" class="search-query" />

                    <button class="akeeba-btn--dark-small" id="ats-search" title="@lang('COM_ATS_COMMON_SEARCH')">
                        <span class="akion-search"></span>
                    </button>
                </span>
            </span>

            <a href="@route('index.php?option=com_ats&view=NewTicket' . ($this->filterCategory ? '&category=' . $this->filterCategory : '') . ($this->itemID ? '&Itemid=' . $this->itemID : ''))"
               class="akeeba-btn--primary-small">
                <span class="akion-document"></span>
                @lang('COM_ATS_TICKETS_BUTTON_NEWTICKET')
            </a>
        </div>
        <div class="pull-right">
            @atsCategorySelect($this->filterCategory, 'category', array('class' => 'atscategory', 'style' => 'width: 100%'), null, true)
        </div>

        <div class="ats-clear"></div>
    </div>

    @if(!count($this->items))
        @section('no-my-tickets-modules')
            @modules('ats-mytickets-none-top')
            <p>
                @lang('COM_ATS_MYTICKETS_MSG_NOTICKETS')
            </p>
            @modules('ats-mytickets-none-bottom')
        @show
    @else
        <table class="akeeba-table--striped ats-tickets-table">
            <tbody>
            @foreach($this->items as $ticket)
                @include('site:com_ats/Tickets/default_ticket', [
                    'ticket' => $ticket,
                    'showMy' => 0
                ])
            @endforeach
            </tbody>
        </table>

        <div class="pagination">
            <p class="counter">
                {{ $this->pagination->getPagesCounter() }}
            </p>

            {{ $this->pagination->getPagesLinks() }}
        </div>
    @endif
</form>

@section('footer-modules')
    @modules('ats-mytickets-bottom')
    @modules('ats-bottom')
@show