<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var Akeeba\TicketSystem\Site\View\NewTickets\Html $this */

?>
@section('head-modules')
    @modules('ats-top')
    @modules('ats-newticket-top')
@show

@if ($this->getPageParams()->get('show_page_heading', 1))
    <h1>
        @sprintf('COM_ATS_NEWTICKET_TITLE', $this->escape($this->category->title))
    </h1>
@endif

<form name="ats_newticket_form" class="akeeba-form--horizontal"
      action="@route('index.php?option=com_ats&view=NewTicket' . ($this->itemID != 0) ? '&Itemid=' . $this->itemID : 0)"
      method="post" enctype="multipart/form-data">

    @if ($this->isManager)
        <input type="hidden" name="created_by" id="created_by" value="{{ $this->created_by }}" />

        <div class="akeeba-form-group">
            <label for="created_by_visible">@lang('COM_ATS_COMMON_USERSELECT_LBL')</label>

            <div class="akeeba-input-group">
                <input type="text" name="xxx_userid" id="created_by_visible"
                       value="{{ $this->created_by ? \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser($this->created_by)->username : '' }}"
                       disabled="disabled" />
                <span class="akeeba-input-group-btn">
				<a id="userselect"
                   href="index.php?option=com_ats&view=Jusers&tmpl=component&field=created_by&category={{ $this->category->id }}"
                   class="akeeba-btn">
                    @lang('COM_ATS_COMMON_SELECTUSER')
                </a>
			</span>
            </div>
        </div>
    @endif

    <div class="akeeba-form-group">
        <label for="tickettitle">@lang('COM_ATS_NEWTICKET_LBL_TITLE')</label>

        <input type="text" id="tickettitle" name="ticket[title]" value="{{ $this->ticket_title }}"
               required="required" />
    </div>

    @if($this->category->params->get('instantreply',0))
        <div id="ats-instantreply-wrapper" class="akeeba-form-group" style="display:none;">
            <label id="ats-instantreply-title">@lang('COM_ATS_NEWTICKET_INSTANTREPLY_HEADER')</label>
            <div>
                <div id="ats-instantreply-grid" style="display:none"></div>

                <div id="ats-instantreply-noresults" class="akeeba-block--failure-small"
                     style="display:none">@lang('COM_ATS_NEWTICKET_INSTANTREPLY_NORESULTS')</div>
                <div id="ats-instantreply-wait" class="akeeba-block--warning-small"
                     style="display:none">@lang('COM_ATS_NEWTICKET_INSTANTREPLY_LOADING')</div>
            </div>

        </div>
        <div id="ats-instantreply-lightbox-wrapper" style="display:none">
            <div id="ats-instantreply-lightbox-shader">
                <div id="ats-instantreply-lightbox-innerbox">
			<span id="ats-instantreply-lightbox-close" class="akeeba-btn--grey-small">
				<span class="akion-checkmark-round"></span>
				@lang('COM_ATS_NEWTICKET_INSTANTREPLY_CLOSETHIS')
			</span>
                    <iframe id="ats-instantreply-lightbox-iframe"></iframe>
                </div>
            </div>
        </div>
    @endif

    @if($this->forceType)
        {{-- Am I forcing a ticket type (public private)? --}}
        <input type="hidden" name="ticket[public]" value="{{ (int) ($this->forceType == 'PUB') }}" />
    @elseif ($this->allow_private)
        {{-- I always display the public/private select list, even if I know I can't post using a status, but at least I can inform the user how much it will cost to do so... --}}
        <div class="akeeba-form-group">
            <label for="privateticket">@lang('COM_ATS_NEWTICKET_LBL_VISIBILITY')</label>
            <select id="privateticket" name="ticket[public]">
                <option value="1" {{{ !$this->ticketPrivate ? 'selected="selected"' : ''  }}}>
                    @lang('COM_ATS_NEWTICKET_LBL_PUBLIC')
                </option>
                <option value="0" {{{ $this->ticketPrivate ? 'selected="selected"' : ''  }}}>
                    @lang('COM_ATS_NEWTICKET_LBL_PRIVATE')
                </option>
            </select>
        </div>
    @endif

	<?php // Can users choose ticket priorities? If they can't, I'll automatically put the value in F0FTable check ?>
    @if($this->displayPriorities)
        <div class="akeeba-form-group">
            <label for="priority">@lang('COM_ATS_TICKET_PRIORITY')</label>
            @atsPrioritySelect('ticket[priority]', $this->ticketPriority)
        </div>
    @endif

    @if(!$this->isManager && $this->show_credits && ATS_PRO)
        <div class="akeeba-form-group">
            <div class="akeeba-block--info-small">
                @sprintf('COM_ATS_COMMON_CREDITSLEFT', $this->totalCreditsLeft)
            </div>
        </div>
    @endif

    <div>
        <div id="loading" style="text-align:center;display:none;margin-bottom:20px">
            <img src="@media('media://com_ats/images/throbber.gif')" />
        </div>
        <div class="akeeba-block--warning-small" id="ats-newticket-pubnote-public"
                {{ $this->ticketPrivate ? 'style="display: none"' : '' }}>
            @lang('COM_ATS_NEWTICKET_MSG_PUBNOTE_PUBLIC')
            @if(!$this->isManager && $this->show_credits && ATS_PRO)
                @if($this->credits_public)
                    @sprintf('COM_ATS_NEWTICKET_LBL_COST', '<span class="credits">'.$this->credits_public.'</span>')
                @else
                    @lang('COM_ATS_NEWTICKET_LBL_NOCOST')
                @endif
            @endif
        </div>
        <div class="akeeba-block--success-small" id="ats-newticket-pubnote-private"
                {{ !$this->ticketPrivate ? 'style="display: none"' : '' }}>
            @lang('COM_ATS_NEWTICKET_MSG_PUBNOTE_PRIVATE')
            @if(!$this->isManager && $this->show_credits && ATS_PRO)
                @if($this->credits_private)
                    @sprintf('COM_ATS_NEWTICKET_LBL_COST', '<span class="credits">'.$this->credits_private.'</span>')
                @else
                    @lang('COM_ATS_NEWTICKET_LBL_NOCOST')
                @endif
            @endif
        </div>
    </div>

    {{-- ========== Guest Post ======== --}}
    @if (\Akeeba\TicketSystem\Admin\Helper\Permissions::getUser()->guest)
        <div class="akeeba-form-group">
            <label for="ticket_email">@lang('COM_ATS_NEWTICKET_GUESTPOST_EMAIL')</label>

            <input type="email" id="ticket_email" name="email" value="{{ $this->ticket_email }}" required="required" />
        </div>

        <div class="akeeba-form-group">
            <label for="ticket_name">@lang('COM_ATS_NEWTICKET_GUESTPOST_NAME')</label>

            <input type="text" id="ticket_name" name="name" value="{{ $this->ticket_name }}" required="required" />
        </div>

        @if ($this->captchaPlugin)
            <div class="akeeba-form-group">
                <label for="com_ats_newticket_captcha">@lang('COM_ATS_NEWTICKET_GUESTPOST_CAPTCHA')</label>

                {{ JCaptcha::getInstance($this->captchaPlugin, array('namespace' => 'com_ats_newTicket'))
                   ->display('captcha', 'com_ats_newticket_captcha', 'ats_captcha') }}
            </div>
        @endif
    @endif

    @if(!$this->item->ats_ticket_id)
        @include('site:com_ats/NewTickets/customfields', ['customFields' => $this->customFields])
    @endif

    <div class="akeeba-form-group">
        <label for="bbcode">@lang('COM_ATS_NEWTICKET_LBL_YOURREQUEST')</label>
		@include('site:com_ats/Posts/post', array(
			'post_content'     => $this->post_content,
			'allow_attachment' => $this->allow_attachment,
			'category'         => $this->category->id,
		))
    </div>

    <div class="akeeba-for-group--pull-right">
        <button type="submit" class="akeeba-btn--primary">
            <span class="akion-chatbubble-working"></span>
            @lang('COM_ATS_NEWTICKET_LBL_DOPOST')
        </button>
    </div>

    <input type="hidden" name="option" value="com_ats" />
    <input type="hidden" name="view" value="NewTicket" />
    <input type="hidden" name="task" value="save" />
    <input type="hidden" name="ticket[catid]" id="ticket_catid" value="{{ $this->category->id }}" />
    <input type="hidden" name="category" value="{{ $this->category->id }}" />
    <input type="hidden" name="Itemid" value="{{ $this->itemID }}" />
    <input type="hidden" name="@token(true)" value="1" />

    @if($this->category->params->get('instantreply',0))
        <input type="hidden" name="ats_attempt_id" value="" />
    @endif
</form>

@section('footer-modules')
    @modules('ats-newticket-bottom')
    @modules('ats-bottom')
@show