<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Editor;
use Akeeba\TicketSystem\Admin\Helper\Select;
use Akeeba\TicketSystem\Site\Model\Posts;

/** @var Akeeba\TicketSystem\Site\View\Posts\Html $this */

// This file is loaded when editing existing tickets

/** @var Posts $post */
$post = $this->item;

if (!isset($returnURL))
{
	$returnURLtemp = $this->input->getString('returnurl', null);

	if (!empty($returnURLtemp))
	{
		$returnURL = $returnURLtemp;
	}
}

// Get the tags
/** @var \Akeeba\TicketSystem\Site\Model\Jusers $joomlaModel */
$joomlaModel = $this->getModel('Jusers');
$joomlaModel->find($this->item->created_by);

/** @var \FOF40\Model\DataModel\Collection $collection */
$collection = $joomlaModel->atstags;
$tags = array_unique($collection->modelKeys());

$timespentMandatory = $this->getContainer()->params->get('timespent_mandatory', 0);
?>
@jhtml('formbehavior.chosen')

<div class="ats-ticket-replyarea">
    <form class="akeeba-form--horizontal" action="@route('index.php?option=com_ats&view=Post')" method="post"
          name="adminForm" id="adminForm" enctype="multipart/form-data">

        {{-- Allow custom field edit only if I'm a manger and this is the fist post of the thread --}}
        @if($this->isManager && $post->isFirstOne())
            @include('site:com_ats/NewTickets/customfields', ['customFields' => $post->ticket->getCustomFieldDefinitions()])
        @endif

        <div class="ats-ticket-replyarea-content bbcode">
            <?php
	        // Always show HTML code, even if we're editing a legacy BBcode-formatted ticket.
	        $contentsLegacy = $this->item->content;
	        $contents = $this->item->content_html;

	        if (empty($contents) && !empty($contentsLegacy))
	        {
		        $contents = \Akeeba\TicketSystem\Admin\Helper\Bbcode::parseBBCode($contentsLegacy);
	        }
	        ?>
            @editor('content_html', htmlspecialchars($contents, ENT_COMPAT, 'UTF-8'), '95%', 350, 80, 20, false, 'ats-content')
        </div>

        @if($this->isManager && ATS_PRO)
            <div class="ats-ticket-replyarea-timetracking">
                <div class="akeeba-form-group">
                    <label for="ats-timespent">@lang('COM_ATS_POSTS_LBL_TIMESPENT')</label>

                    <span class="akeeba-input-group">
                    <input type="text" name="timespent" id="ats-timespent"
                           {{ $timespentMandatory ? 'required="required"' : '' }} value="{{ $this->item->timespent }}" />
                    <span>@lang('COM_ATS_POSTS_LBL_TIMESPENT_MINUTES')</span>
                </span>
                </div>
            </div>
        @endif

        @if($this->isManager)
            <div class="ats-ticket-replyarea-usertags">
                <div class="akeeba-form-group">
                    <label for="usertags">@lang('COM_ATS_COMMON_USER_TAGS')</label>
                    {{ Select::usertags('usertags[]', $tags, array('class' => 'advancedSelect', 'multiple' => 'multiple', 'size' => 5)) }}
                </div>
            </div>
        @endif

        <div class="akeeba-form-group">
            <div>
                <input class="akeeba-btn--primary" type="submit" value="@lang('COM_ATS_POSTS_MSG_POST')" />
            </div>
        </div>

        <input type="hidden" name="option" value="com_ats" />
        <input type="hidden" name="view" value="Post" />
        <input type="hidden" name="task" value="save" />
        <input type="hidden" name="ats_ticket_id" value="{{ $post->ats_ticket_id }}" />
        <input type="hidden" name="ats_post_id" value="{{ $post->ats_post_id }}" />
        <input type="hidden" name="@token(true)" value="1" />
        @if(isset($returnURL))
            <input type="hidden" name="returnurl" value="{{ $returnURL }}" />
        @endif
    </form>
</div>
