<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var    FOF40\View\DataView\Html $this */

use Akeeba\TicketSystem\Admin\Helper\Editor;use Akeeba\TicketSystem\Admin\Helper\Html;use Akeeba\TicketSystem\Admin\Helper\Permissions;

/**
 * Renders the Post a Reply section when viewing a ticket. Also used when filing a new ticket.
 *
 * Params passed by the loadAnyTemplate function
 *
 * $category            : Category id
 * $direct              : Controls the field name of the post editor. When false (default) it's something like
 *                        "post[content]", otherwise it's "content".
 * $allow_attachment    : Are attachments allowed?
 * $post_content        : Content of the post stored in the session (previous failed save)
 */

if (!isset($category)) $category = 0;
if (!isset($direct)) $direct = false;
if (!isset($allow_attachment)) $allow_attachment = false;
if (!isset($post_content)) $post_content = '';

$isAdmin = Permissions::getUser()->authorise('core.admin', 'com_ats') || Permissions::getUser()->authorise('core.manage', 'com_ats');
$isManager = Permissions::isManager($category);
$uploadLimit = Html::getUploadLimits();
$allowedExt = Html::allowedExtensions();
$showCredits = $this->container->params->get('showcredits', 0);

$tags = [];

if ($this->item->created_by)
{
	// Get the tags, arranged so that we can have a nice select list
	$tags = Html::getUserTags($this->item->created_by);
	$tags = array_map(function($value){
		return $value['ats_usertag_id'];
    }, $tags);
}

$timespentMandatory = $this->getContainer()->params->get('timespent_mandatory', 0);

if ($timespentMandatory)
{
    $this->container->platform->addScriptOptions('ats.TimeSpent.mandatory', true);
}
?>
@if (version_compare(JVERSION, '3.999.999', 'le'))
    @jhtml('behavior.tooltip')
@endif

{{-- Display a modal message over the ticket post area --}}
@section('post-form-overlay')
    <?php $overlays = $this->getContainer()->template->loadPosition('ats-replyarea-overlay') ?>
    @unless($isManager || empty($overlays))
        <?php $this->container->platform->addScriptOptions('ats.TicketOverlays.autoShow', true); ?>
        <div id="ats-replyarea-overlay-modal" style="display: none;">
            <div class="akeeba-renderer-fef">
                {{ $overlays }}

                <hr/>
                <a href="#" class="akeeba-btn--green atsTicketsOverlayClose">
                    <span class="akion-checkmark-round"></span>
                    @lang('COM_ATS_NEWTICKET_INSTANTREPLY_CLOSEMESSAGE')
                </a>
            </div>
        </div>
    @endunless
@stop

@section('post-form-timespent')
    @if($isManager && ATS_PRO)
        <div class="AKEEBA_MASTER_FORM_STYLING akeeba-form--inline">
            <div class="akeeba-form-group" style="display: inline-flex">
                <label for="ats-timespent">@lang('COM_ATS_POSTS_LBL_TIMESPENT')</label>
                <div class="akeeba-input-group">
                    <input type="text" name="timespent" id="ats-timespent"
                           {{ $timespentMandatory ? 'required="required"' : '' }} value="" />
                    <span>@lang('COM_ATS_POSTS_LBL_TIMESPENT_MINUTES')</span>
                </div>
            </div>

            <div class="akeeba-form-group--actions" style="margin: 5px 0" style="display: inline-flex">
                <span class="akeeba-btn--small" id="timerBtn">@lang('COM_ATS_TIMER_START')</span>
            </div>
        </div>
    @endif
@stop

@section('post-form-editor')
	<?php
	$editorParams = [
		'buckets'       => $isAdmin && ATS_PRO,
		'ats_ticket_id' => $this->item->ats_ticket_id,
		'cannedreplies' => $isManager,
		'category'      => isset($category) ? $category : null
	];
	?>
    @jhtml('formbehavior.chosen')
    <div class="ats-ticket-replyarea-content bbcode">
	    <?php
	    $this->container->platform->setSessionVar('canned_replies.category', $category, 'com_ats');
	    $this->container->platform->setSessionVar('canned_replies.enabled', $isManager, 'com_ats');
	    ?>
        @editor($direct ? 'content_html' : 'post[content_html]', htmlspecialchars($post_content, ENT_COMPAT, 'UTF-8'), '95%', 350, 80, 20, $isManager, 'ats-content')
    </div>
    <div class="ats-ticket-replyarea-postcontent"></div>
@stop


@section('post-form-credits')
    @if ($isManager && ATS_PRO)
        @if($showCredits)
            <div class="akeeba-form-group">
                <label for="ats-credits-charge">@lang('COM_ATS_POSTS_CREDITS_CHARGE')</label>
                <div>
                    <div class="akeeba-input-group">
                        <input type="text" name="extracredits" id="ats-credits-charge" value="" />
                        <span>@lang('COM_ATS_TICKETS_USERINFO_CREDITS')</span>
                    </div>
                </div>
            </div>
        @endif
    @endif
@stop

@section('post-form-usertags')
    @if ($isManager)
        <div class="akeeba-form-group">
            <label for="usertags">@lang('COM_ATS_COMMON_USER_TAGS')</label>
            {{ \Akeeba\TicketSystem\Admin\Helper\Select::usertags('usertags[]', $tags, array('class' => 'advancedSelect', 'multiple' => 'multiple', 'size' => 5)) }}
        </div>
    @endif
@stop

@section('post-form-attachments')
    @if ($allow_attachment)
        <div class="ats-ticket-replyarea-attachment akeeba-form-group" id="attachedfileMainField">
            <label for="attachedfile">@lang('COM_ATS_NEWTICKET_LBL_ATTACHMENT')</label>
            <div>
                <span class="attFileField">
                    <input type="file" name="attachedfile[]" />
                </span>
                <span class="attButtonField" style="display: none;">
                    <a class="akeeba-btn--dark-small" href="javascript:void(0);">
                        @lang('COM_ATS_COMMON_REMOVE')
                    </a>
                </span>
            </div>
        </div>

        <div class="ats-attachments"></div>

        <div class="ats-ticket-replyarea-attachment-help akeeba-form-group--pull-right">
            <div>
                <a href="javascript:void(0);" class="akeeba-btn--primary" id="addAttachment">
                    <span class="akion-plus-round"></span>
                    @lang('COM_ATS_POSTS_ADD_ATTACHMENT')
                </a>

                <p>
                    @sprintf('COM_ATS_NEWTICKET_LBL_ATTACHMENT_MAXSIZE',$uploadLimit)
                    @if(!empty($allowedExt))
                    @sprintf('COM_ATS_NEWTICKET_LBL_ATTACHMENT_ALLOWED_EXTENSIONS', implode(', ',$allowedExt))
                    @endif
                </p>
            </div>
        </div>
    @endif
@stop

@yield('post-form-overlay')
@yield('post-form-bbcode-info')
@yield('post-form-timespent')
@yield('post-form-editor')
@yield('post-form-credits')
@yield('post-form-usertags')
@yield('post-form-attachments')