<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/**
 * Defines the Blade sections for rendering the user information section of a post
 *
 * Params coming from including this layout with loadAnyTemplate:
 *
 * $user        : The user who posted this reply
 * $isPrintView : Are we rendering with the intention of printing (as opposed to displaying on screen)?
 *
 * $this->isManager     : Is the user a manager?
 */

/** @var FOF40\View\DataView\Html $this */

use Akeeba\TicketSystem\Admin\Helper\Filter;
use Akeeba\TicketSystem\Admin\Helper\Html;
use Akeeba\TicketSystem\Admin\Helper\JoomlaUsers;
use Akeeba\TicketSystem\Admin\Helper\Subscriptions;

$this->getContainer()->platform->importPlugin('ats');

$avatarURL    = Html::getAvatarURL($user, 128);
$subsPerUser  = Subscriptions::getSubscriptionsList($user);
$userGroups   = JoomlaUsers::getUserGroups($user);
$countryInfo  = null;
$pluginResult = $this->getContainer()->platform->runPlugins('onAtsGetSubscriptionCountry', array(
	$user->id, $this->isManager
));

if (is_array($pluginResult))
{
	$countryInfo = array_shift($pluginResult);
}
?>
@section('post-user-avatar')
    @if ($avatarURL)
        <div class="ats-post-userinfo-avatar">
            <img src="{{ $avatarURL }}" alt="" width="64" height="64" />
        </div>
    @endif
@overwrite

@section('post-user-username')
    @if ($this->isManager && !$isPrintView)
		<?php $count = Html::getTicketsCount($user->id); ?>
        <a href="@route('index.php?option=com_ats&view=Mies&userid=' . $user->id)">{{ $user->username }}</a>
        @if(!empty($countryInfo) && is_array($countryInfo) && (count($countryInfo) > 1))
            <span class="ats-post-userinfo-flag">
				<span class="hasTooltip" title="{{ $countryInfo[1] }}">
					{{ \Akeeba\TicketSystem\Admin\Helper\Format::countryToEmoji($countryInfo[0]) }}
				</span>
            </span>
        @endif
        <br />
        <span class="akeeba-label--grey hasTooltip" title="@sprintf('COM_ATS_TICKET_LBL_HADFILEDXTICKETS', $count)">
        <span class="akion-document"></span>
        {{ $count }}
    </span>
    @else
        {{ $user->username }}
    @endif
@overwrite

@section('post-user-timespent')
    @if($this->isManager)
        <span class="akeeba-label--teal hasTooltip"
              title="@sprintf('COM_ATS_TICKET_LBL_HAVESPENTXMINUTES', Html::getTimeSpentPerUser($user->id))">
            <span class="akion-android-time"></span>
            {{ Html::getTimeSpentPerUser($user->id) }}'
        </span>
    @endif
@overwrite

@section('post-user-badges')
    {{-- User group  badges --}}
    <div class="ats-post-userinfo-badge">
        @foreach($user->groups as $groupID => $groupName )
            <?php $mediaBase = 'media://com_ats/groups/' . Filter::toSlug($groupID); ?>
            @if (@file_exists($this->getContainer()->template->parsePath($mediaBase . '.png', true)))
                <img src="@media($mediaBase . '.png')" border="0">
            @elseif (@file_exists($this->getContainer()->template->parsePath($mediaBase . '.jpg', true)))
                <img src="@media($mediaBase . '.png')" border="0">
            @endif
        @endforeach
    </div>
@overwrite

@section('post-user-subscriptions')
    {{-- User subscriptions --}}
    @if($this->isManager)
        <div class="ats-post-userinfo-subscriptions">
            @foreach ($subsPerUser->active as $subName)
                <span class="akeeba-label--grey--small">{{ $subName }}</span>
            @endforeach
            @foreach ($subsPerUser->inactive as $subName)
                <span class="akeeba-label--red--small">{{ $subName }}</span>
            @endforeach
        </div>

    @endif
@overwrite

@section('post-user-groups')
    {{-- User groups --}}
    @if($this->isManager)
        @if ($userGroups)
            <div class="ats-post-userinfo-usergroups">
                {{ implode(', ', $userGroups) }}
            </div>
        @endif
    @endif
@overwrite

@section('post-user-tags')
    {{-- User tags --}}
    @if($this->isManager)
        @foreach(\Akeeba\TicketSystem\Admin\Helper\Html::getUserTags($user->id) as $tag)
            <span class="akeeba-label--teal atsTooltip" data-toggle="tooltip" title="{{ $tag['title'] }}">
                {{ $tag['title'] }}
            </span>
        @endforeach
    @endif
@overwrite