<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var Akeeba\TicketSystem\Site\View\Tickets\Html $this */

use Akeeba\TicketSystem\Admin\Helper\Html;
use Akeeba\TicketSystem\Admin\Helper\Select;
use Joomla\CMS\Language\Text;

/**
 * This view template is loaded when displaying the list of tickets belonging to a Category
 */
?>

@section('head-modules')
    @modules('ats-top')
    @modules('ats-tickets-top')
@stop

@section('page-heading')
    @if ($this->showPageHeading)
        <h2>
            {{{ $this->escape($this->category->title) }}}
        </h2>
    @endif
@stop

@section('toolbar-newticket')
    @if($this->canCreate)
        <div class="ats-button ats-button-action-newticket" style="float:left">
            <a class="akeeba-btn--green-small"
               href="@route('index.php?option=com_ats&view=NewTicket&category=' . $this->category->id . ($this->itemID ? '&Itemid=' . $this->itemID : ''))">
                <span class="akion-document"></span>
                @lang('COM_ATS_TICKETS_BUTTON_NEWTICKET')
            </a>
        </div>
    @endif
@stop

@section('toolbar-ticket-status')
    <div style="float: right;">
        @atsTicketStatusSelect($this->filterStatus, 'filter-status', ['aria-label' => Text::_('COM_ATS_TICKETS_FILTER_LBL'),'class' => 'form-control atsFilterStatusSelect'], 'filter-status')
    </div>
@stop

@section('toolbar')
    <div class="ats-buttonbar form-inline">
        @yield('toolbar-newticket')
        @yield('toolbar-ticket-status')
        <div class="ats-clear"></div>
    </div>
@stop

@section('modules-notickets')
    @modules('ats-tickets-none-top')

    <p>@lang('COM_ATS_TICKETS_MSG_NOTICKETS')</p>

    @modules('ats-tickets-none-bottom')
@stop

@section('tickets-list')
    @if(!$this->items)
        @yield('modules-notickets')
    @else
        <p></p>
        <table class="akeeba-table--striped ats-tickets-table" role="presentation">
            @each('site:com_ats/Tickets/default_ticket', $this->getItems(), 'ticket')
        </table>
    @endif
@stop

@section('pagination')
    <form id="ats-pagination" name="atspagination" action="@route('index.php?option=com_ats&view=Tickets' . ($this->itemID != 0 ? '&Itemid=' . $this->itemID : ''))" method="post">
        <input type="hidden" name="option" value="com_ats" />
        <input type="hidden" name="view" value="Tickets" />
        <input type="hidden" name="category" value="{{ $this->category->id }}" />
        <input type="hidden" name="status" value="{{ $this->getModel()->getState('status', '') }}" id="ats_filter_status" />
        <input type="hidden" name="@token()" value="1" id="token" />
        <input type="hidden" id="user" value="{{{ \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser()->id }}}" />
        <input type="hidden" name="task" value="browse" />

        <div class="pagination">
            <p class="counter">
                {{ $this->pagination->getPagesCounter() }}
            </p>

            {{ $this->pagination->getPagesLinks() }}
        </div>
    </form>
@stop

@section('footer-modules')
    @modules('ats-tickets-bottom')
    @modules('ats-bottom')
@stop

@yield('head-modules')
@yield('page-heading')
@yield('toolbar')
<div class="ats-clear"></div>
@yield('tickets-list')
@yield('pagination')
@yield('footer-modules')
