<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var Akeeba\TicketSystem\Site\View\Tickets\Html $this */

use Akeeba\TicketSystem\Admin\Helper\Credits;
use Akeeba\TicketSystem\Admin\Helper\Html;

/**
 * This view template is loaded when viewing a single ticket.
 */
/** @var \Akeeba\TicketSystem\Site\Model\Tickets $ticket */
$ticket = $this->item;
?>

@if (version_compare(JVERSION, '3.999.999', 'le'))
    @jhtml('behavior.tooltip')
@endif

@section('head')
    @modules('ats-top')
    @modules('ats-posts-top')

    @include('com_ats/Tickets/item_head')
@stop

@section('footer')
    @modules('ats-posts-bottom')
    @modules('ats-bottom')
@stop

@section('before-conversation')
    @if ($this->beforeConversationResults)
        <div class="ats-before-ticketconversation">
            @foreach ($this->beforeConversationResults as $result)
                @if ($result)
                    {{ $result }}
                @endif
            @endforeach
        </div>
    @endif
@stop

@section('posts-list')
    <div id="atsPostList">
		<?php
		$this->items = $ticket->posts;
		// Let's save the latest post id, so I can warn the user if anyone posted while replying
		$last_post = $this->items->last();
		?>
        @include('site:com_ats/Posts/threaded')
		<?php $this->items = null; ?>
    </div>
@stop

@section('after-conversation')
    {{-- Output the current user in a hidden form (not submitted to the request. It will be used in JavaScript files --}}
    <input type="hidden" id="user" value="{{ $this->user->id }}" />
    @if ($this->afterConversationResults)
        <div class="ats-after-ticketconversation">
            @foreach ($this->afterConversationResults as $result)
                @if ($result)
                    {{ $result }}
                @endif
            @endforeach
        </div>
    @endif
@stop

@section('reply-area')
    @if ((($ticket->status != 'C') && $this->ticketPerms['post']) || $this->isManager)
        <h3 class="ats-ticket-reply-header">@lang('COM_ATS_POSTS_HEADING_REPLYAREA')</h3>

        <form class="akeeba-form--horizontal" name="ats_reply_form"
              action="@route('index.php?option=com_ats&view=Post')" method="post" enctype="multipart/form-data">

            @if ($this->showCredits && !$this->isManager)
                <div class="akeeba-block--info" id="ats-newticket-pubnote-public">
                    @sprintf('COM_ATS_COMMON_CREDITSLEFT', Credits::creditsLeft($this->user->id, true))
                </div>
            @endif

            @if ($this->isManager && ATS_PRO )
                <div class="akeeba-block--success small">
                    <div class="ats-total-timespent">
                        @sprintf('COM_ATS_TICKET_TIMESPENT_MSG', $ticket->timespent)
                    </div>
                    @if ($this->showCredits)
                        <div class="ats-total-credits">
                            @sprintf('COM_ATS_TICKET_TOTALCREDITS_MSG', $this->totalCredits)
                        </div>
                    @endif
                </div>
            @endif

            <div class="akeeba-block--{{ $ticket->public ? 'warning' : 'success' }} small"
                 id="ats-newticket-pubnote-{{ $ticket->public ? 'public' : 'private' }}">
                @lang($ticket->public ? 'COM_ATS_NEWTICKET_MSG_PUBNOTE_PUBLIC' : 'COM_ATS_NEWTICKET_MSG_PUBNOTE_PRIVATE')

                @if(!$this->isManager && $this->showCredits && ATS_PRO)
                    @if($this->creditsRequired)
                        @sprintf('COM_ATS_NEWPOST_LBL_COST', $this->creditsRequired)
                    @else
                        @lang('COM_ATS_NEWPOST_LBL_NOCOST')
                    @endif
                @endif
            </div>

            @if( $this->isManager && ($ticket->status == 'C') )
                <div id="ats-closed-warning-admin" class="akeeba-block--failure small">
                    @lang('COM_ATS_TICKET_MSG_CLOSEDNOTICE_CLOSED_ADMIN')
                </div>
            @endif

            @if($this->input->getInt('warn_reply', 0))
                <div class="akeeba-block--warning small">
                    @lang('COM_ATS_TICKET_REPLY_POSTED_WRITING')
                </div>
            @endif

            @if(!$this->enoughCredits && !$this->isManager)
                @include('site:com_ats/Posts/notenoughcredits')
            @elseif(!$this->isManager && $this->container->params->get('noreplies', 0))
                @include('site:com_ats/Posts/noreplies')
            @else
                {{-- If the ticket is already assigned to another manager, warn the user --}}
                @if ($ticket->assigned_to && $this->isManager && $ticket->assigned_to != $this->user->id)
                    <div id="ats-assignedto-warning" class="akeeba-block--failure small">
                        @sprintf('COM_ATS_TICKET_ALREADY_ASSIGNED_WARN', \Akeeba\TicketSystem\Admin\Helper\Permissions::getUser($ticket->assigned_to)->name)
                    </div>
                @endif

                <div id="ats-reply-form-area">
                    @include('site:com_ats/Posts/post',[
                        'allow_attachment'	=> $this->ticketPerms['attachment'],
                        'direct'			=> true,
                        'category'			=> $ticket->catid,
                        'post_content'      => $this->postContent
                    ])

                    @if(!$this->container->params->get('noreplies', 0) || $this->isManager)
                        <div class="ats-buttonbar">
                            <div class="ats-button ats-button-action-postticket">
                                <button class="akeeba-btn--primary" id="ticketSubmit" type="submit">
                                    @lang('COM_ATS_TICKET_LBL_DOPOST')
                                </button>
                            </div>
                        </div>
                    @endif
                </div>
            @endif

            <input type="hidden" name="option" value="com_ats" />
            <input type="hidden" name="view" value="Post" />
            <input type="hidden" name="task" value="save" />
            <input type="hidden" name="ats_ticket_id"
                   value="{{{ $ticket->ats_ticket_id }}}" />
            <input type="hidden" name="Itemid" value="{{ $this->input->getInt('Itemid',0) }}" />
            <input type="hidden" name="returnurl" value="{{{ $this->returnURL }}}" />
            <input type="hidden" name="@token(true)" id="token" value="1" />
            <input type="hidden" name="last_ats_post_id"
                   value="{{{ isset($last_post->ats_post_id) ? $last_post->ats_post_id : 0 }}}" />
            <input type="hidden" id="category_id" value="{{{ $ticket->catid }}}" />
        </form>
    @elseif($ticket->status == 'C')
        <div class="ats-ticket-closednotice akeeba-block--failure">
            @lang('COM_ATS_TICKET_MSG_CLOSEDNOTICE_CLOSED')
        </div>
    @endif
@stop

@yield('head')
@yield('before-conversation')

@unless($this->isManager)
    @yield('posts-list')
    @yield('after-conversation')
    @yield('reply-area')
@else
    <div id="atsTabContent" class="akeeba-tabs">
        <label for="atsTabConvo" class="active">@lang('COM_ATS_TICKETS_LEGEND_CONVO')</label>
        <section id="atsTabConvo">
            @yield('posts-list')
            @yield('after-conversation')
            @yield('reply-area')
        </section>

        <label for="atsTabManager">@lang('COM_ATS_TICKETS_LEGEND_MANAGERNOTES')</label>
        <section id="atsTabManager">
	        <?php $this->items = $ticket->manager_notes; ?>
            @include('site:com_ats/ManagerNotes/threaded')
	        <?php $this->items = null; ?>
            <h3 class="ats-ticket-reply-header">@lang('COM_ATS_POSTS_HEADING_MANAGERNOTEAREA')</h3>
            @include('site:com_ats/ManagerNotes/form')
        </section>
    </div>
@endif

@yield('footer')

@if($this->container->params->get('userfeedback', 0) && $ticket->status != 'C' && !$this->isManager && ATS_PRO)
    <div style="display: none">
        <div id="akeeba-feedback-modal">
            <div class="akeeba-renderer-fef" style="text-align: center;width: 500px; height: 320px;">
                <h3>@lang('COM_ATS_TICKET_PLEASE_RATE')</h3>
                <p>@lang('COM_ATS_TICKET_PLEASE_RATE_EXPLAIN')</p>

                <form class="akeeba-form">
                    <div class="akeeba-form-group">
                        <div class="akeeba-toggle">
                            <input id="rating-1" type="radio" name="rating" value="1" />
                            <label for="rating-1">1 @lang('COM_ATS_TICKET_PLEASE_RATE_BAD')</label>
                            <input id="rating-2" type="radio" name="rating" value="2" />
                            <label for="rating-2">2</label>
                            <input id="rating-3" type="radio" name="rating" value="3" />
                            <label for="rating-3">3</label>
                            <input id="rating-4" type="radio" name="rating" value="4" />
                            <label for="rating-4">4</label>
                            <input id="rating-5" type="radio" name="rating" value="5" />
                            <label for="rating-5">5 @lang('COM_ATS_TICKET_PLEASE_RATE_GREAT')</label>
                        </div>
                    </div>
                </form>

                <div style="text-align: right">
                    <button type="button" class="akeeba-btn--red atsUserFeedbackModalClose">
                        @lang('JCANCEL')
                    </button>
                    <button type="button" class="akeeba-btn--success atsUserFeedbackModalSubmit">
                        @lang('JSUBMIT')
                    </button>
                </div>
            </div>
        </div>
    </div>
@endif

<div style="display: none">
    <div id="ajaxFormFeedback">
        <div>
            <div class="akeeba-progress">
                <div class="akeeba-progress-fill" style="width:0;"></div>
            </div>
            <div class="messageHolder" style="display:none;text-align: center">
                <div class="message"></div>
                <input type="button" class="closeUpload akeeba-btn--small-grey" value="Ok" />
                <input type="button" class="reloadTicketList akeeba-btn--small-grey" style="display: none"
                       value="@lang('COM_ATS_COMMON_RELOAD')" />
            </div>
        </div>
    </div>
</div>
