<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

defined('_JEXEC') or die;

/** @var Akeeba\TicketSystem\Site\View\Tickets\Html $this */

use Akeeba\TicketSystem\Admin\Helper\Html;

/** @var \Akeeba\TicketSystem\Site\Model\Tickets $ticket */
$ticket = $this->item;

?>
@if ($this->pageParams->get('show_page_heading', 1) || true)
    <h1 class="ats-ticket-view-title">
        #{{{ $ticket->ats_ticket_id }}} &ndash;
        {{{ $ticket->title }}}
    </h1>
    <div class="ats-ticket-view-postedin">
        @sprintf('COM_ATS_TICKET_LBL_POSTEDIN', $this->escape($ticket->joomla_category->title))
    </div>
@endif

<?php if($this->isManager || $this->ticketPerms['close']): ?>
<div>
    <div>

        @if($this->isManager)
            <a id="ats-print-ticket" href="{{ $this->printURL }}" class="akeeba-btn--grey-small atsTooltip"
               data-toggle="tooltip" title="@lang('COM_ATS_TICKETS_PRINTVIEW')" target="_blank">
                <span class="akion-android-print"></span>
            </a>

            @if(!$ticket->public)
                <a id="ats-makepublic-ticket" class="akeeba-btn--grey-small atsTooltip"
                   href="@route($this->adminActionsURL.'&task=public_publish')"
                   data-toggle="tooltip" title="@lang('COM_ATS_TICKET_LBL_MAKEPUBLIC')">
                    <span class="akion-eye-disabled"></span>
                </a>
            @else
                <a id="ats-makeprivate-ticket" class="akeeba-btn--grey-small atsTooltip"
                   href="@route($this->adminActionsURL.'&task=public_unpublish')"
                   data-toggle="tooltip" title="@lang('COM_ATS_TICKET_LBL_MAKEPRIVATE')">
                    <span class="akion-eye"></span>
                </a>
            @endif

            @if(!$ticket->enabled)
                <a id="ats-publish-ticket" class="akeeba-btn--green-small atsTooltip"
                   href="@route($this->adminActionsURL.'&task=publish')"
                   data-toggle="tooltip" title="@lang('COM_ATS_TICKET_LBL_PUBLISH')">
                    <span class="akion-locked"></span>
                </a>
            @else
                <a id="ats-unpublish-ticket" class="akeeba-btn--orange-small atsTooltip"
                   href="@route($this->adminActionsURL.'&task=unpublish')"
                   data-toggle="tooltip" title="@lang('COM_ATS_TICKET_LBL_UNPUBLISH')">
                    <span class="akion-locked"></span>
                </a>
            @endif
        @endif

        @if($ticket->status != 'C')
            @if($this->isManager || !$this->enableUserFeedback || !ATS_PRO)
                <a id="ats-admin-close" class="akeeba-btn--red-small atsTooltip"
                   href="@route($this->adminActionsURL.'&task=close')"
                   data-toggle="tooltip" title="@lang('COM_ATS_TICKET_LBL_CLOSE')">
                    <span class="akion-power"></span>
                </a>
            @else
                <a id="ats-user-close" class="akeeba-btn--red-small atsTooltip user-feedback" href="#akeeba-modal"
                   data-submiturl="@route($this->adminActionsURL.'&task=close')"
                   data-toggle="tooltip" title="@lang('COM_ATS_TICKET_LBL_CLOSE')">
                    <span class="akion-power"></span>
                    @lang('COM_ATS_TICKET_LBL_CLOSE')
                </a>
            @endif
        @elseif($this->isManager)
            {{-- Only administrators can re-open a closed issue --}}
            <a id="ats-reopen" class="akeeba-btn--grey-small atsTooltip"
               href="@route($this->adminActionsURL.'&task=reopen')"
               data-toggle="tooltip" title="@lang('COM_ATS_TICKET_LBL_REOPEN')">
                <span class="akion-loop"></span>
            </a>
        @endif
    </div>

    <div class="akeeba-pull-right">
        @if($this->isManager)
            <div class="ticketstatus">
                @include('admin:com_ats/Common/TicketStatusDropdown', ['item' => $ticket])
            </div>
        @else
            @include('admin:com_ats/Common/TicketStatus', ['item' => $ticket, 'create_span' => true])
        @endif
    </div>

    @if($this->isManager && ATS_PRO)
        <div class="assignto akeeba-pull-right">
            @include('admin:com_ats/Common/ManagerAssignDropdown', ['item' => $ticket, 'selected' => $this->assignedUserFullName])
        </div>
    @endif

    @if($this->isManager)
        <div >
            <form name="ats_moveticket_form" id="ats_moveticket_form"
                  action="@route('index.php?option=com_ats&view=Tickets&Itemid='.$this->itemID)" method="post"
                  class="akeeba-form--inline">
                <input type="hidden" name="option" value="com_ats" />
                <input type="hidden" name="view" value="Tickets" />
                <input type="hidden" name="task" value="move" />
                <input type="hidden" name="id" value="{{ $ticket->ats_ticket_id }}" />
                <input type="hidden" name="Itemid" value="{{ $this->itemID }}" />
                <input type="hidden" name="returnurl" value="{{ $this->returnURL }}" />
                <input type="hidden" name="@token(true)" value="1" />

                @atsCategorySelect($ticket->catid, 'catid', array('class' => 'form-control input-sm atscategory atsCommonEventsOnChangeSubmit', 'data-atssubmittarget' => 'ats_moveticket_form'), null, true)
            </form>
        </div>
    @endif

    @if($this->isManager && $this->showCredits && ATS_PRO )
        @if($this->creditsCharged)
            <a href="index.php?option=com_ats&view=Ticket&task=creditsrefund&id={{ $ticket->ats_ticket_id }}&@token(true)=1&returnurl={{ $this->returnURL }}"
               class="akeeba-btn--red-small atsTooltip" data-toggle="tooltip"
               title="@sprintf('COM_ATS_TICKETS_CREDITS_REFUND', $this->creditsCharged)">
                <span class="akion-minus-round"></span>
                {{ $this->creditsCharged }}
            </a>
        @else
            <a href="index.php?option=com_ats&view=Ticket&task=creditscharge&id={{ $ticket->ats_ticket_id }}&@token(true)=1&returnurl={{ $this->returnURL }}"
               class="akeeba-btn--green-small atsTooltip" data-toggle="tooltip"
               title="@sprintf('COM_ATS_TICKETS_CREDITS_CHARGE', $this->creditsRequiredTicket)">
                <span class="akion-plus-round"></span>
                {{ $this->creditsRequiredTicket }}
            </a>
        @endif
    @endif
</div>
@if($this->showCredits && ATS_PRO)
    <div class="akeeba-block--info small">
        @sprintf('COM_ATS_COMMON_USERCREDITSLEFT', $this->creditsLeft)
    </div>
@endif
<?php endif; ?>

@if($this->isManager && ATS_PRO )
    <div class="akeeba-block--success small">
        <div class="ats-total-timespent">
            @sprintf('COM_ATS_TICKET_TIMESPENT_MSG', $ticket->timespent)
        </div>
        @if ($this->showCredits)
            <div class="ats-total-credits">
                @sprintf('COM_ATS_TICKET_TOTALCREDITS_MSG', $this->totalCredits)
            </div>
        @endif
    </div>
@endif

@if($ticket->public)
    <div class="akeeba-block--warning small" id="ats-newticket-pubnote-public">
        @lang('COM_ATS_NEWTICKET_MSG_PUBNOTE_PUBLIC')
    </div>
@else
    <div class="akeeba-block--success small" id="ats-newticket-pubnote-private">
        @lang('COM_ATS_NEWTICKET_MSG_PUBNOTE_PRIVATE')
    </div>
@endif

