/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof akeeba == "undefined")
{
    var akeeba = {};
}

if (typeof akeeba.ATS == "undefined")
{
    akeeba.ATS = {};
}

if (typeof akeeba.ATS.Buckets == "undefined")
{
    akeeba.ATS.Buckets = {
        modal: null
    };
}

/**
 * Assigns tickets to the bucket on mouse click
 *
 * @param {MouseEvent} event
 */
akeeba.ATS.Buckets.onBucketClick = function (event)
{
    event.preventDefault();

    var elTarget  = event.currentTarget;
    var bucketId  = akeeba.System.data.get(elTarget, "bucketid", 0);
    var ticketIDs = Joomla.getOptions("com_ats.Bucket.ticketIDs", []);

    // Use AJAX to assign the tickets to the bucket
    var url = Joomla.getOptions("com_ats.Bucket.ajaxURL");

    akeeba.System.doAjax({
        ajaxURL:       url,
        ats_ticket_id: ticketIDs,
        cid:           [bucketId],
    }, function (data)
    {
        if (data.success === false)
        {
            akeeba.System.defaultErrorHandler(data.message);

            return;
        }

        // Finally, call the parent window method to close the modal
        window.parent.akeeba.ATS.Buckets.modal.close();
    });
};

/**
 * Opens the bucket selection modal
 *
 * @param   {MouseEvent}  event
 * @returns {boolean}
 */
akeeba.ATS.Buckets.openModal = function (event)
{
    event.preventDefault();

    if (document.adminForm.boxchecked.value == 0)
    {
        alert(Joomla.JText._("JLIB_HTML_PLEASE_MAKE_A_SELECTION_FROM_THE_LIST"));

        return false;
    }

    /** @var {HTMLAnchorElement} elLink */
    var elLink = event.currentTarget;
    var href   = elLink.href;

    akeeba.System.iterateNodes("input[name=\"cid[]\"]:checked", function (item)
    {
        /** @var {HTMLInputElement} item */
        href += "&ats_ticket_id[]=" + item.value;
    });

    akeeba.ATS.Buckets.modal = akeeba.Modal.open({
        iframe: href,
        width:  "80%",
        height: 400
    });

    return false;

};

akeeba.ATS.Buckets.onFilterStatusChange = function (event)
{
    event.preventDefault();

    var elAtsFilterStatus   = document.getElementById("ats_filter_status");
    var elFilterStatus      = document.getElementById("filter-status");
    elAtsFilterStatus.value = elFilterStatus[elFilterStatus.selectedIndex].value;

    document.forms.atspagination.submit();

    return false;
}

/**
 * Initialize the page
 */
akeeba.Loader.add(['akeeba.System', 'akeeba.Modal'], function () {
    akeeba.System.iterateNodes("a.atsBucketSelectLink", function (elLink)
    {
        akeeba.System.addEventListener(elLink, "click", akeeba.ATS.Buckets.onBucketClick);
    });

    akeeba.System.addEventListener("bucketadd", "click", akeeba.ATS.Buckets.openModal);

    akeeba.System.iterateNodes(".atsFilterStatusSelect", function (elSelect)
    {
        akeeba.System.addEventListener(elSelect, "change", akeeba.ATS.Buckets.onFilterStatusChange);
    });
});

// Enable tabs
akeeba.Loader.add('akeeba.fef.tabs', function () {
    akeeba.fef.tabs();
});