/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof akeeba == "undefined")
{
    var akeeba = {};
}

if (typeof akeeba.ATS == "undefined")
{
    akeeba.ATS = {};
}

if (typeof akeeba.ATS.CannedReplies == "undefined")
{
    akeeba.ATS.CannedReplies = {};
}

akeeba.ATS.CannedReplies.active = 1;
akeeba.ATS.CannedReplies.max    = 10;
akeeba.ATS.CannedReplies.id     = 0;

akeeba.ATS.CannedReplies.expand = function (e)
{
    var id = 0;

    if (typeof e != 'object')
    {
        id = e;
    }
    else
    {
        e.preventDefault();

        var el = e.currentTarget;
        id = akeeba.System.data.get(el, "cannedreplyid", 0);
    }

    var replyDiv           = document.getElementById("atsreply" + id);
    var divDisplayState    = (replyDiv.style.display !== "none") && (replyDiv.style.display !== "");
    replyDiv.style.display = divDisplayState ? "none" : "block";

    return false;
}

akeeba.ATS.CannedReplies.use = function (e)
{
    var id = 0;

    if (typeof e != 'object')
    {
        id = e;
    }
    else
    {
        e.preventDefault();

        var el = e.currentTarget;
        id = akeeba.System.data.get(el, "cannedreplyid", 0);
    }

    var content = document.getElementById("atsreply" + id).innerHTML;

    window.parent.akeeba.ATS.CannedReplies.insertIntoEditor(content);

    return false;
}

akeeba.ATS.CannedReplies.renderActiveReply = function ()
{
    akeeba.System.iterateNodes("tr.ats-cannedreply-row", function (e)
    {
        var sequenceId               = akeeba.System.data.get(e, "cannedreplysequence", 0);
        var crId                     = akeeba.System.data.get(e, "cannedreplyid", 0);
        akeeba.ATS.CannedReplies.max = sequenceId;

        if (sequenceId == akeeba.ATS.CannedReplies.active)
        {
            akeeba.ATS.CannedReplies.id = crId;
            akeeba.System.addClass(e, "ats-selected");
        }
        else
        {
            akeeba.System.removeClass(e, "ats-selected");
        }
    });
}

/**
 *
 * @param   {KeyboardEvent} event
 */
akeeba.ATS.CannedReplies.keyPressHandler = function (event)
{
    if ((event.key === 'j') || (event.key === 'J'))
    {
        // Try to go up
        if (akeeba.ATS.CannedReplies.active > 1)
        {
            event.preventDefault();

            akeeba.ATS.CannedReplies.active--;
            akeeba.ATS.CannedReplies.renderActiveReply();
        }
    }
    else if ((event.key === 'k') || (event.key === 'K'))
    {
        // Try to go down
        if (akeeba.ATS.CannedReplies.active < akeeba.ATS.CannedReplies.max)
        {
            event.preventDefault();

            akeeba.ATS.CannedReplies.active++;
            akeeba.ATS.CannedReplies.renderActiveReply();
        }
    }
    else if ((event.key === '+') || (event.key === '-') || (event.key === '='))
    {
        // Plus, minus or equals key was pressed, expand the currently selected reply
        event.preventDefault();

        akeeba.ATS.CannedReplies.expand(akeeba.ATS.CannedReplies.id);
    }
    else if ((event.key === 'Enter'))
    {
        // ENTER key pressed, use the current reply
        event.preventDefault();

        akeeba.ATS.CannedReplies.use(akeeba.ATS.CannedReplies.id);
    }
    // else
    // {
    //     console.log(event.which);
    // }
};

akeeba.Loader.add('akeeba.System', function() {
    akeeba.System.iterateNodes(".atsCannedReplyExpand", function (elBtn)
    {
        akeeba.System.addEventListener(elBtn, "click", akeeba.ATS.CannedReplies.expand);
    });

    akeeba.System.iterateNodes(".atsCannedReplyUse", function (elBtn)
    {
        akeeba.System.addEventListener(elBtn, "click", akeeba.ATS.CannedReplies.use);
    });

    document.addEventListener('keypress', akeeba.ATS.CannedReplies.keyPressHandler, false);

    akeeba.System.triggerEvent(document.getElementById('itemsList'), 'focus');
    //akeeba.ATS.CannedReplies.renderActiveReply();
});