/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof (akeeba) === "undefined")
{
    var akeeba = {};
}

if (typeof (akeeba.ATS) === "undefined")
{
    akeeba.ATS = {};
}

if (typeof (akeeba.ATS.ControlPanel) === "undefined")
{
    akeeba.ATS.ControlPanel = {
        ticketPoints: [],
        postPoints:   [],
        ticketsChart: null,
        sparedChart:  null
    };
}

/**
 * Load and render the graph of tickets and posts the last 10 days
 */
akeeba.ATS.ControlPanel.loadTicketsAndPosts = function ()
{
    akeeba.System.doAjax({
        ajaxURL:       Joomla.getOptions("system.paths").base +
                           "/index.php?option=com_ats&view=ControlPanel&task=getTicketStats&format=raw",
        useTripleHash: false,
        "limitstart":  0,
        "limit":       0,
        "created_on":  {
            "method":   "search",
            "operator": ">=",
            "value":    Joomla.getOptions("ats.ControlPanel.xDay")
        }
    }, function (data)
    {
        akeeba.ATS.ControlPanel.ticketPoints = [];
        akeeba.ATS.ControlPanel.postPoints   = [];

        for (var i = 0; i < data.length; i++)
        {
            var item = data[i];

            akeeba.ATS.ControlPanel.ticketPoints.push({
                "x": item.date,
                "y": item.tickets
            });

            akeeba.ATS.ControlPanel.postPoints.push({
                "x": item.date,
                "y": item.posts
            });
        }

        document.getElementById("akthrobber").style.display = "none";

        akeeba.ATS.ControlPanel.renderTicketsAndPostsGraph();
    });
};

/**
 * Render the graph of tickets and posts the last 10 days
 */
akeeba.ATS.ControlPanel.renderTicketsAndPostsGraph = function ()
{
    var chartOptions = {
        type:    "bar",
        data:    {
            datasets: [
                {
                    label:       "Posts",
                    data:        akeeba.ATS.ControlPanel.postPoints,
                    borderColor: "#F0AD4E",
                    fill:        false,
                    yAxisID:     "y-axis-posts",
                    type:        "line"
                },
                {
                    label:           "Tickets",
                    data:            akeeba.ATS.ControlPanel.ticketPoints,
                    backgroundColor: "#40B5B8",
                    fill:            true,
                    yAxisID:         "y-axis-tickets"
                }
            ]
        },
        options: {
            plugins: {
                legend: {
                    display: false
                }
            },
            scales: {
                x:                {
                    type:  "time",
                    time:  {
                        round:         "day",
                        tooltipFormat: "ll",
                        unit:          "day",
                        minUnit:       "day"
                    },
                    ticks: {
                        color: "#F0AD4E"
                    }
                },
                "y-axis-tickets": {
                    id:       "y-axis-tickets",
                    position: "left",
                    ticks:    {
                        color:       "#40B5B8",
                        beginAtZero: true
                    }
                },
                "y-axis-posts":   {
                    position: "right",
                    ticks:    {
                        color:       "#F0AD4E",
                        beginAtZero: true
                    },
                    grid:     {
                        drawOnChartArea: false
                    }
                }
            }
        }
    };

    if (akeeba.ATS.ControlPanel.ticketsChart)
    {
        akeeba.ATS.ControlPanel.ticketsChart.destroy();
        akeeba.ATS.ControlPanel.ticketsChart = null;
    }

    akeeba.ATS.ControlPanel.ticketsChart = new Chart(document.getElementById("akticketschartCanvas"), chartOptions);
};

akeeba.ATS.ControlPanel.loadSparedTickets = function ()
{
    akeeba.System.doAjax({
        ajaxURL:       Joomla.getOptions("system.paths").base +
                           "/index.php?option=com_ats&view=TicketStatistics&task=showspared&layout=spared&format=json",
        useTripleHash: false,
        "limitstart":  0,
        "limit":       0,
        created_since: document.getElementById("sinceSpared").value,
        created_until: document.getElementById("untilSpared").value
    }, function (data)
    {
        document.getElementById("akthrobberspared").style.display = "none";

        akeeba.ATS.ControlPanel.renderSparedTicketsGraph(data);
    });
};

akeeba.ATS.ControlPanel.renderSparedTicketsGraph = function (data)
{
    var chartOptions = {
        type:    "bar",
        data:    {
            datasets: [
                {
                    label:           "Saved %",
                    data:            data.saved,
                    backgroundColor: "#93C34E",
                    fill:            true,
                    yAxisID:         "y-axis-saved"
                }
            ]
        },
        options: {
            plugins: {
                legend: {
                    display: false
                }
            },
            scales: {
                x:              {
                    type:   "category",
                    labels: data.categories
                },
                "y-axis-saved": {
                    position: "left",
                    ticks:    {
                        beginAtZero: true
                    }
                }
            }
        }
    };

    if (akeeba.ATS.ControlPanel.sparedChart)
    {
        akeeba.ATS.ControlPanel.sparedChart.destroy();
        akeeba.ATS.ControlPanel.sparedChart = null;
    }

    akeeba.ATS.ControlPanel.sparedChart = new Chart(document.getElementById("aksparedticketsCanvas"), chartOptions);
};

/**
 * Convert the user feedback recapitulation table into a live, sortable table.
 */
akeeba.ATS.ControlPanel.applyUserFeedbackTable = function ()
{
    if (!Joomla.getOptions("ats.ControlPanel.UserFeedback", false))
    {
        return;
    }

    if (!document.getElementById("userfeedback"))
    {
        return;
    }

    // Data Tables is the only bit that we cannot implement without using jQuery.
    (function ($)
    {
        $("#userfeedback").dataTable({
            "sDom":            "<<l>r>t<<i><p>>",
            "sPaginationType": "bootstrap"
        });

        $.extend($.fn.dataTableExt.oStdClasses, {
            "sWrapper": "dataTables_wrapper akeeba-form--inline"
        });
    })(window.jQuery);
};

akeeba.Loader.add(["akeeba.System", "Chart"], function ()
{
    akeeba.System.params.errorCallback = function (error)
    {
    };

    akeeba.ATS.ControlPanel.applyUserFeedbackTable();

    // Load the graphs
    akeeba.ATS.ControlPanel.loadTicketsAndPosts();
    akeeba.ATS.ControlPanel.loadSparedTickets();

    // Attach a handler to the spared tickets graph's reload button
    akeeba.System.addEventListener("reloadSpared", "click", akeeba.ATS.ControlPanel.loadSparedTickets);
});
