/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof akeeba == "undefined")
{
    var akeeba = {};
}

if (typeof akeeba.ATS == "undefined")
{
    akeeba.ATS = {};
}

if (typeof akeeba.ATS.Tickets == "undefined")
{
    akeeba.ATS.InstantReply = {
        searching:    false,
        results:      {},
        oldTimeStamp: 0,
        oldSearch:    "",
        statistics:   0
    };
}

/**
 * Key Up event handler for the title field
 *
 * @param   {MouseEvent} event
 */
akeeba.ATS.InstantReply.onTitleKeyUp = function (event)
{
    // If InstantReply is disabled don't take any action
    if (!Joomla.getOptions("ats.InstantReply.enabled", false))
    {
        return;
    }

    // If we're already searching, quit
    if (akeeba.ATS.InstantReply.searching)
    {
        return;
    }

    // Search on space or after at least two seconds have elapsed
    var doSearch = false;

    if (event.key === " ")
    {
        doSearch = true;
    }
    else if (event.timeStamp - akeeba.ATS.InstantReply.oldTimeStamp > 2000)
    {
        doSearch = true;
    }

    // If we don't have to search, bail out
    if (!doSearch)
    {
        return;
    }

    // OK, let's make sure we have enough things to search for
    var searchQuery = document.getElementById("tickettitle").value;

    if (searchQuery === "")
    {
        return;
    }

    if (searchQuery.length < 6)
    {
        return;
    }

    if (akeeba.ATS.InstantReply.oldSearch === searchQuery)
    {
        return;
    }

    akeeba.ATS.InstantReply.oldSearch = searchQuery;

    // Update the timestamp and start searching!
    akeeba.ATS.InstantReply.oldTimeStamp = event.timeStamp;

    var elGrid      = document.getElementById("ats-instantreply-grid");
    var elNoResults = document.getElementById("ats-instantreply-noresults");
    var elWait      = document.getElementById("ats-instantreply-wait");
    var elWrapper   = document.getElementById("ats-instantreply-wrapper");

    elGrid.style.display      = "none";
    elNoResults.style.display = "none";
    elWait.style.display      = "block";

    var atsCategoryID = Joomla.getOptions("ats.InstantReply.catID", 0);
    var url           = Joomla.getOptions("system.paths").base +
        "/index.php?option=com_ats&view=InstantReply&task=browse&format=json&catid=" + atsCategoryID;

    akeeba.ATS.InstantReply.searching = true;

    akeeba.System.doAjax({
        ajaxURL:       url,
        useTripleHash: false,
        search:        searchQuery
    }, akeeba.ATS.InstantReply.onSearchCallback, function (msg)
    {
        elNoResults.style.display = "block";
        elWait.style.display      = "none";
        elGrid.innerHTML          = "";
        elWrapper.style.display   = "none";
    });

    // Instant search statistics
    akeeba.System.doAjax({
        ajaxURL:         Joomla.getOptions("system.paths").base +
                             "/index.php?option=com_ats&view=attempts&format=json",
        useTripleHash:   false,
        task:            "save",
        ats_attempt_id:  akeeba.ATS.InstantReply.statistics,
        title:           searchQuery,
        ats_category_id: atsCategoryID,
        modified_on:     ""
    }, function (response)
    {
        /** @var {HTMLInputElement} attemptIDField */
        var attemptIDField = document.querySelectorAll("input[name=\"ats_attempt_id\"]")[0]

        akeeba.ATS.InstantReply.statistics = response.ats_attempt_id;

        if (attemptIDField)
        {
            attemptIDField.value = akeeba.ATS.InstantReply.statistics;
        }
    });
}

/**
 * Callback for InstantReply search results
 *
 * @param   {Object} msg
 */
akeeba.ATS.InstantReply.onSearchCallback = function (msg)
{
    akeeba.ATS.InstantReply.searching = false;
    var showNoResults                 = false;

    var elWait      = document.getElementById("ats-instantreply-wait");
    var elGrid      = document.getElementById("ats-instantreply-grid");
    var elWrapper   = document.getElementById("ats-instantreply-wrapper");
    var elNoResults = document.getElementById("ats-instantreply-noresults");

    elWait.style.display = "none";
    elGrid.innerHTML     = "";

    try
    {
        if (msg.length < 1)
        {
            // noinspection ExceptionCaughtLocallyJS
            throw "No results";
        }

        elWrapper.style.display   = "block";
        elNoResults.style.display = "none";
        elGrid.style.display      = "block";

        var myTable       = document.createElement("table");
        myTable.className = "akeeba-table--striped";
        elGrid.appendChild(myTable);

        for (var i = 0; i < msg.length; i++)
        {
            var row   = msg[i];
            var myTr  = document.createElement("tr");
            var myDiv = document.createElement("td");
            myTr.appendChild(myDiv);

            var h4       = document.createElement("h4");
            h4.className = "akfaq-title";
            h4.innerHTML = row.title;
            myDiv.appendChild(h4);

            var span       = document.createElement("span");
            span.className = "akfaq-snip";
            span.innerHTML = row.preview + "&nbsp;";
            myDiv.appendChild(span);

            var a       = document.createElement("a");
            a.href      = "#";
            a.className = "akeeba-btn--mini--primary";
            akeeba.System.data.set(a, "source", row.source);
            akeeba.System.data.set(a, "score", row.score);
            a.innerHTML = "View";
            (function (row){
                akeeba.System.addEventListener(a, "click", function (event)
                {
                    event.preventDefault();

                    /** @var {HTMLIFrameElement} elIframe */
                    var elIframe = document.getElementById("ats-instantreply-lightbox-iframe");

                    elIframe.src = row.url + "#docimport";

                    document.getElementById("ats-instantreply-lightbox-wrapper").style.display = "block";

                    akeeba.ATS.InstantReply.clickedLink(event.currentTarget);

                    return false;
                });
            })(row);

            myDiv.appendChild(a);
            myTable.appendChild(myTr);
        }
    }
    catch (err)
    {
        showNoResults = true;
    }

    if (showNoResults)
    {
        elNoResults.style.display = "block";
        elWrapper.style.display   = "none";
    }
}

akeeba.ATS.InstantReply.clickedLink = function (elAnchor)
{
    var url = Joomla.getOptions("system.paths").base +
        "/index.php?option=com_ats&view=attempts&format=json";

    akeeba.System.doAjax({
        ajaxURL:        url,
        useTripleHash:  false,
        task:           "save",
        ats_attempt_id: akeeba.ATS.InstantReply.statistics,
        update_clicks:  akeeba.System.data.get(elAnchor, "source")
    }, function (data)
    {
    });
}

akeeba.Loader.add('akeeba.System', function () {
    // Attach the InstantReply keyup handler to the ticket title
    akeeba.System.addEventListener("tickettitle", "keyup", akeeba.ATS.InstantReply.onTitleKeyUp);

    // Attach a click handler to the InstantReply lightbox close button
    akeeba.System.addEventListener("ats-instantreply-lightbox-close", "click", function (event)
    {
        document.getElementById("ats-instantreply-lightbox-wrapper").style.display = "none";
    });
});