/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof akeeba == "undefined")
{
    var akeeba = {};
}

if (typeof akeeba.ATS == "undefined")
{
    akeeba.ATS = {};
}

if (typeof akeeba.ATS.NewTicket == "undefined")
{
    akeeba.ATS.NewTicket = {
        modal: null
    };
}

/**
 * Callback for the selecting a user through the JUsers view.
 *
 * @param   {int}     id
 * @param   {string}  username
 */
akeeba.ATS.NewTicket.applySelectedUser = function (id, username)
{
    document.getElementById("created_by").value         = id;
    document.getElementById("created_by_visible").value = username;
    akeeba.ATS.NewTicket.modal.close();
}

/**
 * Click handler for the Select User button
 *
 * @param   {MouseEvent} event
 * @returns {boolean}
 */
akeeba.ATS.NewTicket.onUserSelectClick = function (event)
{
    event.preventDefault();

    akeeba.ATS.NewTicket.modal = akeeba.Modal.open({
        iframe: this.href,
        width:  800,
        height: 500
    });

    return false;
}

/**
 * Change event handler for the private ticket dropdown.
 *
 * Only applies when there are no credit charge differences depending on ticket visibility and priority.
 *
 * @param   {MouseEvent} event
 */
akeeba.ATS.NewTicket.onPrivateTicketChange = function (event)
{
    var elPrivateTicket = document.getElementById("privateticket");

    if (elPrivateTicket === null)
    {
        return;
    }

    var elNotePrivate = document.getElementById("ats-newticket-pubnote-private");
    var elNotePublic  = document.getElementById("ats-newticket-pubnote-public");

    if (elPrivateTicket.value == 0)
    {
        elNotePrivate.style.display = "block";
        elNotePublic.style.display  = "none";

        return;
    }

    elNotePrivate.style.display = "none";
    elNotePublic.style.display  = "block";
}

akeeba.ATS.NewTicket.onCreditsImportantChange = function (event)
{
    var elLoading     = document.getElementById("loading");
    var elNotePrivate = document.getElementById("ats-newticket-pubnote-private");
    var elNotePublic  = document.getElementById("ats-newticket-pubnote-public");
    var elSelectPrivate = document.getElementById("privateticket");
    var elTicketPublic = document.querySelectorAll("input[name=\"ticket[public]\"]");
    var isPrivate = false;

    if (!is_null(elSelectPrivate))
    {
        isPrivate = elSelectPrivate.value == 0;
    }
    else {
        isPrivate = elTicketPublic[0].value == 0;
    }

    elLoading.style.display     = "block";
    elNotePrivate.style.display = "none";
    elNotePublic.style.display  = "none";

    akeeba.System.doAjax({
        ajaxURL:       Joomla.getOptions("system.paths").base +
                           "/index.php?option=com_ats&view=NewTickets&task=getcredits&format=json",
        useTripleHash: false,
        "public":        isPrivate ? 0 : 1,
        catid:         document.getElementById("ticket_catid").value,
        priority:      document.getElementById("ticketpriority").value
    }, function (responseJSON)
    {
        elLoading.style.display     = "none";

        if (isPrivate)
        {
            document.querySelectorAll("#ats-newticket-pubnote-private .credits")[0]
                .innerHTML = responseJSON.credits;
            elNotePrivate.style.display = 'block';

            return;
        }

        document.querySelectorAll("#ats-newticket-pubnote-public .credits")[0]
            .innerHTML = responseJSON.credits;
        elNotePublic.style.display = 'block';
    })
}

/**
 * Click handler for change ticket status drop-downs menus.
 *
 * @param   {MouseEvent}  event
 */
akeeba.ATS.NewTicket.onAddAttachmentClick = function (event)
{
    event.preventDefault();

    var elAttachedFiles = document.querySelectorAll("input[name=\"attachedfile[]\"]");

    if (elAttachedFiles.length >= 10)
    {
        return false;
    }

    var mainField     = document.getElementById("attachedfileMainField");
    /** @var {HTMLElement} clone */
    var clone         = mainField.cloneNode(true);
    var elLabel       = clone.querySelectorAll("label")[0];
    var elFileField   = clone.querySelectorAll(".attFileField")[0];
    var elButtonField = clone.querySelectorAll(".attButtonField")[0];
    var elButton      = elButtonField.querySelectorAll("a")[0];

    clone.id                    = null;
    elLabel.innerHTML           = "";
    elLabel.className           = "";
    elFileField.value           = "";
    elButtonField.style.display = "inline-block";

    mainField.insertAdjacentElement("afterend", clone);

    akeeba.System.addEventListener(elButton, "click", function (clickEvent)
    {
        clickEvent.preventDefault();

        /** @var {HTMLElement} elAnchor */
        var elAnchor = clickEvent.currentTarget;
        var elDiv    = elAnchor.parentElement.parentElement.parentElement;
        elDiv.parentElement.removeChild(elDiv);
    });
}

akeeba.Loader.add(['akeeba.Modal', 'akeeba.System'], function ()
{
    akeeba.System.addEventListener("userselect", "click", akeeba.ATS.NewTicket.onUserSelectClick);
    akeeba.System.addEventListener("addAttachment", "click", akeeba.ATS.NewTicket.onAddAttachmentClick);

    if (!Joomla.getOptions("ats.PriorityCredits.enabled", false))
    {
        akeeba.System.addEventListener("privateticket", "change", akeeba.ATS.NewTicket.onPrivateTicketChange)
    }
    else
    {
        akeeba.System.addEventListener("privateticket", "change", akeeba.ATS.NewTicket.onCreditsImportantChange)
        akeeba.System.addEventListener("ticketpriority", "change", akeeba.ATS.NewTicket.onCreditsImportantChange)

    }
});
