/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof akeeba == "undefined")
{
    var akeeba = {};
}

if (typeof akeeba.ATS == "undefined")
{
    akeeba.ATS = {};
}

if (typeof akeeba.ATS.Tickets == "undefined")
{
    akeeba.ATS.Tickets = {
        feedbackModal: null,
        timer:         null,
        timeCounter:   null
    };
}

/**
 * Click handler for assign to manager drop-downs menus.
 *
 * @param   {MouseEvent}  event
 */
akeeba.ATS.Tickets.onManagerAssignClick = function (event)
{
    /** @var {Element} elAnchor */
    var elAnchor  = event.currentTarget;
    var btn_class = "--grey";
    var id        = akeeba.System.data.get(elAnchor, "ticketid");
    var assign_to = akeeba.System.data.get(elAnchor, "userid");

    // Teal class if we're assigning to us
    if (assign_to)
    {
        // Assigned to someone else
        btn_class = "--dark";

        // Assigned to me
        if (assign_to === document.getElementById("user").value)
        {
            btn_class = "--teal";
        }
        else if (assign_to <= 0)
        {
            btn_class = "--grey";
        }
    }

    var elButton = elAnchor.parentElement.parentElement.querySelectorAll("button")[0];

    akeeba.System.doAjax({
        ajaxURL:       Joomla.getOptions("system.paths").base +
                           "/index.php?option=com_ats&view=Tickets&format=json&" +
                           Joomla.getOptions("csrf.token") + "=1",
        useTripleHash: false,
        "task":        "assign",
        "id":          id,
        "assigned_to": assign_to
    }, function (data)
    {
        if (data.result !== true)
        {
            return;
        }

        elButton.className = "akeeba-btn--small" + btn_class;
        elButton.innerHTML = data.assigned;
    })
};

/**
 * Click handler for change ticket status drop-downs menus.
 *
 * @param   {MouseEvent}  event
 */
akeeba.ATS.Tickets.onTicketStatusClick = function (event)
{
    var elAnchor   = event.currentTarget;
    var btn_status = "grey";
    var status     = akeeba.System.data.get(elAnchor, "status");
    var ticketID   = akeeba.System.data.get(elAnchor, "ticketid");

    switch (status)
    {
        case "O":
            btn_status = "red";
            break;

        case "P":
            btn_status = "orange";
            break;

        case "C":
            btn_status = "green";
            break;
    }

    var elButton = elAnchor.parentElement.parentElement.querySelectorAll("button")[0];

    akeeba.System.doAjax({
            ajaxURL:       Joomla.getOptions("system.paths").base +
                               "/index.php?option=com_ats&view=Tickets&task=ajax_set_status&format=json&" +
                               Joomla.getOptions("csrf.token") + "=1",
            useTripleHash: false,
            id:            ticketID,
            status:        status
        }, function (data)
        {
            if (data.err)
            {
                akeeba.System.defaultErrorHandler(data.err);

                return;
            }

            elButton.className = "akeeba-btn-small--" + btn_status;
            elButton.innerHTML = data.msg;
        }
    );
};

/**
 * Ticket reply form submission handler. This applies only to members of the Support Staff, obviously.
 *
 * @param   {Event} event
 */
akeeba.ATS.Tickets.onReplyFormSubmit = function (event)
{
    var canSubmit = true;

    if (Joomla.getOptions("ats.Tickets.timeSpendMandatory", false))
    {
        var timeSpent = document.getElementById("ats-timespent").value;

        canSubmit = timeSpent > 0;
    }

    if (!canSubmit)
    {
        event.preventDefault();

        return false;
    }

    return true;
}

/**
 * Click handler for change ticket status drop-downs menus.
 *
 * @param   {MouseEvent}  event
 */
akeeba.ATS.Tickets.onAddAttachmentClick = function (event)
{
    event.preventDefault();

    var elAttachedFiles = document.querySelectorAll("input[name=\"attachedfile[]\"]");

    if (elAttachedFiles.length >= 10)
    {
        return false;
    }

    var mainField     = document.getElementById("attachedfileMainField");
    /** @var {HTMLElement} clone */
    var clone         = mainField.cloneNode(true);
    var elLabel       = clone.querySelectorAll("label")[0];
    var elFileField   = clone.querySelectorAll(".attFileField")[0];
    var elButtonField = clone.querySelectorAll(".attButtonField")[0];
    var elButton      = elButtonField.querySelectorAll("a")[0];

    clone.id                    = null;
    elLabel.innerHTML           = "";
    elLabel.className           = "";
    elFileField.value           = "";
    elButtonField.style.display = "inline-block";

    mainField.insertAdjacentElement("afterend", clone);

    akeeba.System.addEventListener(elButton, "click", function (clickEvent)
    {
        clickEvent.preventDefault();

        /** @var {HTMLElement} elAnchor */
        var elAnchor = clickEvent.currentTarget;
        var elDiv    = elAnchor.parentElement.parentElement.parentElement;
        elDiv.parentElement.removeChild(elDiv);
    });
}

/**
 * Applies on the Assigned Tickets page only. Handles the filter change to reload the page.
 */
akeeba.ATS.Tickets.assignedTicketsFiltering = function ()
{
    var elFilterStatus = document.getElementById("filter-status");

    if (elFilterStatus === null)
    {
        return;
    }

    akeeba.System.addEventListener(elFilterStatus, "change", function (event)
    {
        document.getElementById("ats_filter_status").value = elFilterStatus.value;
        document.getElementById("ats-pagination").submit();
    });
}

/**
 * Applies the category filtering on the My Tickets and Assigned Tickets pages
 */
akeeba.ATS.Tickets.myTicketsFiltering = function ()
{
    var elCategory = document.getElementById("category");

    if ((elCategory === null))
    {
        return;
    }

    akeeba.System.addEventListener(elCategory, "change", function (event)
    {
        var elAdminForm  = document.getElementById("adminForm");
        var elPagination = document.getElementById("ats-pagination");

        if (elAdminForm)
        {
            elAdminForm.submit();
        }
        else if (elPagination)
        {
            elPagination.submit();
        }
    });
}

/**
 * Click event handler for the User Feedback modal dialog's Close button
 *
 * @param   {MouseEvent} event
 * @returns {boolean}
 */
akeeba.ATS.Tickets.onUserFeedbackModalCloseClick = function (event)
{
    event.preventDefault();
    akeeba.ATS.Tickets.feedbackModal.close();

    return false;
}

/**
 * Click event handler for the User Feedback modal dialog's Submit button
 *
 * @param   {MouseEvent} event
 * @returns {boolean}
 */
akeeba.ATS.Tickets.onUserFeedbackModalSubmitClick = function (event)
{
    var elChecked = document.querySelectorAll("input[name=\"rating\"]:checked")[0];
    var rating    = 0;

    if (elChecked)
    {
        rating = elChecked.value;
    }

    if (rating <= 0)
    {
        event.preventDefault();

        return false;
    }

    var url            = "";
    var elUserFeedback = document.querySelectorAll(".user-feedback")[0];

    if (elUserFeedback)
    {
        url = akeeba.System.data.get(elUserFeedback, "submiturl", "");
    }

    if (!url)
    {
        return true;
    }

    event.preventDefault();

    url += "&rating=" + rating;

    window.location = url;

    return false;
};

akeeba.ATS.Tickets.onTimerTick = function ()
{
    var elTimeSpent = document.getElementById("ats-timespent");

    akeeba.ATS.Tickets.timeCounter += 5;

    if (elTimeSpent)
    {
        elTimeSpent.value = Math.ceil(akeeba.ATS.Tickets.timeCounter / 60);
    }
}

/**
 * Click handler for the timer start / stop button
 *
 * @param   {MouseEvent} event
 */
akeeba.ATS.Tickets.onTimerToggleClick = function (event)
{
    event.preventDefault();
    /** @var {HTMLElement} elButton */
    var elButton = event.currentTarget;

    if (akeeba.ATS.Tickets.timer)
    {
        clearInterval(akeeba.ATS.Tickets.timer);
        akeeba.ATS.Tickets.timer = null;

        elButton.innerHTML = Joomla.JText._("COM_ATS_TIMER_START");

        return;
    }

    akeeba.ATS.Tickets.timeCounter = 0;
    akeeba.ATS.Tickets.timer = setInterval(akeeba.ATS.Tickets.onTimerTick, 5000);

    elButton.innerHTML = Joomla.JText._("COM_ATS_TIMER_STOP");
}

akeeba.ATS.Tickets.onFilterStatusChange = function (event)
{
    event.preventDefault();

    var elAtsFilterStatus   = document.getElementById("ats_filter_status");
    var elFilterStatus      = document.getElementById("filter-status");
    elAtsFilterStatus.value = elFilterStatus[elFilterStatus.selectedIndex].value;

    document.forms.atspagination.submit();

    return false;
}

// Enable tabs
akeeba.Loader.add('akeeba.fef.tabs', function () {
    akeeba.fef.tabs();
});

akeeba.Loader.add('akeeba.fef.dropdown', function () {
    akeeba.fef.dropdown();
});

akeeba.Loader.add(['akeeba.System', 'akeeba.Modal'], function ()
{
    akeeba.System.iterateNodes(".assignto nav.akeeba-dropdown a", function (elAnchor)
    {
        akeeba.System.addEventListener(elAnchor, "click", akeeba.ATS.Tickets.onManagerAssignClick);
    });

    akeeba.System.iterateNodes(".ticketstatus nav.akeeba-dropdown a", function (elAnchor)
    {
        akeeba.System.addEventListener(elAnchor, "click", akeeba.ATS.Tickets.onTicketStatusClick);
    });

    akeeba.System.iterateNodes("form.ats_reply_form", function (elForm)
    {
        akeeba.System.addEventListener(elForm, "submit", akeeba.ATS.Tickets.onReplyFormSubmit);
    });

    akeeba.System.iterateNodes(".atsFilterStatusSelect", function (elSelect)
    {
        akeeba.System.addEventListener(elSelect, "change", akeeba.ATS.Tickets.onFilterStatusChange);
    });

    akeeba.System.addEventListener("addAttachment", "click", akeeba.ATS.Tickets.onAddAttachmentClick);

    // For the Assigned Tickets page.
    akeeba.ATS.Tickets.assignedTicketsFiltering();

    // For the My Tickets page. Also applies on Latest Open Tickets.
    akeeba.ATS.Tickets.myTicketsFiltering();

    // User Feedback, if enabled
    if (Joomla.getOptions("ats.UserFeedback.enable", false))
    {
        // Attach event handler to the ticket close button
        akeeba.System.addEventListener("ats-user-close", "click", function (event)
        {
            event.preventDefault();

            akeeba.ATS.Tickets.feedbackModal = akeeba.Modal.open({
                inherit: "#akeeba-feedback-modal"
            });
        })

        // Attach a click event handler to the user feedback modal dialog's Close button
        akeeba.System.iterateNodes("button.atsUserFeedbackModalClose", function (elButton)
        {
            akeeba.System.addEventListener(elButton, "click", akeeba.ATS.Tickets.onUserFeedbackModalCloseClick);
        });

        // Attach a click event handler to the user feedback modal dialog's Submit button
        akeeba.System.iterateNodes("button.atsUserFeedbackModalSubmit", function (elButton)
        {
            akeeba.System.addEventListener(elButton, "click", akeeba.ATS.Tickets.onUserFeedbackModalSubmitClick);
        });
    }

    // Manager time tracking
    var elTimerButton = document.getElementById('timerBtn');
    akeeba.System.addEventListener(elTimerButton, 'click', akeeba.ATS.Tickets.onTimerToggleClick);

    if (Joomla.getOptions('ats.TimeSpent.mandatory', false) && elTimerButton)
    {
        akeeba.System.triggerEvent(elTimerButton, 'click');
    }
});