/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof (akeeba) === "undefined")
{
    var akeeba = {};
}

if (typeof (akeeba.ATS) === "undefined")
{
    akeeba.ATS = {};
}

if (typeof (akeeba.ATS.TimeCards) === "undefined")
{
    akeeba.ATS.TimeCards = {
        timeChart: null
    };
}

akeeba.ATS.TimeCards.load = function ()
{
    akeeba.System.doAjax({
        ajaxURL:        Joomla.getOptions("system.paths").base +
                            "/index.php?option=com_ats&view=TimeCards&task=browse&format=json",
        useTripleHash:  false,
        "limitstart":   0,
        "limit":        0,
        "sumtimespent": 1,
        "created_on":   {
            "from":    document.getElementById("time_start").value,
            "to":      document.getElementById("time_end").value,
            "method":  "between",
            "include": true
        }
    }, function (data)
    {
        akeeba.ATS.TimeCards.renderGraph(data);
    });
};

akeeba.ATS.TimeCards.renderGraph = function (data)
{
    var chartOptions = {
        type:    "bar",
        data:    {
            datasets: [
                {
                    label:           "Hours",
                    data:            data.data,
                    backgroundColor: "#40B5B8",
                    fill:            true,
                    yAxisID:         "y-axis-hours"
                }
            ]
        },
        options: {
            legend: {
                display: false
            },
            scales: {
                x:              {
                    type:   "category",
                    labels: data.labels,
                    ticks:  {
                        color: "#F0AD4E"
                    }
                },
                "y-axis-hours": [
                    {
                        position: "left",
                        ticks:    {
                            color:       "#40B5B8",
                            beginAtZero: true
                        }
                    }
                ]
            }
        }
    };

    if (akeeba.ATS.TimeCards.timeChart)
    {
        akeeba.ATS.TimeCards.timeChart.destroy();
        akeeba.ATS.TimeCards.timeChart = null;
    }

    akeeba.ATS.TimeCards.timeChart = new Chart(document.getElementById("ats-timecard"), chartOptions);
};

akeeba.Loader.add("akeeba.System", function ()
{
    akeeba.System.addEventListener("time_graph_reload", "click", akeeba.ATS.TimeCards.load);

    akeeba.ATS.TimeCards.load();
});
