<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') or die();

use Joomla\CMS\Factory as JFactory;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri as JUri;

class plgAtsSociallike extends CMSPlugin
{
	/**
	 * Public constructor
	 *
	 * @param   object  $subject  The onject to observe
	 * @param   array   $config   Configuration parameters to the plugin
	 */
	public function __construct(&$subject, $config = [])
	{
		parent::__construct($subject, $config);

		if (!defined('FOF40_INCLUDED'))
		{
			require_once JPATH_LIBRARIES . '/fof40/include.php';
		}
	}

	public function onBeforeTicketConversationDisplay($ticket)
	{
		// Share only public tickets
		if (!$ticket->public)
		{
			return '';
		}

		// Are we on localhost? Output a warning, since things won't work
		$url   = Route::_('index.php?option=com_ats&view=ticket&id=' . $ticket->ats_ticket_id, true, Route::TLS_IGNORE, true);
		$title = $ticket->title;

		$this->addJavascript();

		$html = '<div class="addthis_toolbox addthis_default_style">';

		if ($this->params->get('button_facebook', 1))
		{
			$html .= '<a class="addthis_button_facebook_like" addthis:url="' . $url . '" fb:like:layout="button_count"></a>';
		}

		if ($this->params->get('button_twitter', 1))
		{
			$html .= '<a class="addthis_button_tweet" addthis:url="' . $url . '" tw:text="' . $title . '"></a>';
		}

		if ($this->params->get('button_gplus', 1))
		{
			$html .= '<a class="addthis_button_google_plusone" addthis:url="' . $url . '" g:plusone:annotation="bubble" g:plusone:size="medium"></a>';
		}

		if ($this->params->get('button_linkedin', 1))
		{
			$html .= '<a class="addthis_button_linkedin_counter"></a>';
		}

		if ($this->params->get('button_stumbleupon', 1))
		{
			$html .= '<a class="addthis_button_stumbleupon_badge"></a>';
		}

		if ($this->params->get('button_pinterest', 1))
		{
			$container = FOF40\Container\Container::getInstance('com_ats');
			$html      .= '<a class="addthis_button_pinterest_pinit" pi:pinit:url="' . $url . '" pi:pinit:media="' . $container->template->parsePath('media://com_ats/images/ats-256.png') . '" pi:pinit:layout="horizontal"></a>';
		}

		if ($this->params->get('button_addthis', 1))
		{
			$html .= '<a class="addthis_counter addthis_pill_style" addthis:url="' . $url . '"></a>';
		}

		$html .= '</div>';

		return $html;
	}

	public function onAfterTicketConversationDisplay($ticket)
	{
		return $this->onBeforeTicketConversationDisplay($ticket);
	}

	private function addJavascript()
	{
		static $included = false;

		if ($included)
		{
			return;
		}

		// Get the correct protocol (http or https)
		$uri      = JUri::getInstance();
		$protocol = $uri->toString(['scheme']);

		JFactory::getDocument()->addScript($protocol . 's7.addthis.com/js/300/addthis_widget.js', [
			'version' => 'auto'
		], [
			'defer' => true
		]);

		$included = true;
	}
}
